*==================== PROGRAM: PSI17_ALL_CONTROL.SAS ======================= ;
* ------------------------------------------------------------------------- ;
*                >>> AHRQ QI VERSION 6.0.2 ICD-09-CM <<<
*                >>> VERSION DATE AUGUST 2017 <<<
* ------------------------------------------------------------------------- ;
 * The PATIENT SAFETY Indicator 17 (PSI 17) stand alone module of the AHRQ 
   Quality Indicators software includes the following programs:
   
    1. PSI17_ALL_CONTROL.sas  Assigns user inputs required by other programs
                            and optional output options.  
                        
    2. PSI17_ALL_FORMATS.sas  Creates SAS format library used by other programs.

    3. PSI17_ALL_MEASURES.sas  Assigns HCUP PEDIATRIC Quality                    
                               Indicators to inpatient records.

    4. PSI17_PROV_OBSERVED.sas Calculates observed provider rates               
                             for Pediatric Quality Indicators.  

 * The software also requires the following files:
 
    1. discharges.sas7bdat  User supplied discharge level file organized according 
                            to the layout in the software instructions.
                            The file name is up to the user but must be listed below.
                            
    2. PSI17_Dx_Px_Macros.sas Standard processes used by the other SAS programs.
                            The user does not need to open.
******************************************************************* ;
****************************PLEASE READ**************************** ;
******************************************************************* ;
 * The AHRQ Quality Indicator software is intended for use with discharges
   coded according to the standards in place at the date of the discharge. 
   Discharges should be classified under the ICD-09-CM/PCS specifications 
   effective 10/1/2007 to 09/30/2015. All diagnosis codes require a corresponding 
   Present On Admission, POA, value coded according to UB04 standards. 
   
 * The USER MUST modify portions of the following code in order to
   run this software.  With one exception (see NOTE immediately
   following this paragraph), the only changes necessary to run
   this software are changes in this program (PSI17_ALL_CONTROL.SAS). 
   The modifications include such items as specifying the name and location
   of the input data set, the year of population data to be used, and the 
   name and location of output data sets.
 
 * NOTE:  PSI17_ALL_CONTROL.SAS provides the option to read data in and write 
          data out to different locations.  For example, "libname INMSR" points
          to the location of the input data set for the PSI17_ALL_MEASURES program
          and "libname OUTMSR" points to the location of the output data set
          created by the PSI17_ALL_MEASURES program.  The location and file name of 
          each input and output can be assigned separately below. The default 
          values will place output in a SASData folder with standard names for
          each file based on the location of the PSI 17 folder listed in the 
          PATHNAME variable.
          
 * NOTE:  In the other programs included with this package there is a 
          line of code that begins with "filename CONTROL".  
          The USER MUST include after "filename CONTROL" the location
          of the PSI17_ALL_CONTROL.SAS file.

 * Generally speaking, a first-time user of this software would
   proceed as follows:
        1.  Modify PSI17_ALL_CONTROL.SAS.  (MUST be done.)
        2.  In the program generating needed formats, i.e., in
            PSI17_ALL_FORMATS.SAS, specify location (path name) of
            PSI17_ALL_CONTROL.SAS. (MUST be done.)
        3.  Run PSI17_ALL_FORMATS.SAS.  (MUST be done.)
        4.  Open PSI17_ALL_MEASURES.SAS and specify location of PSI17_ALL_CONTROL.SAS
            program.  (MUST be done.)
        5.  Run PSI17_MEASURES.  (MUST be done.)
        6.  To calculate provider level rates for Patient Safety Indicator 17 (PSI 17):
             a. Open PSI17_PROV_OBSERVED.SAS and specify location
                of PSI17_ALL_CONTROL.SAS program. (MUST be done.) 
             b. Run PSI17_PROV_OBSERVED.SAS. (MUST have run PSI17_ALL_MEASURES.SAS.)

 * ---------------------------------------------------------------- ;           
 * ---                       All Programs                       --- ;           
 * ---------------------------------------------------------------- ;           
*PATHNAME specifies the main working folder which includes 
          Macros, ParmFiles, Programs, and SASdata subfolders;
%LET PATHNAME=c:\Pathname\PSI17;                  *<===USER MUST modify;
*DISFOLDER specifies the folder that contains the discharge data;
%LET DISFOLDER=c:\pathname\PSI17\SASData;         *<===USER MUST modify;
*DISCHARGE specifies the name of the discharge data file;
%LET DISCHARGE=discharges;                      *<===USER MUST modify;
*SUFX specifies an identifier suffix to be placed on all output datasets;
%LET SUFX=v6_ICD9;                              *<===USER may modify;

title "TITLE - PSI 17 - &SUFX.";                                  
libname LIBRARY "&PATHNAME.\SASData";

 * ---------------------------------------------------------------- ;
 * --- INDICATE IF RECORDS SHOULD BE PRINTED IN SAS OUTPUT AT   --- ;
 * --- END OF EACH PROGRAM.  0 = NO, 1 = YES                    --- ;
 * ---------------------------------------------------------------- ;
%LET PRINT = 1;                                 *<===USER may modify;

 * --------------------------------------------------------------- ;
 * --- ADD OPTIONS TO COMPRESS OUTPUT AND SUPPRESS SOURCE CODE  --- ;
 * --- IN LOG. RECOMMENDED WITH LARGE FILES. TO RESTORE, RUN:   --- ;
 * --- options source compress = no                             --- ;
 * ---------------------------------------------------------------- ;
options compress = YES ;               *<===USER may modify;

 * ---------------------------------------------------------------- ;
 * --- SET LOCATION OF SAS MACRO LIBRARY                        --- ;
 * ---------------------------------------------------------------- ;
filename MacLib "&PATHNAME.\Macros" ;

 * ---------------------------------------------------------------- ;
 * ---         Program : PSI17_ALL_MEASURES.SAS                 --- ;
 * ---------------------------------------------------------------- ;
 * ---------------------------------------------------------------- ;
 * --- SET LOCATION OF PSI17_ALL_MEASURES INPUT DATA            --- ;
 * ---------------------------------------------------------------- ;
libname INMSR  "&DISFOLDER.";                     *<==USER may modify;
 * ---------------------------------------------------------------- ;
 * --- SET LOCATION OF PSI17_ALL_MEASURES OUTPUT DATA           --- ;
 * ---------------------------------------------------------------- ;
libname OUTMSR "&PATHNAME.\SASdata";          *<==USER may modify;
 * --- SET NAME OF OUTPUT FILE FROM PSI17_ALL_MEASURES.SAS        --- ;
%LET OUTFILE_MEAS = psi17msr_&SUFX.;             *<===USER may modify;

 * ---------------------------------------------------------------- ;
 * --- MODIFY INPUT AND OUTPUT FILE                             --- ;
 * ---------------------------------------------------------------- ;
 * --- PROGRAM DEFAULT ASSUMES THERE ARE                        --- ;
 * ---     35 DIAGNOSES (DX1-DX35)                              --- ;
 * ---------------------------------------------------------------- ;
 * --- MODIFY NUMBER OF DIAGNOSES, VARIABLES                    --- ;
 * --- TO MATCH INPUT DATA                                      --- ;
 * ---------------------------------------------------------------- ;
%LET NDX = 35;                                   *<===USER may modify;

 * ---------------------------------------------------------------- ;
 * - CREATE PERMANENT SAS DATASET TO STORE RECORDS THAT WILL    --- ;
 * - NOT BE INCLUDED IN CALCULATIONS BECAUSE KEY VARIABLE       --- ;
 * - VALUES ARE MISSING.  THIS DATASET SHOULD BE REVIEWED AFTER --- ;
 * - RUNNING PSI17_ALL_MEASURES.SAS.                            --- ;
 * ---------------------------------------------------------------- ;
%LET DELFILE1  = PS17_DELETED_&SUFX.;

 * =================================================================;
 * ============PROVIDER-LEVEL PEDIATRIC QUALITY INDICATORS==========;
 * =================================================================;
 * ---              PSI17_PROV_OBSERVED : Observed Rates        --- ;
 * ---------------------------------------------------------------- ;
libname OUTPOBS "&PATHNAME.\SASdata";

 * ----------------------------------------------------------------------- ;
 * --- TYPELVLP indicates the levels (or _TYPE_) of                    --- ;
 * --- summarization to be kept in the output.                         --- ;
 * ---                                                                 --- ;
 * ---  TYPELVLP      stratification                                   --- ;
 * ---  --------  ---------------------------------------------------- --- ;
 * ---     0      overall                                              --- ;
 * ---     1                                                      race --- ;
 * ---     2                                              payer        --- ;
 * ---     3                                              payer * race --- ;
 * ---     4                                        sex                --- ;
 * ---     5                                        sex         * race --- ;
 * ---     6                                        sex * payer        --- ;
 * ---     7                                        sex * payer * race --- ;
 * ---     8                                  age                      --- ;
 * ---     9                                  age               * race --- ;
 * ---    10                                  age       * payer        --- ;
 * ---    11                                  age       * payer * race --- ;
 * ---    12                                  age * sex                --- ;
 * ---    13                                  age * sex         * race --- ;
 * ---    14                                  age * sex * payer        --- ;
 * ---    15                                  age * sex * payer * race --- ;
 * ---    16                         ageday                            --- ;
 * ---    17                         ageday                     * race --- ;
 * ---    18                         ageday             * payer        --- ;
 * ---    19                         ageday             * payer * race --- ;
 * ---    20                         ageday       * sex                --- ;
 * ---    21                         ageday       * sex         * race --- ;
 * ---    22                         ageday       * sex * payer        --- ;
 * ---    23                         ageday       * sex * payer * race --- ;
 * ---    24                         ageday * age                      --- ;
 * ---    25                         ageday * age               * race --- ;
 * ---    26                         ageday * age       * payer        --- ;
 * ---    27                         ageday * age       * payer * race --- ;
 * ---    28                         ageday * age * sex                --- ;
 * ---    29                         ageday * age * sex         * race --- ;
 * ---    30                         ageday * age * sex * payer        --- ;
 * ---    31                         ageday * age * sex * payer * race --- ;
 * ---    32                  bwht                                     --- ;
 * ---    33                  bwht                              * race --- ;
 * ---    34                  bwht                      * payer        --- ;
 * ---    35                  bwht                      * payer * race --- ;
 * ---    36                  bwht                * sex                --- ;
 * ---    37                  bwht                * sex         * race --- ;
 * ---    38                  bwht                * sex * payer        --- ;
 * ---    39                  bwht                * sex * payer * race --- ;
 * ---    40                  bwht          * age                      --- ;
 * ---    41                  bwht          * age               * race --- ;
 * ---    42                  bwht          * age       * payer        --- ;
 * ---    43                  bwht          * age       * payer * race --- ;
 * ---    44                  bwht          * age * sex                --- ;
 * ---    45                  bwht          * age * sex         * race --- ;
 * ---    46                  bwht          * age * sex * payer        --- ;
 * ---    47                  bwht          * age * sex * payer * race --- ;
 * ---    48                  bwht * ageday                            --- ;
 * ---    49                  bwht * ageday                     * race --- ;
 * ---    50                  bwht * ageday             * payer        --- ;
 * ---    51                  bwht * ageday             * payer * race --- ;
 * ---    52                  bwht * ageday       * sex                --- ;
 * ---    53                  bwht * ageday       * sex         * race --- ;
 * ---    54                  bwht * ageday       * sex * payer        --- ;
 * ---    55                  bwht * ageday       * sex * payer * race --- ;
 * ---    56                  bwht * ageday * age                      --- ;
 * ---    57                  bwht * ageday * age               * race --- ;
 * ---    58                  bwht * ageday * age       * payer        --- ;
 * ---    59                  bwht * ageday * age       * payer * race --- ;
 * ---    60                  bwht * ageday * age * sex                --- ;
 * ---    61                  bwht * ageday * age * sex         * race --- ;
 * ---    62                  bwht * ageday * age * sex * payer        --- ;
 * ---    63                  bwht * ageday * age * sex * payer * race --- ;
 * ---    64       provider                                            --- ;
 * ---    65       provider                                     * race --- ;
 * ---    66       provider                             * payer        --- ;
 * ---    67       provider                             * payer * race --- ;
 * ---    68       provider                       * sex                --- ;
 * ---    69       provider                       * sex         * race --- ;
 * ---    70       provider                       * sex * payer        --- ;
 * ---    71       provider                       * sex * payer * race --- ;
 * ---    72       provider                 * age                      --- ;
 * ---    73       provider                 * age               * race --- ;
 * ---    74       provider                 * age       * payer        --- ;
 * ---    75       provider                 * age       * payer * race --- ;
 * ---    76       provider                 * age * sex                --- ;
 * ---    77       provider                 * age * sex         * race --- ;
 * ---    78       provider                 * age * sex * payer        --- ;
 * ---    79       provider                 * age * sex * payer * race --- ;
 * ---    80       provider        * ageday                            --- ;
 * ---    81       provider        * ageday                     * race --- ;
 * ---    82       provider        * ageday             * payer        --- ;
 * ---    83       provider        * ageday             * payer * race --- ;
 * ---    84       provider        * ageday       * sex                --- ;
 * ---    85       provider        * ageday       * sex         * race --- ;
 * ---    86       provider        * ageday       * sex * payer        --- ;
 * ---    87       provider        * ageday       * sex * payer * race --- ;
 * ---    88       provider        * ageday * age                      --- ;
 * ---    89       provider        * ageday * age               * race --- ;
 * ---    90       provider        * ageday * age       * payer        --- ;
 * ---    91       provider        * ageday * age       * payer * race --- ;
 * ---    92       provider        * ageday * age * sex                --- ;
 * ---    93       provider        * ageday * age * sex         * race --- ;
 * ---    94       provider        * ageday * age * sex * payer        --- ;
 * ---    95       provider        * ageday * age * sex * payer * race --- ;
 * ---    96       provider * bwht                                     --- ;
 * ---    97       provider * bwht                              * race --- ;
 * ---    98       provider * bwht                      * payer        --- ;
 * ---    99       provider * bwht                      * payer * race --- ;
 * ---   100       provider * bwht                * sex                --- ;
 * ---   101       provider * bwht                * sex         * race --- ;
 * ---   102       provider * bwht                * sex * payer        --- ;
 * ---   103       provider * bwht                * sex * payer * race --- ;
 * ---   104       provider * bwht          * age                      --- ;
 * ---   105       provider * bwht          * age               * race --- ;
 * ---   106       provider * bwht          * age       * payer        --- ;
 * ---   107       provider * bwht          * age       * payer * race --- ;
 * ---   108       provider * bwht          * age * sex                --- ;
 * ---   109       provider * bwht          * age * sex         * race --- ;
 * ---   110       provider * bwht          * age * sex * payer        --- ;
 * ---   111       provider * bwht          * age * sex * payer * race --- ;
 * ---   112       provider * bwht * ageday                            --- ;
 * ---   113       provider * bwht * ageday                     * race --- ;
 * ---   114       provider * bwht * ageday             * payer        --- ;
 * ---   115       provider * bwht * ageday             * payer * race --- ;
 * ---   116       provider * bwht * ageday       * sex                --- ;
 * ---   117       provider * bwht * ageday       * sex         * race --- ;
 * ---   118       provider * bwht * ageday       * sex * payer        --- ;
 * ---   119       provider * bwht * ageday       * sex * payer * race --- ;
 * ---   120       provider * bwht * ageday * age                      --- ;
 * ---   121       provider * bwht * ageday * age               * race --- ;
 * ---   122       provider * bwht * ageday * age       * payer        --- ;
 * ---   123       provider * bwht * ageday * age       * payer * race --- ;
 * ---   124       provider * bwht * ageday * age * sex                --- ;
 * ---   125       provider * bwht * ageday * age * sex         * race --- ;
 * ---   126       provider * bwht * ageday * age * sex * payer        --- ;
 * ---   127       provider * bwht * ageday * age * sex * payer * race --- ;
 * ---                                                                 --- ;
 * --- The default TYPELVLP (0,64) will provide an overall             --- ;
 * --- and provider-level totals. If you run stratifications that      --- ;
 * --- include Age and/or Sex, be aware that the numerical             --- ;
 * --- results for non-Age/Sex categories will be incorrect.           --- ;  
 * ----------------------------------------------------------------------- ;  

%LET TYPELVLP = IN (0,64);                         *<===USER may modify;   

 * ----------------------------------------------------------------- ;
 * --- NAME OF SAS DATASET OUTPUT FROM PSI_PROV_OBSERVED         --- ;
 * --- SUMMARY OUTPUT FILE OF OBSERVED PROVIDER RATES.           --- ;
 * ----------------------------------------------------------------- ;
%LET OUTFILE_PROVOBS = PS17POBS_&SUFX.;        *<===USER may modify;

 * ------------------------------------------------------------------ ;
 * --- INDICATE IF A COMMA-DELIMITED FILE SHOULD BE GENERATED FOR --- ;
 * --- EXPORT INTO A SPREADSHEET. 0 = NO, 1 = YES.                --- ;
 * ------------------------------------------------------------------ ;
%LET TEXTPOBS = 1;                                 *<===USER may modify;

 * ---------------------------------------------------------------- ;
 * --- IF YOU CREATE A COMMA-DELIMITED FILE, SPECIFY THE LOCATION - ;
 * --- OF THE FILE.                                             --- ;
 * ---------------------------------------------------------------- ;
filename PDPOBS "&PATHNAME.\SASdata\PS17POBS_&SUFX..TXT";  *<===USER MUST modify;   

