*=================== PROGRAM: PSI17_ALL_FORMATS.SAS ============================;
*
*  TITLE:  SAS formats for AHRQ Patient Safety Indicator 17
*          
*  DESCRIPTION:
*     Format library for AHRQ Patient Safety Indicator 17
*
*     AHRQ QI VERSION 6.0.2 ICD-09-CM
*     VERSION DATE AUGUST 2017
*
*     Note: Codes valid from 10/1/2007 to 9/30/2015 (FY 2015)
*
*=============================================================================;

*PATHNAME specifies the main working folder which includes 
          Macros, ParmFiles, Programs, and SASdata subfolders;
filename CONTROL "c:\pathname\PSI_17\PROGRAMS\PSI17_ALL_CONTROL.SAS";
%include CONTROL;

proc Format library=LIBRARY;
 
/* -------------------------------------------------------------- */
/* --- FORMATS FOR STRATIFIERS ---------------------------------- */
/* -------------------------------------------------------------- */

/* --- FORMAT FOR SEX CATEGORY ---------------------------------- */
value SEXCAT
1 = 'Male'
2 = 'Female';
 
/* --- FORMAT FOR AGE CATEGORY ---------------------------------- */
value PAGECAT
1 = "<1"
2 = "1 TO 2"
3 = "3 TO 5"
4 = "6 TO 12"
5 = "13 TO 17";
 
/* --- FORMAT FOR AGEDAY CATEGORY ------------------------------- */
value AGEDCAT
0 = "NA"
1 = "0 TO 28"
2 = "29 TO 60"
3 = "61 TO 90"
4 = "91+";
 
/* --- FORMAT FOR BIRTH WEIGHT CATEGORY ------------------------- */
value BWHTCAT
0 = "NA"
1 = "0 TO 499g"
2 = "500 TO 749g"
3 = "750 TO 999g"
4 = "1000 TO 1249g"
5 = "1250 TO 1499g"
6 = "1500 TO 1749g"
7 = "1750 TO 1999g"
8 = "2000 TO 2499g"
9 = "2500g or more";
 
/* --- FORMAT FOR RACE CATEGORY --------------------------------- */
value RACECAT
1 = 'White'
2 = 'Black'
3 = 'Hispanic'
4 = 'Asian and NH/PI'
5 = 'Amer Indian/AN'
6 = 'Other';
 
/* --- FORMAT FOR PAYER CATEGORY ---------------------------------- */
value PAYCAT
1 = 'Medicare'
2 = 'Medicaid'
3 = 'Private'
4 = 'Self Pay'
5 = 'No Charge'
6 = 'Other';
 
/* -------------------------------------------------------------- */
/* --- FORMATS FOR MDC using principal diagnosis for MEDICARE data*/
/* -------------------------------------------------------------- */

   VALUE $DX1MDC
   '0010'  = 06
   '0011'  = 06
   '0019'  = 06
   '0020'  = 18
   '0021'  = 18
   '0022'  = 18
   '0023'  = 18
   '0029'  = 18
   '0030'  = 06
   '0031'  = 18
   '00320' = 18
   '00321' = 01
   '00322' = 04
   '00323' = 08
   '00324' = 08
   '00329' = 18
   '0038'  = 18
   '0039'  = 18
   '0040'  = 06
   '0041'  = 06
   '0042'  = 06
   '0043'  = 06
   '0048'  = 06
   '0049'  = 06
   '0050'  = 06
   '0051'  = 18
   '0052'  = 06
   '0053'  = 06
   '0054'  = 06
   '00581' = 06
   '00589' = 06
   '0059'  = 06
   '0060'  = 06
   '0061'  = 06
   '0062'  = 06
   '0063'  = 07
   '0064'  = 04
   '0065'  = 01
   '0066'  = 09
   '0068'  = 18
   '0069'  = 18
   '0070'  = 06
   '0071'  = 06
   '0072'  = 06
   '0073'  = 06
   '0074'  = 06
   '0075'  = 06
   '0078'  = 06
   '0079'  = 06
   '00800' = 06
   '00801' = 06
   '00802' = 06
   '00803' = 06
   '00804' = 06
   '00809' = 06
   '0081'  = 06
   '0082'  = 06
   '0083'  = 06
   '00841' = 06
   '00842' = 06
   '00843' = 06
   '00844' = 06
   '00845' = 06
   '00846' = 06
   '00847' = 06
   '00849' = 06
   '0085'  = 06
   '00861' = 06
   '00862' = 06
   '00863' = 06
   '00864' = 06
   '00865' = 06
   '00866' = 06
   '00867' = 06
   '00869' = 06
   '0088'  = 06
   '0090'  = 06
   '0091'  = 06
   '0092'  = 06
   '0093'  = 06
   '01000' = 04
   '01001' = 04
   '01002' = 04
   '01003' = 04
   '01004' = 04
   '01005' = 04
   '01006' = 04
   '01010' = 04
   '01011' = 04
   '01012' = 04
   '01013' = 04
   '01014' = 04
   '01015' = 04
   '01016' = 04
   '01080' = 04
   '01081' = 04
   '01082' = 04
   '01083' = 04
   '01084' = 04
   '01085' = 04
   '01086' = 04
   '01090' = 04
   '01091' = 04
   '01092' = 04
   '01093' = 04
   '01094' = 04
   '01095' = 04
   '01096' = 04
   '01100' = 04
   '01101' = 04
   '01102' = 04
   '01103' = 04
   '01104' = 04
   '01105' = 04
   '01106' = 04
   '01110' = 04
   '01111' = 04
   '01112' = 04
   '01113' = 04
   '01114' = 04
   '01115' = 04
   '01116' = 04
   '01120' = 04
   '01121' = 04
   '01122' = 04
   '01123' = 04
   '01124' = 04
   '01125' = 04
   '01126' = 04
   '01130' = 04
   '01131' = 04
   '01132' = 04
   '01133' = 04
   '01134' = 04
   '01135' = 04
   '01136' = 04
   '01140' = 04
   '01141' = 04
   '01142' = 04
   '01143' = 04
   '01144' = 04
   '01145' = 04
   '01146' = 04
   '01150' = 04
   '01151' = 04
   '01152' = 04
   '01153' = 04
   '01154' = 04
   '01155' = 04
   '01156' = 04
   '01160' = 04
   '01161' = 04
   '01162' = 04
   '01163' = 04
   '01164' = 04
   '01165' = 04
   '01166' = 04
   '01170' = 04
   '01171' = 04
   '01172' = 04
   '01173' = 04
   '01174' = 04
   '01175' = 04
   '01176' = 04
   '01180' = 04
   '01181' = 04
   '01182' = 04
   '01183' = 04
   '01184' = 04
   '01185' = 04
   '01186' = 04
   '01190' = 04
   '01191' = 04
   '01192' = 04
   '01193' = 04
   '01194' = 04
   '01195' = 04
   '01196' = 04
   '01200' = 04
   '01201' = 04
   '01202' = 04
   '01203' = 04
   '01204' = 04
   '01205' = 04
   '01206' = 04
   '01210' = 04
   '01211' = 04
   '01212' = 04
   '01213' = 04
   '01214' = 04
   '01215' = 04
   '01216' = 04
   '01220' = 04
   '01221' = 04
   '01222' = 04
   '01223' = 04
   '01224' = 04
   '01225' = 04
   '01226' = 04
   '01230' = 03
   '01231' = 03
   '01232' = 03
   '01233' = 03
   '01234' = 03
   '01235' = 03
   '01236' = 03
   '01280' = 04
   '01281' = 04
   '01282' = 04
   '01283' = 04
   '01284' = 04
   '01285' = 04
   '01286' = 04
   '01300' = 01
   '01301' = 01
   '01302' = 01
   '01303' = 01
   '01304' = 01
   '01305' = 01
   '01306' = 01
   '01310' = 01
   '01311' = 01
   '01312' = 01
   '01313' = 01
   '01314' = 01
   '01315' = 01
   '01316' = 01
   '01320' = 01
   '01321' = 01
   '01322' = 01
   '01323' = 01
   '01324' = 01
   '01325' = 01
   '01326' = 01
   '01330' = 01
   '01331' = 01
   '01332' = 01
   '01333' = 01
   '01334' = 01
   '01335' = 01
   '01336' = 01
   '01340' = 01
   '01341' = 01
   '01342' = 01
   '01343' = 01
   '01344' = 01
   '01345' = 01
   '01346' = 01
   '01350' = 01
   '01351' = 01
   '01352' = 01
   '01353' = 01
   '01354' = 01
   '01355' = 01
   '01356' = 01
   '01360' = 01
   '01361' = 01
   '01362' = 01
   '01363' = 01
   '01364' = 01
   '01365' = 01
   '01366' = 01
   '01380' = 01
   '01381' = 01
   '01382' = 01
   '01383' = 01
   '01384' = 01
   '01385' = 01
   '01386' = 01
   '01390' = 01
   '01391' = 01
   '01392' = 01
   '01393' = 01
   '01394' = 01
   '01395' = 01
   '01396' = 01
   '01400' = 06
   '01401' = 06
   '01402' = 06
   '01403' = 06
   '01404' = 06
   '01405' = 06
   '01406' = 06
   '01480' = 06
   '01481' = 06
   '01482' = 06
   '01483' = 06
   '01484' = 06
   '01485' = 06
   '01486' = 06
   '01500' = 08
   '01501' = 08
   '01502' = 08
   '01503' = 08
   '01504' = 08
   '01505' = 08
   '01506' = 08
   '01510' = 08
   '01511' = 08
   '01512' = 08
   '01513' = 08
   '01514' = 08
   '01515' = 08
   '01516' = 08
   '01520' = 08
   '01521' = 08
   '01522' = 08
   '01523' = 08
   '01524' = 08
   '01525' = 08
   '01526' = 08
   '01550' = 08
   '01551' = 08
   '01552' = 08
   '01553' = 08
   '01554' = 08
   '01555' = 08
   '01556' = 08
   '01560' = 03
   '01561' = 03
   '01562' = 03
   '01563' = 03
   '01564' = 03
   '01565' = 03
   '01566' = 03
   '01570' = 08
   '01571' = 08
   '01572' = 08
   '01573' = 08
   '01574' = 08
   '01575' = 08
   '01576' = 08
   '01580' = 08
   '01581' = 08
   '01582' = 08
   '01583' = 08
   '01584' = 08
   '01585' = 08
   '01586' = 08
   '01590' = 08
   '01591' = 08
   '01592' = 08
   '01593' = 08
   '01594' = 08
   '01595' = 08
   '01596' = 08
   '01600' = 11
   '01601' = 11
   '01602' = 11
   '01603' = 11
   '01604' = 11
   '01605' = 11
   '01606' = 11
   '01610' = 11
   '01611' = 11
   '01612' = 11
   '01613' = 11
   '01614' = 11
   '01615' = 11
   '01616' = 11
   '01620' = 11
   '01621' = 11
   '01622' = 11
   '01623' = 11
   '01624' = 11
   '01625' = 11
   '01626' = 11
   '01630' = 11
   '01631' = 11
   '01632' = 11
   '01633' = 11
   '01634' = 11
   '01635' = 11
   '01636' = 11
   '01640' = 12
   '01641' = 12
   '01642' = 12
   '01643' = 12
   '01644' = 12
   '01645' = 12
   '01646' = 12
   '01650' = 12
   '01651' = 12
   '01652' = 12
   '01653' = 12
   '01654' = 12
   '01655' = 12
   '01656' = 12
   '01660' = 13
   '01661' = 13
   '01662' = 13
   '01663' = 13
   '01664' = 13
   '01665' = 13
   '01666' = 13
   '01670' = 13
   '01671' = 13
   '01672' = 13
   '01673' = 13
   '01674' = 13
   '01675' = 13
   '01676' = 13
   '01690' = 11
   '01691' = 11
   '01692' = 11
   '01693' = 11
   '01694' = 11
   '01695' = 11
   '01696' = 11
   '01700' = 09
   '01701' = 09
   '01702' = 09
   '01703' = 09
   '01704' = 09
   '01705' = 09
   '01706' = 09
   '01710' = 09
   '01711' = 09
   '01712' = 09
   '01713' = 09
   '01714' = 09
   '01715' = 09
   '01716' = 09
   '01720' = 16
   '01721' = 16
   '01722' = 16
   '01723' = 16
   '01724' = 16
   '01725' = 16
   '01726' = 16
   '01730' = 02
   '01731' = 02
   '01732' = 02
   '01733' = 02
   '01734' = 02
   '01735' = 02
   '01736' = 02
   '01740' = 03
   '01741' = 03
   '01742' = 03
   '01743' = 03
   '01744' = 03
   '01745' = 03
   '01746' = 03
   '01750' = 10
   '01751' = 10
   '01752' = 10
   '01753' = 10
   '01754' = 10
   '01755' = 10
   '01756' = 10
   '01760' = 10
   '01761' = 10
   '01762' = 10
   '01763' = 10
   '01764' = 10
   '01765' = 10
   '01766' = 10
   '01770' = 16
   '01771' = 16
   '01772' = 16
   '01773' = 16
   '01774' = 16
   '01775' = 16
   '01776' = 16
   '01780' = 06
   '01781' = 06
   '01782' = 06
   '01783' = 06
   '01784' = 06
   '01785' = 06
   '01786' = 06
   '01790' = 18
   '01791' = 18
   '01792' = 18
   '01793' = 18
   '01794' = 18
   '01795' = 18
   '01796' = 18
   '01800' = 18
   '01801' = 18
   '01802' = 18
   '01803' = 18
   '01804' = 18
   '01805' = 18
   '01806' = 18
   '01880' = 18
   '01881' = 18
   '01882' = 18
   '01883' = 18
   '01884' = 18
   '01885' = 18
   '01886' = 18
   '01890' = 18
   '01891' = 18
   '01892' = 18
   '01893' = 18
   '01894' = 18
   '01895' = 18
   '01896' = 18
   '0200'  = 18
   '0201'  = 18
   '0202'  = 18
   '0203'  = 04
   '0204'  = 04
   '0205'  = 04
   '0208'  = 18
   '0209'  = 18
   '0210'  = 18
   '0211'  = 06
   '0212'  = 04
   '0213'  = 18
   '0218'  = 18
   '0219'  = 18
   '0220'  = 09
   '0221'  = 04
   '0222'  = 06
   '0223'  = 18
   '0228'  = 18
   '0229'  = 18
   '0230'  = 18
   '0231'  = 18
   '0232'  = 18
   '0233'  = 18
   '0238'  = 18
   '0239'  = 18
   '024'   = 18
   '025'   = 18
   '0260'  = 18
   '0261'  = 18
   '0269'  = 18
   '0270'  = 18
   '0271'  = 18
   '0272'  = 18
   '0278'  = 18
   '0279'  = 18
   '0300'  = 18
   '0301'  = 18
   '0302'  = 18
   '0303'  = 18
   '0308'  = 18
   '0309'  = 18
   '0310'  = 04
   '0311'  = 09
   '0312'  = 18
   '0318'  = 18
   '0319'  = 18
   '0320'  = 03
   '0321'  = 03
   '0322'  = 03
   '0323'  = 03
   '03281' = 02
   '03282' = 05
   '03283' = 06
   '03284' = 11
   '03285' = 09
   '03289' = 18
   '0329'  = 18
   '0330'  = 04
   '0331'  = 04
   '0338'  = 04
   '0339'  = 04
   '0340'  = 03
   '0341'  = 18
   '035'   = 09
   '0360'  = 01
   '0361'  = 01
   '0362'  = 18
   '0363'  = 18
   '03640' = 05
   '03641' = 05
   '03642' = 05
   '03643' = 05
   '03681' = 02
   '03682' = 08
   '03689' = 18
   '0369'  = 18
   '037'   = 18
   '0380'  = 18
   '03810' = 18
   '03811' = 18
   '03812' = 18
   '03819' = 18
   '0382'  = 18
   '0383'  = 18
   '03840' = 18
   '03841' = 18
   '03842' = 18
   '03843' = 18
   '03844' = 18
   '03849' = 18
   '0388'  = 18
   '0389'  = 18
   '0390'  = 09
   '0391'  = 04
   '0392'  = 06
   '0393'  = 09
   '0394'  = 09
   '0398'  = 18
   '0399'  = 18
   '0400'  = 18
   '0401'  = 18
   '0402'  = 06
   '0403'  = 18
   '04041' = 18
   '04042' = 18
   '04081' = 08
   '04082' = 18
   '04089' = 18
   '04100' = 18
   '04101' = 18
   '04102' = 18
   '04103' = 18
   '04104' = 18
   '04105' = 18
   '04109' = 18
   '04110' = 18
   '04111' = 18
   '04112' = 18
   '04119' = 18
   '0412'  = 18
   '0413'  = 18
   '04141' = 18
   '04142' = 18
   '04143' = 18
   '04149' = 18
   '0415'  = 18
   '0416'  = 18
   '0417'  = 18
   '04181' = 18
   '04182' = 18
   '04183' = 18
   '04184' = 18
   '04185' = 18
   '04186' = 18
   '04189' = 18
   '0419'  = 18
   '042'   = 25
   '04500' = 01
   '04501' = 01
   '04502' = 01
   '04503' = 01
   '04510' = 01
   '04511' = 01
   '04512' = 01
   '04513' = 01
   '04520' = 18
   '04521' = 18
   '04522' = 18
   '04523' = 18
   '04590' = 01
   '04591' = 01
   '04592' = 01
   '04593' = 01
   '0460'  = 01
   '04611' = 01
   '04619' = 01
   '0462'  = 01
   '0463'  = 01
   '04671' = 01
   '04672' = 01
   '04679' = 01
   '0468'  = 01
   '0469'  = 01
   '0470'  = 01
   '0471'  = 01
   '0478'  = 01
   '0479'  = 01
   '048'   = 01
   '0490'  = 01
   '0491'  = 01
   '0498'  = 01
   '0499'  = 01
   '0500'  = 18
   '0501'  = 18
   '0502'  = 18
   '0509'  = 18
   '05101' = 18
   '05102' = 18
   '0511'  = 09
   '0512'  = 09
   '0519'  = 18
   '0520'  = 01
   '0521'  = 04
   '0522'  = 01
   '0527'  = 18
   '0528'  = 18
   '0529'  = 18
   '0530'  = 01
   '05310' = 01
   '05311' = 01
   '05312' = 01
   '05313' = 01
   '05314' = 01
   '05319' = 01
   '05320' = 02
   '05321' = 02
   '05322' = 02
   '05329' = 02
   '05371' = 03
   '05379' = 18
   '0538'  = 18
   '0539'  = 09
   '0540'  = 09
   '05410' = 12
   '05411' = 13
   '05412' = 13
   '05413' = 12
   '05419' = 12
   '0542'  = 03
   '0543'  = 01
   '05440' = 02
   '05441' = 02
   '05442' = 02
   '05443' = 02
   '05444' = 02
   '05449' = 02
   '0545'  = 18
   '0546'  = 09
   '05471' = 06
   '05472' = 01
   '05473' = 03
   '05474' = 01
   '05479' = 18
   '0548'  = 18
   '0549'  = 09
   '0550'  = 01
   '0551'  = 04
   '0552'  = 03
   '05571' = 02
   '05579' = 18
   '0558'  = 18
   '0559'  = 18
   '05600' = 01
   '05601' = 01
   '05609' = 01
   '05671' = 08
   '05679' = 18
   '0568'  = 18
   '0569'  = 18
   '0570'  = 18
   '0578'  = 18
   '0579'  = 18
   '05810' = 18
   '05811' = 18
   '05812' = 18
   '05821' = 01
   '05829' = 01
   '05881' = 09
   '05882' = 09
   '05889' = 09
   '05900' = 18
   '05901' = 18
   '05909' = 18
   '05910' = 18
   '05911' = 18
   '05912' = 18
   '05919' = 18
   '05920' = 18
   '05921' = 18
   '05922' = 18
   '0598'  = 18
   '0599'  = 18
   '0600'  = 18
   '0601'  = 18
   '0609'  = 18
   '061'   = 18
   '0620'  = 01
   '0621'  = 01
   '0622'  = 01
   '0623'  = 01
   '0624'  = 01
   '0625'  = 01
   '0628'  = 01
   '0629'  = 01
   '0630'  = 01
   '0631'  = 01
   '0632'  = 01
   '0638'  = 01
   '0639'  = 01
   '064'   = 01
   '0650'  = 18
   '0651'  = 18
   '0652'  = 18
   '0653'  = 18
   '0654'  = 18
   '0658'  = 18
   '0659'  = 18
   '0660'  = 18
   '0661'  = 18
   '0662'  = 01
   '0663'  = 18
   '06640' = 18
   '06641' = 18
   '06642' = 18
   '06649' = 18
   '0668'  = 18
   '0669'  = 18
   '0700'  = 07
   '0701'  = 07
   '07020' = 07
   '07021' = 07
   '07022' = 07
   '07023' = 07
   '07030' = 07
   '07031' = 07
   '07032' = 07
   '07033' = 07
   '07041' = 07
   '07042' = 07
   '07043' = 07
   '07044' = 07
   '07049' = 07
   '07051' = 07
   '07052' = 07
   '07053' = 07
   '07054' = 07
   '07059' = 07
   '0706'  = 07
   '07070' = 07
   '07071' = 07
   '0709'  = 07
   '071'   = 01
   '0720'  = 12
   '0721'  = 01
   '0722'  = 01
   '0723'  = 07
   '07271' = 07
   '07272' = 01
   '07279' = 18
   '0728'  = 18
   '0729'  = 18
   '0730'  = 04
   '0737'  = 18
   '0738'  = 18
   '0739'  = 18
   '0740'  = 03
   '0741'  = 04
   '07420' = 05
   '07421' = 05
   '07422' = 05
   '07423' = 05
   '0743'  = 18
   '0748'  = 18
   '075'   = 18
   '0760'  = 02
   '0761'  = 02
   '0769'  = 02
   '0770'  = 02
   '0771'  = 02
   '0772'  = 02
   '0773'  = 02
   '0774'  = 02
   '0778'  = 02
   '07798' = 02
   '07799' = 02
   '0780'  = 09
   '07810' = 09
   '07811' = 09
   '07812' = 09
   '07819' = 09
   '0782'  = 18
   '0783'  = 16
   '0784'  = 18
   '0785'  = 18
   '0786'  = 11
   '0787'  = 18
   '07881' = 01
   '07882' = 06
   '07888' = 18
   '07889' = 18
   '0790'  = 18
   '0791'  = 18
   '0792'  = 18
   '0793'  = 18
   '0794'  = 18
   '07950' = 18
   '07951' = 18
   '07952' = 18
   '07953' = 18
   '07959' = 18
   '0796'  = 18
   '07981' = 18
   '07982' = 18
   '07983' = 18
   '07988' = 18
   '07989' = 18
   '07998' = 18
   '07999' = 18
   '080'   = 18
   '0810'  = 18
   '0811'  = 18
   '0812'  = 18
   '0819'  = 18
   '0820'  = 18
   '0821'  = 18
   '0822'  = 18
   '0823'  = 18
   '08240' = 18
   '08241' = 18
   '08249' = 18
   '0828'  = 18
   '0829'  = 18
   '0830'  = 18
   '0831'  = 18
   '0832'  = 18
   '0838'  = 18
   '0839'  = 18
   '0840'  = 18
   '0841'  = 18
   '0842'  = 18
   '0843'  = 18
   '0844'  = 18
   '0845'  = 18
   '0846'  = 18
   '0847'  = 18
   '0848'  = 18
   '0849'  = 18
   '0850'  = 18
   '0851'  = 09
   '0852'  = 09
   '0853'  = 09
   '0854'  = 09
   '0855'  = 09
   '0859'  = 18
   '0860'  = 05
   '0861'  = 18
   '0862'  = 18
   '0863'  = 18
   '0864'  = 18
   '0865'  = 18
   '0869'  = 18
   '0870'  = 18
   '0871'  = 18
   '0879'  = 18
   '0880'  = 18
   '08881' = 18
   '08882' = 18
   '08889' = 18
   '0889'  = 18
   '0900'  = 18
   '0901'  = 18
   '0902'  = 18
   '0903'  = 02
   '09040' = 01
   '09041' = 01
   '09042' = 01
   '09049' = 01
   '0905'  = 18
   '0906'  = 18
   '0907'  = 18
   '0909'  = 18
   '0910'  = 12
   '0911'  = 06
   '0912'  = 18
   '0913'  = 09
   '0914'  = 16
   '09150' = 02
   '09151' = 02
   '09152' = 02
   '09161' = 08
   '09162' = 07
   '09169' = 06
   '0917'  = 18
   '09181' = 01
   '09182' = 09
   '09189' = 18
   '0919'  = 18
   '0920'  = 18
   '0929'  = 18
   '0930'  = 05
   '0931'  = 05
   '09320' = 05
   '09321' = 05
   '09322' = 05
   '09323' = 05
   '09324' = 05
   '09381' = 05
   '09382' = 05
   '09389' = 05
   '0939'  = 05
   '0940'  = 01
   '0941'  = 01
   '0942'  = 01
   '0943'  = 01
   '09481' = 01
   '09482' = 01
   '09483' = 02
   '09484' = 02
   '09485' = 01
   '09486' = 03
   '09487' = 01
   '09489' = 01
   '0949'  = 01
   '0950'  = 02
   '0951'  = 04
   '0952'  = 06
   '0953'  = 07
   '0954'  = 11
   '0955'  = 08
   '0956'  = 08
   '0957'  = 08
   '0958'  = 18
   '0959'  = 18
   '096'   = 18
   '0970'  = 18
   '0971'  = 18
   '0979'  = 18
   '0980'  = 12
   '09810' = 12
   '09811' = 11
   '09812' = 12
   '09813' = 12
   '09814' = 12
   '09815' = 13
   '09816' = 13
   '09817' = 13
   '09819' = 12
   '0982'  = 12
   '09830' = 11
   '09831' = 11
   '09832' = 12
   '09833' = 12
   '09834' = 12
   '09835' = 13
   '09836' = 13
   '09837' = 13
   '09839' = 12
   '09840' = 02
   '09841' = 02
   '09842' = 02
   '09843' = 02
   '09849' = 02
   '09850' = 08
   '09851' = 08
   '09852' = 08
   '09853' = 08
   '09859' = 08
   '0986'  = 03
   '0987'  = 06
   '09881' = 02
   '09882' = 01
   '09883' = 05
   '09884' = 05
   '09885' = 05
   '09886' = 06
   '09889' = 18
   '0990'  = 12
   '0991'  = 12
   '0992'  = 12
   '0993'  = 08
   '09940' = 12
   '09941' = 12
   '09949' = 12
   '09950' = 12
   '09951' = 03
   '09952' = 06
   '09953' = 12
   '09954' = 11
   '09955' = 12
   '09956' = 06
   '09959' = 12
   '0998'  = 12
   '0999'  = 12
   '1000'  = 18
   '10081' = 01
   '10089' = 01
   '1009'  = 18
   '101'   = 03
   '1020'  = 09
   '1021'  = 09
   '1022'  = 09
   '1023'  = 09
   '1024'  = 09
   '1025'  = 03
   '1026'  = 08
   '1027'  = 18
   '1028'  = 18
   '1029'  = 18
   '1030'  = 09
   '1031'  = 09
   '1032'  = 18
   '1033'  = 09
   '1039'  = 18
   '1040'  = 18
   '1048'  = 18
   '1049'  = 18
   '1100'  = 09
   '1101'  = 09
   '1102'  = 09
   '1103'  = 09
   '1104'  = 09
   '1105'  = 09
   '1106'  = 09
   '1108'  = 09
   '1109'  = 09
   '1110'  = 09
   '1111'  = 09
   '1112'  = 09
   '1113'  = 09
   '1118'  = 09
   '1119'  = 09
   '1120'  = 03
   '1121'  = 13
   '1122'  = 12
   '1123'  = 09
   '1124'  = 04
   '1125'  = 18
   '11281' = 05
   '11282' = 03
   '11283' = 01
   '11284' = 06
   '11285' = 06
   '11289' = 18
   '1129'  = 18
   '1140'  = 04
   '1141'  = 09
   '1142'  = 01
   '1143'  = 18
   '1144'  = 04
   '1145'  = 04
   '1149'  = 18
   '11500' = 18
   '11501' = 01
   '11502' = 02
   '11503' = 05
   '11504' = 05
   '11505' = 04
   '11509' = 18
   '11510' = 18
   '11511' = 01
   '11512' = 02
   '11513' = 05
   '11514' = 05
   '11515' = 04
   '11519' = 18
   '11590' = 18
   '11591' = 01
   '11592' = 02
   '11593' = 05
   '11594' = 05
   '11595' = 04
   '11599' = 18
   '1160'  = 18
   '1161'  = 18
   '1162'  = 18
   '1170'  = 18
   '1171'  = 18
   '1172'  = 18
   '1173'  = 18
   '1174'  = 18
   '1175'  = 18
   '1176'  = 18
   '1177'  = 18
   '1178'  = 18
   '1179'  = 18
   '118'   = 18
   '1200'  = 11
   '1201'  = 07
   '1202'  = 18
   '1203'  = 09
   '1208'  = 18
   '1209'  = 18
   '1210'  = 07
   '1211'  = 07
   '1212'  = 04
   '1213'  = 07
   '1214'  = 07
   '1215'  = 18
   '1216'  = 18
   '1218'  = 18
   '1219'  = 18
   '1220'  = 07
   '1221'  = 04
   '1222'  = 10
   '1223'  = 18
   '1224'  = 18
   '1225'  = 07
   '1226'  = 18
   '1227'  = 18
   '1228'  = 07
   '1229'  = 18
   '1230'  = 06
   '1231'  = 06
   '1232'  = 06
   '1233'  = 06
   '1234'  = 06
   '1235'  = 06
   '1236'  = 06
   '1238'  = 06
   '1239'  = 06
   '124'   = 18
   '1250'  = 18
   '1251'  = 18
   '1252'  = 18
   '1253'  = 18
   '1254'  = 18
   '1255'  = 18
   '1256'  = 18
   '1257'  = 18
   '1259'  = 18
   '1260'  = 06
   '1261'  = 06
   '1262'  = 06
   '1263'  = 06
   '1268'  = 06
   '1269'  = 06
   '1270'  = 06
   '1271'  = 06
   '1272'  = 06
   '1273'  = 06
   '1274'  = 06
   '1275'  = 06
   '1276'  = 06
   '1277'  = 06
   '1278'  = 18
   '1279'  = 06
   '1280'  = 18
   '1281'  = 18
   '1288'  = 18
   '1289'  = 18
   '129'   = 06
   '1300'  = 01
   '1301'  = 02
   '1302'  = 02
   '1303'  = 05
   '1304'  = 04
   '1305'  = 07
   '1307'  = 18
   '1308'  = 18
   '1309'  = 18
   '13100' = 12
   '13101' = 13
   '13102' = 12
   '13103' = 12
   '13109' = 12
   '1318'  = 18
   '1319'  = 18
   '1320'  = 09
   '1321'  = 09
   '1322'  = 09
   '1323'  = 09
   '1329'  = 09
   '1330'  = 09
   '1338'  = 09
   '1339'  = 09
   '1340'  = 09
   '1341'  = 09
   '1342'  = 09
   '1348'  = 09
   '1349'  = 09
   '135'   = 04
   '1360'  = 18
   '1361'  = 08
   '13621' = 18
   '13629' = 18
   '1363'  = 04
   '1364'  = 18
   '1365'  = 18
   '1368'  = 18
   '1369'  = 18
   '1370'  = 04
   '1371'  = 01
   '1372'  = 11
   '1373'  = 08
   '1374'  = 18
   '138'   = 01
   '1390'  = 01
   '1391'  = 02
   '1398'  = 18
   '1400'  = 03
   '1401'  = 03
   '1403'  = 03
   '1404'  = 03
   '1405'  = 03
   '1406'  = 03
   '1408'  = 03
   '1409'  = 03
   '1410'  = 03
   '1411'  = 03
   '1412'  = 03
   '1413'  = 03
   '1414'  = 03
   '1415'  = 03
   '1416'  = 03
   '1418'  = 03
   '1419'  = 03
   '1420'  = 03
   '1421'  = 03
   '1422'  = 03
   '1428'  = 03
   '1429'  = 03
   '1430'  = 03
   '1431'  = 03
   '1438'  = 03
   '1439'  = 03
   '1440'  = 03
   '1441'  = 03
   '1448'  = 03
   '1449'  = 03
   '1450'  = 03
   '1451'  = 03
   '1452'  = 03
   '1453'  = 03
   '1454'  = 03
   '1455'  = 03
   '1456'  = 03
   '1458'  = 03
   '1459'  = 03
   '1460'  = 03
   '1461'  = 03
   '1462'  = 03
   '1463'  = 03
   '1464'  = 03
   '1465'  = 03
   '1466'  = 03
   '1467'  = 03
   '1468'  = 03
   '1469'  = 03
   '1470'  = 03
   '1471'  = 03
   '1472'  = 03
   '1473'  = 03
   '1478'  = 03
   '1479'  = 03
   '1480'  = 03
   '1481'  = 03
   '1482'  = 03
   '1483'  = 03
   '1488'  = 03
   '1489'  = 03
   '1490'  = 03
   '1491'  = 03
   '1498'  = 03
   '1499'  = 03
   '1500'  = 06
   '1501'  = 06
   '1502'  = 06
   '1503'  = 06
   '1504'  = 06
   '1505'  = 06
   '1508'  = 06
   '1509'  = 06
   '1510'  = 06
   '1511'  = 06
   '1512'  = 06
   '1513'  = 06
   '1514'  = 06
   '1515'  = 06
   '1516'  = 06
   '1518'  = 06
   '1519'  = 06
   '1520'  = 06
   '1521'  = 06
   '1522'  = 06
   '1523'  = 06
   '1528'  = 06
   '1529'  = 06
   '1530'  = 06
   '1531'  = 06
   '1532'  = 06
   '1533'  = 06
   '1534'  = 06
   '1535'  = 06
   '1536'  = 06
   '1537'  = 06
   '1538'  = 06
   '1539'  = 06
   '1540'  = 06
   '1541'  = 06
   '1542'  = 06
   '1543'  = 06
   '1548'  = 06
   '1550'  = 07
   '1551'  = 07
   '1552'  = 07
   '1560'  = 07
   '1561'  = 07
   '1562'  = 07
   '1568'  = 07
   '1569'  = 07
   '1570'  = 07
   '1571'  = 07
   '1572'  = 07
   '1573'  = 07
   '1574'  = 07
   '1578'  = 07
   '1579'  = 07
   '1580'  = 17
   '1588'  = 06
   '1589'  = 06
   '1590'  = 06
   '1591'  = 17
   '1598'  = 06
   '1599'  = 06
   '1600'  = 03
   '1601'  = 03
   '1602'  = 03
   '1603'  = 03
   '1604'  = 03
   '1605'  = 03
   '1608'  = 03
   '1609'  = 03
   '1610'  = 03
   '1611'  = 03
   '1612'  = 03
   '1613'  = 03
   '1618'  = 03
   '1619'  = 03
   '1620'  = 04
   '1622'  = 04
   '1623'  = 04
   '1624'  = 04
   '1625'  = 04
   '1628'  = 04
   '1629'  = 04
   '1630'  = 04
   '1631'  = 04
   '1638'  = 04
   '1639'  = 04
   '1640'  = 17
   '1641'  = 05
   '1642'  = 04
   '1643'  = 04
   '1648'  = 04
   '1649'  = 04
   '1650'  = 03
   '1658'  = 04
   '1659'  = 04
   '1700'  = 08
   '1701'  = 08
   '1702'  = 08
   '1703'  = 08
   '1704'  = 08
   '1705'  = 08
   '1706'  = 08
   '1707'  = 08
   '1708'  = 08
   '1709'  = 08
   '1710'  = 08
   '1712'  = 08
   '1713'  = 08
   '1714'  = 08
   '1715'  = 08
   '1716'  = 08
   '1717'  = 08
   '1718'  = 08
   '1719'  = 08
   '1720'  = 09
   '1721'  = 02
   '1722'  = 09
   '1723'  = 09
   '1724'  = 09
   '1725'  = 09
   '1726'  = 09
   '1727'  = 09
   '1728'  = 09
   '1729'  = 09
   '17300' = 09
   '17301' = 09
   '17302' = 09
   '17309' = 09
   '17310' = 02
   '17311' = 02
   '17312' = 02
   '17319' = 02
   '17320' = 09
   '17321' = 09
   '17322' = 09
   '17329' = 09
   '17330' = 09
   '17331' = 09
   '17332' = 09
   '17339' = 09
   '17340' = 09
   '17341' = 09
   '17342' = 09
   '17349' = 09
   '17350' = 09
   '17351' = 09
   '17352' = 09
   '17359' = 09
   '17360' = 09
   '17361' = 09
   '17362' = 09
   '17369' = 09
   '17370' = 09
   '17371' = 09
   '17372' = 09
   '17379' = 09
   '17380' = 09
   '17381' = 09
   '17382' = 09
   '17389' = 09
   '17390' = 09
   '17391' = 09
   '17392' = 09
   '17399' = 09
   '1740'  = 09
   '1741'  = 09
   '1742'  = 09
   '1743'  = 09
   '1744'  = 09
   '1745'  = 09
   '1746'  = 09
   '1748'  = 09
   '1749'  = 09
   '1750'  = 09
   '1759'  = 09
   '1760'  = 09
   '1761'  = 09
   '1762'  = 03
   '1763'  = 06
   '1764'  = 04
   '1765'  = 17
   '1768'  = 09
   '1769'  = 09
   '179'   = 13
   '1800'  = 13
   '1801'  = 13
   '1808'  = 13
   '1809'  = 13
   '181'   = 13
   '1820'  = 13
   '1821'  = 13
   '1828'  = 13
   '1830'  = 13
   '1832'  = 13
   '1833'  = 13
   '1834'  = 13
   '1835'  = 13
   '1838'  = 13
   '1839'  = 13
   '1840'  = 13
   '1841'  = 13
   '1842'  = 13
   '1843'  = 13
   '1844'  = 13
   '1848'  = 13
   '1849'  = 13
   '185'   = 12
   '1860'  = 12
   '1869'  = 12
   '1871'  = 12
   '1872'  = 12
   '1873'  = 12
   '1874'  = 12
   '1875'  = 12
   '1876'  = 12
   '1877'  = 12
   '1878'  = 12
   '1879'  = 12
   '1880'  = 11
   '1881'  = 11
   '1882'  = 11
   '1883'  = 11
   '1884'  = 11
   '1885'  = 11
   '1886'  = 11
   '1887'  = 11
   '1888'  = 11
   '1889'  = 11
   '1890'  = 11
   '1891'  = 11
   '1892'  = 11
   '1893'  = 11
   '1894'  = 11
   '1898'  = 11
   '1899'  = 11
   '1900'  = 02
   '1901'  = 02
   '1902'  = 02
   '1903'  = 02
   '1904'  = 02
   '1905'  = 02
   '1906'  = 02
   '1907'  = 02
   '1908'  = 02
   '1909'  = 02
   '1910'  = 01
   '1911'  = 01
   '1912'  = 01
   '1913'  = 01
   '1914'  = 01
   '1915'  = 01
   '1916'  = 01
   '1917'  = 01
   '1918'  = 01
   '1919'  = 01
   '1920'  = 01
   '1921'  = 01
   '1922'  = 01
   '1923'  = 01
   '1928'  = 01
   '1929'  = 01
   '193'   = 10
   '1940'  = 10
   '1941'  = 10
   '1943'  = 10
   '1944'  = 01
   '1945'  = 01
   '1946'  = 01
   '1948'  = 10
   '1949'  = 10
   '1950'  = 03
   '1951'  = 04
   '1952'  = 06
   '1953'  = 12
   '1954'  = 17
   '1955'  = 17
   '1958'  = 17
   '1960'  = 17
   '1961'  = 17
   '1962'  = 17
   '1963'  = 17
   '1965'  = 17
   '1966'  = 17
   '1968'  = 17
   '1969'  = 17
   '1970'  = 04
   '1971'  = 04
   '1972'  = 04
   '1973'  = 04
   '1974'  = 06
   '1975'  = 06
   '1976'  = 06
   '1977'  = 07
   '1978'  = 06
   '1980'  = 11
   '1981'  = 11
   '1982'  = 09
   '1983'  = 01
   '1984'  = 01
   '1985'  = 08
   '1986'  = 13
   '1987'  = 10
   '19881' = 09
   '19882' = 12
   '19889' = 17
   '1990'  = 17
   '1991'  = 17
   '1992'  = 17
   '20000' = 17
   '20001' = 17
   '20002' = 17
   '20003' = 17
   '20004' = 17
   '20005' = 17
   '20006' = 17
   '20007' = 17
   '20008' = 17
   '20010' = 17
   '20011' = 17
   '20012' = 17
   '20013' = 17
   '20014' = 17
   '20015' = 17
   '20016' = 17
   '20017' = 17
   '20018' = 17
   '20020' = 17
   '20021' = 17
   '20022' = 17
   '20023' = 17
   '20024' = 17
   '20025' = 17
   '20026' = 17
   '20027' = 17
   '20028' = 17
   '20030' = 17
   '20031' = 17
   '20032' = 17
   '20033' = 17
   '20034' = 17
   '20035' = 17
   '20036' = 17
   '20037' = 17
   '20038' = 17
   '20040' = 17
   '20041' = 17
   '20042' = 17
   '20043' = 17
   '20044' = 17
   '20045' = 17
   '20046' = 17
   '20047' = 17
   '20048' = 17
   '20050' = 17
   '20051' = 17
   '20052' = 17
   '20053' = 17
   '20054' = 17
   '20055' = 17
   '20056' = 17
   '20057' = 17
   '20058' = 17
   '20060' = 17
   '20061' = 17
   '20062' = 17
   '20063' = 17
   '20064' = 17
   '20065' = 17
   '20066' = 17
   '20067' = 17
   '20068' = 17
   '20070' = 17
   '20071' = 17
   '20072' = 17
   '20073' = 17
   '20074' = 17
   '20075' = 17
   '20076' = 17
   '20077' = 17
   '20078' = 17
   '20080' = 17
   '20081' = 17
   '20082' = 17
   '20083' = 17
   '20084' = 17
   '20085' = 17
   '20086' = 17
   '20087' = 17
   '20088' = 17
   '20100' = 17
   '20101' = 17
   '20102' = 17
   '20103' = 17
   '20104' = 17
   '20105' = 17
   '20106' = 17
   '20107' = 17
   '20108' = 17
   '20110' = 17
   '20111' = 17
   '20112' = 17
   '20113' = 17
   '20114' = 17
   '20115' = 17
   '20116' = 17
   '20117' = 17
   '20118' = 17
   '20120' = 17
   '20121' = 17
   '20122' = 17
   '20123' = 17
   '20124' = 17
   '20125' = 17
   '20126' = 17
   '20127' = 17
   '20128' = 17
   '20140' = 17
   '20141' = 17
   '20142' = 17
   '20143' = 17
   '20144' = 17
   '20145' = 17
   '20146' = 17
   '20147' = 17
   '20148' = 17
   '20150' = 17
   '20151' = 17
   '20152' = 17
   '20153' = 17
   '20154' = 17
   '20155' = 17
   '20156' = 17
   '20157' = 17
   '20158' = 17
   '20160' = 17
   '20161' = 17
   '20162' = 17
   '20163' = 17
   '20164' = 17
   '20165' = 17
   '20166' = 17
   '20167' = 17
   '20168' = 17
   '20170' = 17
   '20171' = 17
   '20172' = 17
   '20173' = 17
   '20174' = 17
   '20175' = 17
   '20176' = 17
   '20177' = 17
   '20178' = 17
   '20190' = 17
   '20191' = 17
   '20192' = 17
   '20193' = 17
   '20194' = 17
   '20195' = 17
   '20196' = 17
   '20197' = 17
   '20198' = 17
   '20200' = 17
   '20201' = 17
   '20202' = 17
   '20203' = 17
   '20204' = 17
   '20205' = 17
   '20206' = 17
   '20207' = 17
   '20208' = 17
   '20210' = 17
   '20211' = 17
   '20212' = 17
   '20213' = 17
   '20214' = 17
   '20215' = 17
   '20216' = 17
   '20217' = 17
   '20218' = 17
   '20220' = 17
   '20221' = 17
   '20222' = 17
   '20223' = 17
   '20224' = 17
   '20225' = 17
   '20226' = 17
   '20227' = 17
   '20228' = 17
   '20230' = 17
   '20231' = 17
   '20232' = 17
   '20233' = 17
   '20234' = 17
   '20235' = 17
   '20236' = 17
   '20237' = 17
   '20238' = 17
   '20240' = 17
   '20241' = 17
   '20242' = 17
   '20243' = 17
   '20244' = 17
   '20245' = 17
   '20246' = 17
   '20247' = 17
   '20248' = 17
   '20250' = 17
   '20251' = 17
   '20252' = 17
   '20253' = 17
   '20254' = 17
   '20255' = 17
   '20256' = 17
   '20257' = 17
   '20258' = 17
   '20260' = 17
   '20261' = 17
   '20262' = 17
   '20263' = 17
   '20264' = 17
   '20265' = 17
   '20266' = 17
   '20267' = 17
   '20268' = 17
   '20270' = 17
   '20271' = 17
   '20272' = 17
   '20273' = 17
   '20274' = 17
   '20275' = 17
   '20276' = 17
   '20277' = 17
   '20278' = 17
   '20280' = 17
   '20281' = 17
   '20282' = 17
   '20283' = 17
   '20284' = 17
   '20285' = 17
   '20286' = 17
   '20287' = 17
   '20288' = 17
   '20290' = 17
   '20291' = 17
   '20292' = 17
   '20293' = 17
   '20294' = 17
   '20295' = 17
   '20296' = 17
   '20297' = 17
   '20298' = 17
   '20300' = 17
   '20301' = 17
   '20302' = 17
   '20310' = 17
   '20311' = 17
   '20312' = 17
   '20380' = 17
   '20381' = 17
   '20382' = 17
   '20400' = 17
   '20401' = 17
   '20402' = 17
   '20410' = 17
   '20411' = 17
   '20412' = 17
   '20420' = 17
   '20421' = 17
   '20422' = 17
   '20480' = 17
   '20481' = 17
   '20482' = 17
   '20490' = 17
   '20491' = 17
   '20492' = 17
   '20500' = 17
   '20501' = 17
   '20502' = 17
   '20510' = 17
   '20511' = 17
   '20512' = 17
   '20520' = 17
   '20521' = 17
   '20522' = 17
   '20530' = 17
   '20531' = 17
   '20532' = 17
   '20580' = 17
   '20581' = 17
   '20582' = 17
   '20590' = 17
   '20591' = 17
   '20592' = 17
   '20600' = 17
   '20601' = 17
   '20602' = 17
   '20610' = 17
   '20611' = 17
   '20612' = 17
   '20620' = 17
   '20621' = 17
   '20622' = 17
   '20680' = 17
   '20681' = 17
   '20682' = 17
   '20690' = 17
   '20691' = 17
   '20692' = 17
   '20700' = 17
   '20701' = 17
   '20702' = 17
   '20710' = 17
   '20711' = 17
   '20712' = 17
   '20720' = 17
   '20721' = 17
   '20722' = 17
   '20780' = 17
   '20781' = 17
   '20782' = 17
   '20800' = 17
   '20801' = 17
   '20802' = 17
   '20810' = 17
   '20811' = 17
   '20812' = 17
   '20820' = 17
   '20821' = 17
   '20822' = 17
   '20880' = 17
   '20881' = 17
   '20882' = 17
   '20890' = 17
   '20891' = 17
   '20892' = 17
   '20900' = 06
   '20901' = 06
   '20902' = 06
   '20903' = 06
   '20910' = 06
   '20911' = 06
   '20912' = 06
   '20913' = 06
   '20914' = 06
   '20915' = 06
   '20916' = 06
   '20917' = 06
   '20920' = 17
   '20921' = 04
   '20922' = 17
   '20923' = 06
   '20924' = 11
   '20925' = 06
   '20926' = 06
   '20927' = 06
   '20929' = 17
   '20930' = 17
   '20931' = 09
   '20932' = 09
   '20933' = 09
   '20934' = 09
   '20935' = 09
   '20936' = 09
   '20940' = 06
   '20941' = 06
   '20942' = 06
   '20943' = 06
   '20950' = 06
   '20951' = 06
   '20952' = 06
   '20953' = 06
   '20954' = 06
   '20955' = 06
   '20956' = 06
   '20957' = 06
   '20960' = 17
   '20961' = 04
   '20962' = 16
   '20963' = 06
   '20964' = 11
   '20965' = 06
   '20966' = 06
   '20967' = 06
   '20969' = 17
   '20970' = 17
   '20971' = 17
   '20972' = 07
   '20973' = 08
   '20974' = 06
   '20975' = 17
   '20979' = 17
   '2100'  = 03
   '2101'  = 03
   '2102'  = 03
   '2103'  = 03
   '2104'  = 03
   '2105'  = 03
   '2106'  = 03
   '2107'  = 03
   '2108'  = 03
   '2109'  = 03
   '2110'  = 06
   '2111'  = 06
   '2112'  = 06
   '2113'  = 06
   '2114'  = 06
   '2115'  = 07
   '2116'  = 07
   '2117'  = 10
   '2118'  = 06
   '2119'  = 06
   '2120'  = 03
   '2121'  = 03
   '2122'  = 04
   '2123'  = 04
   '2124'  = 04
   '2125'  = 04
   '2126'  = 16
   '2127'  = 05
   '2128'  = 04
   '2129'  = 04
   '2130'  = 08
   '2131'  = 03
   '2132'  = 08
   '2133'  = 04
   '2134'  = 08
   '2135'  = 08
   '2136'  = 08
   '2137'  = 08
   '2138'  = 08
   '2139'  = 08
   '2140'  = 09
   '2141'  = 09
   '2142'  = 04
   '2143'  = 06
   '2144'  = 12
   '2148'  = 09
   '2149'  = 09
   '2150'  = 08
   '2152'  = 08
   '2153'  = 08
   '2154'  = 08
   '2155'  = 08
   '2156'  = 08
   '2157'  = 08
   '2158'  = 08
   '2159'  = 08
   '2160'  = 09
   '2161'  = 02
   '2162'  = 09
   '2163'  = 09
   '2164'  = 09
   '2165'  = 09
   '2166'  = 09
   '2167'  = 09
   '2168'  = 09
   '2169'  = 09
   '217'   = 09
   '2180'  = 13
   '2181'  = 13
   '2182'  = 13
   '2189'  = 13
   '2190'  = 13
   '2191'  = 13
   '2198'  = 13
   '2199'  = 13
   '220'   = 13
   '2210'  = 13
   '2211'  = 13
   '2212'  = 13
   '2218'  = 13
   '2219'  = 13
   '2220'  = 12
   '2221'  = 12
   '2222'  = 12
   '2223'  = 12
   '2224'  = 12
   '2228'  = 12
   '2229'  = 12
   '2230'  = 11
   '2231'  = 11
   '2232'  = 11
   '2233'  = 11
   '22381' = 11
   '22389' = 11
   '2239'  = 11
   '2240'  = 02
   '2241'  = 02
   '2242'  = 02
   '2243'  = 02
   '2244'  = 02
   '2245'  = 02
   '2246'  = 02
   '2247'  = 02
   '2248'  = 02
   '2249'  = 02
   '2250'  = 01
   '2251'  = 01
   '2252'  = 01
   '2253'  = 01
   '2254'  = 01
   '2258'  = 01
   '2259'  = 01
   '226'   = 10
   '2270'  = 10
   '2271'  = 10
   '2273'  = 10
   '2274'  = 01
   '2275'  = 01
   '2276'  = 01
   '2278'  = 10
   '2279'  = 10
   '22800' = 05
   '22801' = 09
   '22802' = 01
   '22803' = 02
   '22804' = 06
   '22809' = 05
   '2281'  = 16
   '2290'  = 16
   '2298'  = 17
   '2299'  = 17
   '2300'  = 03
   '2301'  = 06
   '2302'  = 06
   '2303'  = 06
   '2304'  = 06
   '2305'  = 06
   '2306'  = 06
   '2307'  = 06
   '2308'  = 07
   '2309'  = 06
   '2310'  = 03
   '2311'  = 04
   '2312'  = 04
   '2318'  = 04
   '2319'  = 04
   '2320'  = 09
   '2321'  = 02
   '2322'  = 09
   '2323'  = 09
   '2324'  = 09
   '2325'  = 09
   '2326'  = 09
   '2327'  = 09
   '2328'  = 09
   '2329'  = 09
   '2330'  = 09
   '2331'  = 13
   '2332'  = 13
   '23330' = 13
   '23331' = 13
   '23332' = 13
   '23339' = 13
   '2334'  = 12
   '2335'  = 12
   '2336'  = 12
   '2337'  = 11
   '2339'  = 11
   '2340'  = 02
   '2348'  = 17
   '2349'  = 17
   '2350'  = 03
   '2351'  = 03
   '2352'  = 06
   '2353'  = 07
   '2354'  = 06
   '2355'  = 06
   '2356'  = 03
   '2357'  = 04
   '2358'  = 04
   '2359'  = 04
   '2360'  = 13
   '2361'  = 13
   '2362'  = 13
   '2363'  = 13
   '2364'  = 12
   '2365'  = 12
   '2366'  = 12
   '2367'  = 11
   '23690' = 11
   '23691' = 11
   '23699' = 11
   '2370'  = 10
   '2371'  = 01
   '2372'  = 10
   '2373'  = 01
   '2374'  = 10
   '2375'  = 01
   '2376'  = 01
   '23770' = 01
   '23771' = 01
   '23772' = 01
   '23773' = 01
   '23779' = 01
   '2379'  = 01
   '2380'  = 08
   '2381'  = 08
   '2382'  = 09
   '2383'  = 09
   '2384'  = 17
   '2385'  = 17
   '2386'  = 17
   '23871' = 16
   '23872' = 16
   '23873' = 16
   '23874' = 16
   '23875' = 16
   '23876' = 17
   '23877' = 21
   '23879' = 17
   '2388'  = 17
   '2389'  = 17
   '2390'  = 06
   '2391'  = 04
   '2392'  = 08
   '2393'  = 09
   '2394'  = 11
   '2395'  = 11
   '2396'  = 01
   '2397'  = 10
   '23981' = 17
   '23989' = 17
   '2399'  = 17
   '2400'  = 10
   '2409'  = 10
   '2410'  = 10
   '2411'  = 10
   '2419'  = 10
   '24200' = 10
   '24201' = 10
   '24210' = 10
   '24211' = 10
   '24220' = 10
   '24221' = 10
   '24230' = 10
   '24231' = 10
   '24240' = 10
   '24241' = 10
   '24280' = 10
   '24281' = 10
   '24290' = 10
   '24291' = 10
   '243'   = 10
   '2440'  = 10
   '2441'  = 10
   '2442'  = 10
   '2443'  = 10
   '2448'  = 10
   '2449'  = 10
   '2450'  = 10
   '2451'  = 10
   '2452'  = 10
   '2453'  = 10
   '2454'  = 10
   '2458'  = 10
   '2459'  = 10
   '2460'  = 10
   '2461'  = 10
   '2462'  = 10
   '2463'  = 10
   '2468'  = 10
   '2469'  = 10
   '24900' = 10
   '24901' = 10
   '24910' = 10
   '24911' = 10
   '24920' = 10
   '24921' = 10
   '24930' = 10
   '24931' = 10
   '24940' = 11
   '24941' = 11
   '24950' = 02
   '24951' = 02
   '24960' = 01
   '24961' = 01
   '24970' = 05
   '24971' = 05
   '24980' = 10
   '24981' = 10
   '24990' = 10
   '24991' = 10
   '25000' = 10
   '25001' = 10
   '25002' = 10
   '25003' = 10
   '25010' = 10
   '25011' = 10
   '25012' = 10
   '25013' = 10
   '25020' = 10
   '25021' = 10
   '25022' = 10
   '25023' = 10
   '25030' = 10
   '25031' = 10
   '25032' = 10
   '25033' = 10
   '25040' = 11
   '25041' = 11
   '25042' = 11
   '25043' = 11
   '25050' = 02
   '25051' = 02
   '25052' = 02
   '25053' = 02
   '25060' = 01
   '25061' = 01
   '25062' = 01
   '25063' = 01
   '25070' = 05
   '25071' = 05
   '25072' = 05
   '25073' = 05
   '25080' = 10
   '25081' = 10
   '25082' = 10
   '25083' = 10
   '25090' = 10
   '25091' = 10
   '25092' = 10
   '25093' = 10
   '2510'  = 10
   '2511'  = 10
   '2512'  = 10
   '2513'  = 10
   '2514'  = 10
   '2515'  = 06
   '2518'  = 10
   '2519'  = 10
   '25200' = 10
   '25201' = 10
   '25202' = 10
   '25208' = 10
   '2521'  = 10
   '2528'  = 10
   '2529'  = 10
   '2530'  = 10
   '2531'  = 10
   '2532'  = 10
   '2533'  = 10
   '2534'  = 10
   '2535'  = 10
   '2536'  = 10
   '2537'  = 10
   '2538'  = 10
   '2539'  = 10
   '2540'  = 16
   '2541'  = 16
   '2548'  = 16
   '2549'  = 16
   '2550'  = 10
   '25510' = 10
   '25511' = 10
   '25512' = 10
   '25513' = 10
   '25514' = 10
   '2552'  = 10
   '2553'  = 10
   '25541' = 10
   '25542' = 10
   '2555'  = 10
   '2556'  = 10
   '2558'  = 10
   '2559'  = 10
   '2560'  = 13
   '2561'  = 13
   '2562'  = 13
   '25631' = 13
   '25639' = 13
   '2564'  = 13
   '2568'  = 13
   '2569'  = 13
   '2570'  = 10
   '2571'  = 10
   '2572'  = 10
   '2578'  = 10
   '2579'  = 10
   '25801' = 10
   '25802' = 10
   '25803' = 10
   '2581'  = 10
   '2588'  = 10
   '2589'  = 10
   '2590'  = 10
   '2591'  = 10
   '2592'  = 10
   '2593'  = 10
   '2594'  = 10
   '25950' = 10
   '25951' = 10
   '25952' = 10
   '2598'  = 10
   '2599'  = 10
   '260'   = 10
   '261'   = 10
   '262'   = 10
   '2630'  = 10
   '2631'  = 10
   '2632'  = 10
   '2638'  = 10
   '2639'  = 10
   '2640'  = 02
   '2641'  = 02
   '2642'  = 02
   '2643'  = 02
   '2644'  = 02
   '2645'  = 02
   '2646'  = 02
   '2647'  = 02
   '2648'  = 10
   '2649'  = 10
   '2650'  = 10
   '2651'  = 10
   '2652'  = 10
   '2660'  = 10
   '2661'  = 10
   '2662'  = 10
   '2669'  = 10
   '267'   = 10
   '2680'  = 08
   '2681'  = 08
   '2682'  = 08
   '2689'  = 10
   '2690'  = 10
   '2691'  = 10
   '2692'  = 10
   '2693'  = 10
   '2698'  = 10
   '2699'  = 10
   '2700'  = 10
   '2701'  = 10
   '2702'  = 10
   '2703'  = 10
   '2704'  = 10
   '2705'  = 10
   '2706'  = 10
   '2707'  = 10
   '2708'  = 10
   '2709'  = 10
   '2710'  = 10
   '2711'  = 10
   '2712'  = 06
   '2713'  = 06
   '2714'  = 10
   '2718'  = 10
   '2719'  = 10
   '2720'  = 10
   '2721'  = 10
   '2722'  = 10
   '2723'  = 10
   '2724'  = 10
   '2725'  = 10
   '2726'  = 10
   '2727'  = 10
   '2728'  = 10
   '2729'  = 10
   '2730'  = 16
   '2731'  = 16
   '2732'  = 17
   '2733'  = 17
   '2734'  = 10
   '2738'  = 17
   '2739'  = 17
   '27400' = 08
   '27401' = 08
   '27402' = 08
   '27403' = 08
   '27410' = 11
   '27411' = 11
   '27419' = 11
   '27481' = 08
   '27482' = 08
   '27489' = 08
   '2749'  = 08
   '27501' = 10
   '27502' = 10
   '27503' = 10
   '27509' = 10
   '2751'  = 10
   '2752'  = 10
   '2753'  = 10
   '27540' = 10
   '27541' = 10
   '27542' = 10
   '27549' = 10
   '2755'  = 10
   '2758'  = 10
   '2759'  = 10
   '2760'  = 10
   '2761'  = 10
   '2762'  = 10
   '2763'  = 10
   '2764'  = 10
   '27650' = 10
   '27651' = 10
   '27652' = 10
   '27661' = 10
   '27669' = 10
   '2767'  = 10
   '2768'  = 10
   '2769'  = 10
   '27700' = 10
   '27701' = 15
   '27702' = 04
   '27703' = 06
   '27709' = 10
   '2771'  = 10
   '2772'  = 10
   '27730' = 08
   '27731' = 08
   '27739' = 08
   '2774'  = 07
   '2775'  = 10
   '2776'  = 10
   '2777'  = 10
   '27781' = 10
   '27782' = 10
   '27783' = 10
   '27784' = 10
   '27785' = 10
   '27786' = 10
   '27787' = 10
   '27788' = 11
   '27789' = 10
   '2779'  = 10
   '27800' = 10
   '27801' = 10
   '27802' = 10
   '27803' = 04
   '2781'  = 10
   '2782'  = 10
   '2783'  = 10
   '2784'  = 10
   '2788'  = 10
   '27900' = 16
   '27901' = 16
   '27902' = 16
   '27903' = 16
   '27904' = 16
   '27905' = 16
   '27906' = 16
   '27909' = 16
   '27910' = 16
   '27911' = 16
   '27912' = 16
   '27913' = 16
   '27919' = 16
   '2792'  = 16
   '2793'  = 16
   '27941' = 08
   '27949' = 08
   '27950' = 16
   '27951' = 16
   '27952' = 16
   '27953' = 16
   '2798'  = 16
   '2799'  = 16
   '2800'  = 16
   '2801'  = 16
   '2808'  = 16
   '2809'  = 16
   '2810'  = 16
   '2811'  = 16
   '2812'  = 16
   '2813'  = 16
   '2814'  = 16
   '2818'  = 16
   '2819'  = 16
   '2820'  = 16
   '2821'  = 16
   '2822'  = 16
   '2823'  = 16
   '28240' = 16
   '28241' = 16
   '28242' = 16
   '28243' = 16
   '28244' = 16
   '28245' = 16
   '28246' = 16
   '28247' = 16
   '28249' = 16
   '2825'  = 16
   '28260' = 16
   '28261' = 16
   '28262' = 16
   '28263' = 16
   '28264' = 16
   '28268' = 16
   '28269' = 16
   '2827'  = 16
   '2828'  = 16
   '2829'  = 16
   '2830'  = 16
   '28310' = 16
   '28311' = 16
   '28319' = 16
   '2832'  = 16
   '2839'  = 16
   '28401' = 16
   '28409' = 16
   '28411' = 16
   '28412' = 16
   '28419' = 16
   '2842'  = 17
   '28481' = 16
   '28489' = 16
   '2849'  = 16
   '2850'  = 16
   '2851'  = 16
   '28521' = 16
   '28522' = 16
   '28529' = 16
   '2853'  = 16
   '2858'  = 16
   '2859'  = 16
   '2860'  = 16
   '2861'  = 16
   '2862'  = 16
   '2863'  = 16
   '2864'  = 16
   '28652' = 16
   '28653' = 16
   '28659' = 16
   '2866'  = 16
   '2867'  = 16
   '2869'  = 16
   '2870'  = 16
   '2871'  = 16
   '2872'  = 16
   '28730' = 16
   '28731' = 16
   '28732' = 16
   '28733' = 16
   '28739' = 16
   '28741' = 16
   '28749' = 16
   '2875'  = 16
   '2878'  = 16
   '2879'  = 16
   '28800' = 16
   '28801' = 16
   '28802' = 16
   '28803' = 16
   '28804' = 16
   '28809' = 16
   '2881'  = 16
   '2882'  = 16
   '2883'  = 16
   '2884'  = 16
   '28850' = 16
   '28851' = 16
   '28859' = 16
   '28860' = 16
   '28861' = 16
   '28862' = 16
   '28863' = 16
   '28864' = 16
   '28865' = 16
   '28866' = 16
   '28869' = 16
   '2888'  = 16
   '2889'  = 16
   '2890'  = 16
   '2891'  = 16
   '2892'  = 06
   '2893'  = 16
   '2894'  = 16
   '28950' = 16
   '28951' = 16
   '28952' = 16
   '28953' = 16
   '28959' = 16
   '2896'  = 16
   '2897'  = 16
   '28981' = 16
   '28982' = 16
   '28983' = 17
   '28984' = 16
   '28989' = 16
   '2899'  = 16
   '2900'  = 19
   '29010' = 19
   '29011' = 19
   '29012' = 19
   '29013' = 19
   '29020' = 19
   '29021' = 19
   '2903'  = 19
   '29040' = 19
   '29041' = 19
   '29042' = 19
   '29043' = 19
   '2908'  = 19
   '2909'  = 19
   '2910'  = 20
   '2911'  = 20
   '2912'  = 20
   '2913'  = 20
   '2914'  = 20
   '2915'  = 20
   '29181' = 20
   '29182' = 20
   '29189' = 20
   '2919'  = 20
   '2920'  = 20
   '29211' = 20
   '29212' = 20
   '2922'  = 20
   '29281' = 20
   '29282' = 20
   '29283' = 20
   '29284' = 20
   '29285' = 20
   '29289' = 20
   '2929'  = 20
   '2930'  = 19
   '2931'  = 19
   '29381' = 19
   '29382' = 19
   '29383' = 19
   '29384' = 19
   '29389' = 19
   '2939'  = 19
   '2940'  = 19
   '29410' = 19
   '29411' = 19
   '29420' = 19
   '29421' = 19
   '2948'  = 19
   '2949'  = 19
   '29500' = 19
   '29501' = 19
   '29502' = 19
   '29503' = 19
   '29504' = 19
   '29505' = 19
   '29510' = 19
   '29511' = 19
   '29512' = 19
   '29513' = 19
   '29514' = 19
   '29515' = 19
   '29520' = 19
   '29521' = 19
   '29522' = 19
   '29523' = 19
   '29524' = 19
   '29525' = 19
   '29530' = 19
   '29531' = 19
   '29532' = 19
   '29533' = 19
   '29534' = 19
   '29535' = 19
   '29540' = 19
   '29541' = 19
   '29542' = 19
   '29543' = 19
   '29544' = 19
   '29545' = 19
   '29550' = 19
   '29551' = 19
   '29552' = 19
   '29553' = 19
   '29554' = 19
   '29555' = 19
   '29560' = 19
   '29561' = 19
   '29562' = 19
   '29563' = 19
   '29564' = 19
   '29565' = 19
   '29570' = 19
   '29571' = 19
   '29572' = 19
   '29573' = 19
   '29574' = 19
   '29575' = 19
   '29580' = 19
   '29581' = 19
   '29582' = 19
   '29583' = 19
   '29584' = 19
   '29585' = 19
   '29590' = 19
   '29591' = 19
   '29592' = 19
   '29593' = 19
   '29594' = 19
   '29595' = 19
   '29600' = 19
   '29601' = 19
   '29602' = 19
   '29603' = 19
   '29604' = 19
   '29605' = 19
   '29606' = 19
   '29610' = 19
   '29611' = 19
   '29612' = 19
   '29613' = 19
   '29614' = 19
   '29615' = 19
   '29616' = 19
   '29620' = 19
   '29621' = 19
   '29622' = 19
   '29623' = 19
   '29624' = 19
   '29625' = 19
   '29626' = 19
   '29630' = 19
   '29631' = 19
   '29632' = 19
   '29633' = 19
   '29634' = 19
   '29635' = 19
   '29636' = 19
   '29640' = 19
   '29641' = 19
   '29642' = 19
   '29643' = 19
   '29644' = 19
   '29645' = 19
   '29646' = 19
   '29650' = 19
   '29651' = 19
   '29652' = 19
   '29653' = 19
   '29654' = 19
   '29655' = 19
   '29656' = 19
   '29660' = 19
   '29661' = 19
   '29662' = 19
   '29663' = 19
   '29664' = 19
   '29665' = 19
   '29666' = 19
   '2967'  = 19
   '29680' = 19
   '29681' = 19
   '29682' = 19
   '29689' = 19
   '29690' = 19
   '29699' = 19
   '2970'  = 19
   '2971'  = 19
   '2972'  = 19
   '2973'  = 19
   '2978'  = 19
   '2979'  = 19
   '2980'  = 19
   '2981'  = 19
   '2982'  = 19
   '2983'  = 19
   '2984'  = 19
   '2988'  = 19
   '2989'  = 19
   '29900' = 19
   '29901' = 19
   '29910' = 19
   '29911' = 19
   '29980' = 19
   '29981' = 19
   '29990' = 19
   '29991' = 19
   '30000' = 19
   '30001' = 19
   '30002' = 19
   '30009' = 19
   '30010' = 19
   '30011' = 19
   '30012' = 19
   '30013' = 19
   '30014' = 19
   '30015' = 19
   '30016' = 19
   '30019' = 19
   '30020' = 19
   '30021' = 19
   '30022' = 19
   '30023' = 19
   '30029' = 19
   '3003'  = 19
   '3004'  = 19
   '3005'  = 19
   '3006'  = 19
   '3007'  = 19
   '30081' = 19
   '30082' = 19
   '30089' = 19
   '3009'  = 19
   '3010'  = 19
   '30110' = 19
   '30111' = 19
   '30112' = 19
   '30113' = 19
   '30120' = 19
   '30121' = 19
   '30122' = 19
   '3013'  = 19
   '3014'  = 19
   '30150' = 19
   '30151' = 19
   '30159' = 19
   '3016'  = 19
   '3017'  = 19
   '30181' = 19
   '30182' = 19
   '30183' = 19
   '30184' = 19
   '30189' = 19
   '3019'  = 19
   '3020'  = 19
   '3021'  = 19
   '3022'  = 19
   '3023'  = 19
   '3024'  = 19
   '30250' = 19
   '30251' = 19
   '30252' = 19
   '30253' = 19
   '3026'  = 19
   '30270' = 19
   '30271' = 19
   '30272' = 19
   '30273' = 19
   '30274' = 19
   '30275' = 19
   '30276' = 19
   '30279' = 19
   '30281' = 19
   '30282' = 19
   '30283' = 19
   '30284' = 19
   '30285' = 19
   '30289' = 19
   '3029'  = 19
   '30300' = 20
   '30301' = 20
   '30302' = 20
   '30303' = 20
   '30390' = 20
   '30391' = 20
   '30392' = 20
   '30393' = 20
   '30400' = 20
   '30401' = 20
   '30402' = 20
   '30403' = 20
   '30410' = 20
   '30411' = 20
   '30412' = 20
   '30413' = 20
   '30420' = 20
   '30421' = 20
   '30422' = 20
   '30423' = 20
   '30430' = 20
   '30431' = 20
   '30432' = 20
   '30433' = 20
   '30440' = 20
   '30441' = 20
   '30442' = 20
   '30443' = 20
   '30450' = 20
   '30451' = 20
   '30452' = 20
   '30453' = 20
   '30460' = 20
   '30461' = 20
   '30462' = 20
   '30463' = 20
   '30470' = 20
   '30471' = 20
   '30472' = 20
   '30473' = 20
   '30480' = 20
   '30481' = 20
   '30482' = 20
   '30483' = 20
   '30490' = 20
   '30491' = 20
   '30492' = 20
   '30493' = 20
   '30500' = 20
   '30501' = 20
   '30502' = 20
   '30503' = 20
   '3051'  = 23
   '30520' = 20
   '30521' = 20
   '30522' = 20
   '30523' = 20
   '30530' = 20
   '30531' = 20
   '30532' = 20
   '30533' = 20
   '30540' = 20
   '30541' = 20
   '30542' = 20
   '30543' = 20
   '30550' = 20
   '30551' = 20
   '30552' = 20
   '30553' = 20
   '30560' = 20
   '30561' = 20
   '30562' = 20
   '30563' = 20
   '30570' = 20
   '30571' = 20
   '30572' = 20
   '30573' = 20
   '30580' = 20
   '30581' = 20
   '30582' = 20
   '30583' = 20
   '30590' = 20
   '30591' = 20
   '30592' = 20
   '30593' = 20
   '3060'  = 08
   '3061'  = 04
   '3062'  = 05
   '3063'  = 09
   '3064'  = 06
   '30650' = 11
   '30651' = 13
   '30652' = 13
   '30653' = 11
   '30659' = 11
   '3066'  = 10
   '3067'  = 19
   '3068'  = 19
   '3069'  = 19
   '3070'  = 19
   '3071'  = 19
   '30720' = 01
   '30721' = 01
   '30722' = 01
   '30723' = 01
   '3073'  = 19
   '30740' = 19
   '30741' = 19
   '30742' = 19
   '30743' = 19
   '30744' = 19
   '30745' = 19
   '30746' = 19
   '30747' = 19
   '30748' = 19
   '30749' = 19
   '30750' = 19
   '30751' = 19
   '30752' = 19
   '30753' = 19
   '30754' = 19
   '30759' = 19
   '3076'  = 19
   '3077'  = 19
   '30780' = 19
   '30781' = 01
   '30789' = 19
   '3079'  = 19
   '3080'  = 19
   '3081'  = 19
   '3082'  = 19
   '3083'  = 19
   '3084'  = 19
   '3089'  = 19
   '3090'  = 19
   '3091'  = 19
   '30921' = 19
   '30922' = 19
   '30923' = 19
   '30924' = 19
   '30928' = 19
   '30929' = 19
   '3093'  = 19
   '3094'  = 19
   '30981' = 19
   '30982' = 19
   '30983' = 19
   '30989' = 19
   '3099'  = 19
   '3100'  = 19
   '3101'  = 19
   '3102'  = 01
   '31081' = 01
   '31089' = 01
   '3109'  = 19
   '311'   = 19
   '31200' = 19
   '31201' = 19
   '31202' = 19
   '31203' = 19
   '31210' = 19
   '31211' = 19
   '31212' = 19
   '31213' = 19
   '31220' = 19
   '31221' = 19
   '31222' = 19
   '31223' = 19
   '31230' = 19
   '31231' = 19
   '31232' = 19
   '31233' = 19
   '31234' = 19
   '31235' = 19
   '31239' = 19
   '3124'  = 19
   '31281' = 19
   '31282' = 19
   '31289' = 19
   '3129'  = 19
   '3130'  = 19
   '3131'  = 19
   '31321' = 19
   '31322' = 19
   '31323' = 19
   '3133'  = 19
   '31381' = 19
   '31382' = 19
   '31383' = 19
   '31389' = 19
   '3139'  = 19
   '31400' = 19
   '31401' = 19
   '3141'  = 19
   '3142'  = 19
   '3148'  = 19
   '3149'  = 19
   '31500' = 19
   '31501' = 19
   '31502' = 19
   '31509' = 19
   '3151'  = 19
   '3152'  = 19
   '31531' = 19
   '31532' = 19
   '31534' = 19
   '31535' = 01
   '31539' = 19
   '3154'  = 19
   '3155'  = 19
   '3158'  = 19
   '3159'  = 19
   '316'   = 19
   '317'   = 19
   '3180'  = 19
   '3181'  = 19
   '3182'  = 19
   '319'   = 19
   '3200'  = 01
   '3201'  = 01
   '3202'  = 01
   '3203'  = 01
   '3207'  = 01
   '32081' = 01
   '32082' = 01
   '32089' = 01
   '3209'  = 01
   '3210'  = 01
   '3211'  = 01
   '3212'  = 01
   '3213'  = 01
   '3214'  = 01
   '3218'  = 01
   '3220'  = 01
   '3221'  = 01
   '3222'  = 01
   '3229'  = 01
   '32301' = 01
   '32302' = 01
   '3231'  = 01
   '3232'  = 01
   '32341' = 01
   '32342' = 01
   '32351' = 01
   '32352' = 01
   '32361' = 01
   '32362' = 01
   '32363' = 01
   '32371' = 01
   '32372' = 01
   '32381' = 01
   '32382' = 01
   '3239'  = 01
   '3240'  = 01
   '3241'  = 01
   '3249'  = 01
   '325'   = 01
   '326'   = 01
   '32700' = 19
   '32701' = 19
   '32702' = 19
   '32709' = 19
   '32710' = 19
   '32711' = 19
   '32712' = 19
   '32713' = 19
   '32714' = 19
   '32715' = 19
   '32719' = 19
   '32720' = 03
   '32721' = 01
   '32722' = 04
   '32723' = 03
   '32724' = 03
   '32725' = 01
   '32726' = 03
   '32727' = 01
   '32729' = 03
   '32730' = 01
   '32731' = 01
   '32732' = 01
   '32733' = 01
   '32734' = 01
   '32735' = 01
   '32736' = 01
   '32737' = 01
   '32739' = 01
   '32740' = 03
   '32741' = 01
   '32742' = 03
   '32743' = 01
   '32744' = 03
   '32749' = 03
   '32751' = 01
   '32752' = 01
   '32753' = 03
   '32759' = 03
   '3278'  = 03
   '3300'  = 01
   '3301'  = 01
   '3302'  = 01
   '3303'  = 01
   '3308'  = 01
   '3309'  = 01
   '3310'  = 01
   '33111' = 01
   '33119' = 01
   '3312'  = 01
   '3313'  = 01
   '3314'  = 01
   '3315'  = 01
   '3316'  = 01
   '3317'  = 01
   '33181' = 01
   '33182' = 01
   '33183' = 01
   '33189' = 01
   '3319'  = 01
   '3320'  = 01
   '3321'  = 01
   '3330'  = 01
   '3331'  = 01
   '3332'  = 01
   '3333'  = 01
   '3334'  = 01
   '3335'  = 01
   '3336'  = 01
   '33371' = 01
   '33372' = 01
   '33379' = 01
   '33381' = 02
   '33382' = 01
   '33383' = 01
   '33384' = 01
   '33385' = 01
   '33389' = 01
   '33390' = 01
   '33391' = 01
   '33392' = 01
   '33393' = 01
   '33394' = 01
   '33399' = 01
   '3340'  = 01
   '3341'  = 01
   '3342'  = 01
   '3343'  = 01
   '3344'  = 01
   '3348'  = 01
   '3349'  = 01
   '3350'  = 01
   '33510' = 01
   '33511' = 01
   '33519' = 01
   '33520' = 01
   '33521' = 01
   '33522' = 01
   '33523' = 01
   '33524' = 01
   '33529' = 01
   '3358'  = 01
   '3359'  = 01
   '3360'  = 01
   '3361'  = 01
   '3362'  = 01
   '3363'  = 01
   '3368'  = 01
   '3369'  = 01
   '33700' = 01
   '33701' = 01
   '33709' = 01
   '3371'  = 01
   '33720' = 01
   '33721' = 01
   '33722' = 01
   '33729' = 01
   '3373'  = 01
   '3379'  = 01
   '3380'  = 01
   '33811' = 23
   '33812' = 23
   '33818' = 23
   '33819' = 23
   '33821' = 01
   '33822' = 01
   '33828' = 01
   '33829' = 01
   '3383'  = 23
   '3384'  = 01
   '33900' = 01
   '33901' = 01
   '33902' = 01
   '33903' = 01
   '33904' = 01
   '33905' = 01
   '33909' = 01
   '33910' = 01
   '33911' = 01
   '33912' = 01
   '33920' = 01
   '33921' = 01
   '33922' = 01
   '3393'  = 01
   '33941' = 01
   '33942' = 01
   '33943' = 01
   '33944' = 01
   '33981' = 01
   '33982' = 01
   '33983' = 01
   '33984' = 01
   '33985' = 01
   '33989' = 01
   '340'   = 01
   '3410'  = 01
   '3411'  = 01
   '34120' = 01
   '34121' = 01
   '34122' = 01
   '3418'  = 01
   '3419'  = 01
   '34200' = 01
   '34201' = 01
   '34202' = 01
   '34210' = 01
   '34211' = 01
   '34212' = 01
   '34280' = 01
   '34281' = 01
   '34282' = 01
   '34290' = 01
   '34291' = 01
   '34292' = 01
   '3430'  = 01
   '3431'  = 01
   '3432'  = 01
   '3433'  = 01
   '3434'  = 01
   '3438'  = 01
   '3439'  = 01
   '34400' = 01
   '34401' = 01
   '34402' = 01
   '34403' = 01
   '34404' = 01
   '34409' = 01
   '3441'  = 01
   '3442'  = 01
   '34430' = 01
   '34431' = 01
   '34432' = 01
   '34440' = 01
   '34441' = 01
   '34442' = 01
   '3445'  = 01
   '34460' = 01
   '34461' = 11
   '34481' = 01
   '34489' = 01
   '3449'  = 01
   '34500' = 01
   '34501' = 01
   '34510' = 01
   '34511' = 01
   '3452'  = 01
   '3453'  = 01
   '34540' = 01
   '34541' = 01
   '34550' = 01
   '34551' = 01
   '34560' = 01
   '34561' = 01
   '34570' = 01
   '34571' = 01
   '34580' = 01
   '34581' = 01
   '34590' = 01
   '34591' = 01
   '34600' = 01
   '34601' = 01
   '34602' = 01
   '34603' = 01
   '34610' = 01
   '34611' = 01
   '34612' = 01
   '34613' = 01
   '34620' = 01
   '34621' = 01
   '34622' = 01
   '34623' = 01
   '34630' = 01
   '34631' = 01
   '34632' = 01
   '34633' = 01
   '34640' = 01
   '34641' = 01
   '34642' = 01
   '34643' = 01
   '34650' = 01
   '34651' = 01
   '34652' = 01
   '34653' = 01
   '34660' = 01
   '34661' = 01
   '34662' = 01
   '34663' = 01
   '34670' = 01
   '34671' = 01
   '34672' = 01
   '34673' = 01
   '34680' = 01
   '34681' = 01
   '34682' = 01
   '34683' = 01
   '34690' = 01
   '34691' = 01
   '34692' = 01
   '34693' = 01
   '34700' = 01
   '34701' = 01
   '34710' = 01
   '34711' = 01
   '3480'  = 01
   '3481'  = 01
   '3482'  = 01
   '34830' = 01
   '34831' = 01
   '34839' = 01
   '3484'  = 01
   '3485'  = 01
   '34881' = 01
   '34882' = 01
   '34889' = 01
   '3489'  = 01
   '3490'  = 01
   '3491'  = 01
   '3492'  = 01
   '34931' = 21
   '34939' = 21
   '34981' = 01
   '34982' = 01
   '34989' = 01
   '3499'  = 01
   '3501'  = 01
   '3502'  = 01
   '3508'  = 01
   '3509'  = 01
   '3510'  = 01
   '3511'  = 01
   '3518'  = 01
   '3519'  = 01
   '3520'  = 01
   '3521'  = 01
   '3522'  = 01
   '3523'  = 01
   '3524'  = 01
   '3525'  = 01
   '3526'  = 01
   '3529'  = 01
   '3530'  = 01
   '3531'  = 01
   '3532'  = 01
   '3533'  = 01
   '3534'  = 01
   '3535'  = 01
   '3536'  = 01
   '3538'  = 01
   '3539'  = 01
   '3540'  = 01
   '3541'  = 01
   '3542'  = 01
   '3543'  = 01
   '3544'  = 01
   '3545'  = 01
   '3548'  = 01
   '3549'  = 01
   '3550'  = 01
   '3551'  = 01
   '3552'  = 01
   '3553'  = 01
   '3554'  = 01
   '3555'  = 01
   '3556'  = 01
   '35571' = 01
   '35579' = 01
   '3558'  = 01
   '3559'  = 01
   '3560'  = 01
   '3561'  = 01
   '3562'  = 01
   '3563'  = 01
   '3564'  = 01
   '3568'  = 01
   '3569'  = 01
   '3570'  = 01
   '3571'  = 01
   '3572'  = 01
   '3573'  = 01
   '3574'  = 01
   '3575'  = 01
   '3576'  = 01
   '3577'  = 01
   '35781' = 01
   '35782' = 01
   '35789' = 01
   '3579'  = 01
   '35800' = 01
   '35801' = 01
   '3581'  = 01
   '3582'  = 01
   '35830' = 01
   '35831' = 01
   '35839' = 01
   '3588'  = 01
   '3589'  = 01
   '3590'  = 01
   '3591'  = 01
   '35921' = 01
   '35922' = 01
   '35923' = 01
   '35924' = 01
   '35929' = 01
   '3593'  = 01
   '3594'  = 01
   '3595'  = 01
   '3596'  = 01
   '35971' = 08
   '35979' = 08
   '35981' = 01
   '35989' = 01
   '3599'  = 01
   '36000' = 02
   '36001' = 02
   '36002' = 02
   '36003' = 02
   '36004' = 02
   '36011' = 02
   '36012' = 02
   '36013' = 02
   '36014' = 02
   '36019' = 02
   '36020' = 02
   '36021' = 02
   '36023' = 02
   '36024' = 02
   '36029' = 02
   '36030' = 02
   '36031' = 02
   '36032' = 02
   '36033' = 02
   '36034' = 02
   '36040' = 02
   '36041' = 02
   '36042' = 02
   '36043' = 02
   '36044' = 02
   '36050' = 02
   '36051' = 02
   '36052' = 02
   '36053' = 02
   '36054' = 02
   '36055' = 02
   '36059' = 02
   '36060' = 02
   '36061' = 02
   '36062' = 02
   '36063' = 02
   '36064' = 02
   '36065' = 02
   '36069' = 02
   '36081' = 02
   '36089' = 02
   '3609'  = 02
   '36100' = 02
   '36101' = 02
   '36102' = 02
   '36103' = 02
   '36104' = 02
   '36105' = 02
   '36106' = 02
   '36107' = 02
   '36110' = 02
   '36111' = 02
   '36112' = 02
   '36113' = 02
   '36114' = 02
   '36119' = 02
   '3612'  = 02
   '36130' = 02
   '36131' = 02
   '36132' = 02
   '36133' = 02
   '36181' = 02
   '36189' = 02
   '3619'  = 02
   '36201' = 02
   '36202' = 02
   '36203' = 02
   '36204' = 02
   '36205' = 02
   '36206' = 02
   '36207' = 02
   '36210' = 02
   '36211' = 02
   '36212' = 02
   '36213' = 02
   '36214' = 02
   '36215' = 02
   '36216' = 02
   '36217' = 02
   '36218' = 02
   '36220' = 02
   '36221' = 02
   '36222' = 02
   '36223' = 02
   '36224' = 02
   '36225' = 02
   '36226' = 02
   '36227' = 02
   '36229' = 02
   '36230' = 02
   '36231' = 02
   '36232' = 02
   '36233' = 02
   '36234' = 02
   '36235' = 02
   '36236' = 02
   '36237' = 02
   '36240' = 02
   '36241' = 02
   '36242' = 02
   '36243' = 02
   '36250' = 02
   '36251' = 02
   '36252' = 02
   '36253' = 02
   '36254' = 02
   '36255' = 02
   '36256' = 02
   '36257' = 02
   '36260' = 02
   '36261' = 02
   '36262' = 02
   '36263' = 02
   '36264' = 02
   '36265' = 02
   '36266' = 02
   '36270' = 02
   '36271' = 02
   '36272' = 02
   '36273' = 02
   '36274' = 02
   '36275' = 02
   '36276' = 02
   '36277' = 02
   '36281' = 02
   '36282' = 02
   '36283' = 02
   '36284' = 02
   '36285' = 02
   '36289' = 02
   '3629'  = 02
   '36300' = 02
   '36301' = 02
   '36303' = 02
   '36304' = 02
   '36305' = 02
   '36306' = 02
   '36307' = 02
   '36308' = 02
   '36310' = 02
   '36311' = 02
   '36312' = 02
   '36313' = 02
   '36314' = 02
   '36315' = 02
   '36320' = 02
   '36321' = 02
   '36322' = 02
   '36330' = 02
   '36331' = 02
   '36332' = 02
   '36333' = 02
   '36334' = 02
   '36335' = 02
   '36340' = 02
   '36341' = 02
   '36342' = 02
   '36343' = 02
   '36350' = 02
   '36351' = 02
   '36352' = 02
   '36353' = 02
   '36354' = 02
   '36355' = 02
   '36356' = 02
   '36357' = 02
   '36361' = 02
   '36362' = 02
   '36363' = 02
   '36370' = 02
   '36371' = 02
   '36372' = 02
   '3638'  = 02
   '3639'  = 02
   '36400' = 02
   '36401' = 02
   '36402' = 02
   '36403' = 02
   '36404' = 02
   '36405' = 02
   '36410' = 02
   '36411' = 02
   '36421' = 02
   '36422' = 02
   '36423' = 02
   '36424' = 02
   '3643'  = 02
   '36441' = 02
   '36442' = 02
   '36451' = 02
   '36452' = 02
   '36453' = 02
   '36454' = 02
   '36455' = 02
   '36456' = 02
   '36457' = 02
   '36459' = 02
   '36460' = 02
   '36461' = 02
   '36462' = 02
   '36463' = 02
   '36464' = 02
   '36470' = 02
   '36471' = 02
   '36472' = 02
   '36473' = 02
   '36474' = 02
   '36475' = 02
   '36476' = 02
   '36477' = 02
   '36481' = 02
   '36482' = 02
   '36489' = 02
   '3649'  = 02
   '36500' = 02
   '36501' = 02
   '36502' = 02
   '36503' = 02
   '36504' = 02
   '36505' = 02
   '36506' = 02
   '36510' = 02
   '36511' = 02
   '36512' = 02
   '36513' = 02
   '36514' = 02
   '36515' = 02
   '36520' = 02
   '36521' = 02
   '36522' = 02
   '36523' = 02
   '36524' = 02
   '36531' = 02
   '36532' = 02
   '36541' = 02
   '36542' = 02
   '36543' = 02
   '36544' = 02
   '36551' = 02
   '36552' = 02
   '36559' = 02
   '36560' = 02
   '36561' = 02
   '36562' = 02
   '36563' = 02
   '36564' = 02
   '36565' = 02
   '36570' = 02
   '36571' = 02
   '36572' = 02
   '36573' = 02
   '36574' = 02
   '36581' = 02
   '36582' = 02
   '36583' = 02
   '36589' = 02
   '3659'  = 02
   '36600' = 02
   '36601' = 02
   '36602' = 02
   '36603' = 02
   '36604' = 02
   '36609' = 02
   '36610' = 02
   '36611' = 02
   '36612' = 02
   '36613' = 02
   '36614' = 02
   '36615' = 02
   '36616' = 02
   '36617' = 02
   '36618' = 02
   '36619' = 02
   '36620' = 02
   '36621' = 02
   '36622' = 02
   '36623' = 02
   '36630' = 02
   '36631' = 02
   '36632' = 02
   '36633' = 02
   '36634' = 02
   '36641' = 02
   '36642' = 02
   '36643' = 02
   '36644' = 02
   '36645' = 02
   '36646' = 02
   '36650' = 02
   '36651' = 02
   '36652' = 02
   '36653' = 02
   '3668'  = 02
   '3669'  = 02
   '3670'  = 02
   '3671'  = 02
   '36720' = 02
   '36721' = 02
   '36722' = 02
   '36731' = 02
   '36732' = 02
   '3674'  = 02
   '36751' = 02
   '36752' = 02
   '36753' = 02
   '36781' = 02
   '36789' = 02
   '3679'  = 02
   '36800' = 02
   '36801' = 02
   '36802' = 02
   '36803' = 02
   '36810' = 02
   '36811' = 02
   '36812' = 02
   '36813' = 02
   '36814' = 02
   '36815' = 02
   '36816' = 02
   '3682'  = 02
   '36830' = 02
   '36831' = 02
   '36832' = 02
   '36833' = 02
   '36834' = 02
   '36840' = 02
   '36841' = 02
   '36842' = 02
   '36843' = 02
   '36844' = 02
   '36845' = 02
   '36846' = 02
   '36847' = 02
   '36851' = 02
   '36852' = 02
   '36853' = 02
   '36854' = 02
   '36855' = 02
   '36859' = 02
   '36860' = 02
   '36861' = 02
   '36862' = 02
   '36863' = 02
   '36869' = 02
   '3688'  = 02
   '3689'  = 02
   '36900' = 02
   '36901' = 02
   '36902' = 02
   '36903' = 02
   '36904' = 02
   '36905' = 02
   '36906' = 02
   '36907' = 02
   '36908' = 02
   '36910' = 02
   '36911' = 02
   '36912' = 02
   '36913' = 02
   '36914' = 02
   '36915' = 02
   '36916' = 02
   '36917' = 02
   '36918' = 02
   '36920' = 02
   '36921' = 02
   '36922' = 02
   '36923' = 02
   '36924' = 02
   '36925' = 02
   '3693'  = 02
   '3694'  = 02
   '36960' = 02
   '36961' = 02
   '36962' = 02
   '36963' = 02
   '36964' = 02
   '36965' = 02
   '36966' = 02
   '36967' = 02
   '36968' = 02
   '36969' = 02
   '36970' = 02
   '36971' = 02
   '36972' = 02
   '36973' = 02
   '36974' = 02
   '36975' = 02
   '36976' = 02
   '3698'  = 02
   '3699'  = 02
   '37000' = 02
   '37001' = 02
   '37002' = 02
   '37003' = 02
   '37004' = 02
   '37005' = 02
   '37006' = 02
   '37007' = 02
   '37020' = 02
   '37021' = 02
   '37022' = 02
   '37023' = 02
   '37024' = 02
   '37031' = 02
   '37032' = 02
   '37033' = 02
   '37034' = 02
   '37035' = 02
   '37040' = 02
   '37044' = 02
   '37049' = 02
   '37050' = 02
   '37052' = 02
   '37054' = 02
   '37055' = 02
   '37059' = 02
   '37060' = 02
   '37061' = 02
   '37062' = 02
   '37063' = 02
   '37064' = 02
   '3708'  = 02
   '3709'  = 02
   '37100' = 02
   '37101' = 02
   '37102' = 02
   '37103' = 02
   '37104' = 02
   '37105' = 02
   '37110' = 02
   '37111' = 02
   '37112' = 02
   '37113' = 02
   '37114' = 02
   '37115' = 02
   '37116' = 02
   '37120' = 02
   '37121' = 02
   '37122' = 02
   '37123' = 02
   '37124' = 02
   '37130' = 02
   '37131' = 02
   '37132' = 02
   '37133' = 02
   '37140' = 02
   '37141' = 02
   '37142' = 02
   '37143' = 02
   '37144' = 02
   '37145' = 02
   '37146' = 02
   '37148' = 02
   '37149' = 02
   '37150' = 02
   '37151' = 02
   '37152' = 02
   '37153' = 02
   '37154' = 02
   '37155' = 02
   '37156' = 02
   '37157' = 02
   '37158' = 02
   '37160' = 02
   '37161' = 02
   '37162' = 02
   '37170' = 02
   '37171' = 02
   '37172' = 02
   '37173' = 02
   '37181' = 02
   '37182' = 02
   '37189' = 02
   '3719'  = 02
   '37200' = 02
   '37201' = 02
   '37202' = 02
   '37203' = 02
   '37204' = 02
   '37205' = 02
   '37206' = 02
   '37210' = 02
   '37211' = 02
   '37212' = 02
   '37213' = 02
   '37214' = 02
   '37215' = 02
   '37220' = 02
   '37221' = 02
   '37222' = 02
   '37230' = 02
   '37231' = 02
   '37233' = 02
   '37234' = 02
   '37239' = 02
   '37240' = 02
   '37241' = 02
   '37242' = 02
   '37243' = 02
   '37244' = 02
   '37245' = 02
   '37250' = 02
   '37251' = 02
   '37252' = 02
   '37253' = 02
   '37254' = 02
   '37255' = 02
   '37256' = 02
   '37261' = 02
   '37262' = 02
   '37263' = 02
   '37264' = 02
   '37271' = 02
   '37272' = 02
   '37273' = 02
   '37274' = 02
   '37275' = 02
   '37281' = 02
   '37289' = 02
   '3729'  = 02
   '37300' = 02
   '37301' = 02
   '37302' = 02
   '37311' = 02
   '37312' = 02
   '37313' = 02
   '3732'  = 02
   '37331' = 02
   '37332' = 02
   '37333' = 02
   '37334' = 02
   '3734'  = 02
   '3735'  = 02
   '3736'  = 02
   '3738'  = 02
   '3739'  = 02
   '37400' = 02
   '37401' = 02
   '37402' = 02
   '37403' = 02
   '37404' = 02
   '37405' = 02
   '37410' = 02
   '37411' = 02
   '37412' = 02
   '37413' = 02
   '37414' = 02
   '37420' = 02
   '37421' = 02
   '37422' = 02
   '37423' = 02
   '37430' = 02
   '37431' = 02
   '37432' = 02
   '37433' = 02
   '37434' = 02
   '37441' = 02
   '37443' = 02
   '37444' = 02
   '37445' = 02
   '37446' = 02
   '37450' = 02
   '37451' = 09
   '37452' = 02
   '37453' = 02
   '37454' = 02
   '37455' = 02
   '37456' = 02
   '37481' = 02
   '37482' = 02
   '37483' = 02
   '37484' = 02
   '37485' = 02
   '37486' = 02
   '37487' = 02
   '37489' = 02
   '3749'  = 02
   '37500' = 02
   '37501' = 02
   '37502' = 02
   '37503' = 02
   '37511' = 02
   '37512' = 02
   '37513' = 02
   '37514' = 02
   '37515' = 02
   '37516' = 02
   '37520' = 02
   '37521' = 02
   '37522' = 02
   '37530' = 02
   '37531' = 02
   '37532' = 02
   '37533' = 02
   '37541' = 02
   '37542' = 02
   '37543' = 02
   '37551' = 02
   '37552' = 02
   '37553' = 02
   '37554' = 02
   '37555' = 02
   '37556' = 02
   '37557' = 02
   '37561' = 02
   '37569' = 02
   '37581' = 02
   '37589' = 02
   '3759'  = 02
   '37600' = 02
   '37601' = 02
   '37602' = 02
   '37603' = 02
   '37604' = 02
   '37610' = 02
   '37611' = 02
   '37612' = 02
   '37613' = 02
   '37621' = 02
   '37622' = 02
   '37630' = 02
   '37631' = 02
   '37632' = 02
   '37633' = 02
   '37634' = 02
   '37635' = 02
   '37636' = 02
   '37640' = 02
   '37641' = 02
   '37642' = 02
   '37643' = 02
   '37644' = 02
   '37645' = 02
   '37646' = 02
   '37647' = 02
   '37650' = 02
   '37651' = 02
   '37652' = 02
   '3766'  = 02
   '37681' = 02
   '37682' = 02
   '37689' = 02
   '3769'  = 02
   '37700' = 01
   '37701' = 01
   '37702' = 02
   '37703' = 02
   '37704' = 01
   '37710' = 02
   '37711' = 02
   '37712' = 02
   '37713' = 02
   '37714' = 02
   '37715' = 02
   '37716' = 02
   '37721' = 02
   '37722' = 02
   '37723' = 02
   '37724' = 02
   '37730' = 02
   '37731' = 02
   '37732' = 02
   '37733' = 02
   '37734' = 02
   '37739' = 02
   '37741' = 02
   '37742' = 02
   '37743' = 02
   '37749' = 02
   '37751' = 01
   '37752' = 01
   '37753' = 01
   '37754' = 01
   '37761' = 01
   '37762' = 01
   '37763' = 01
   '37771' = 01
   '37772' = 01
   '37773' = 01
   '37775' = 01
   '3779'  = 01
   '37800' = 02
   '37801' = 02
   '37802' = 02
   '37803' = 02
   '37804' = 02
   '37805' = 02
   '37806' = 02
   '37807' = 02
   '37808' = 02
   '37810' = 02
   '37811' = 02
   '37812' = 02
   '37813' = 02
   '37814' = 02
   '37815' = 02
   '37816' = 02
   '37817' = 02
   '37818' = 02
   '37820' = 02
   '37821' = 02
   '37822' = 02
   '37823' = 02
   '37824' = 02
   '37830' = 02
   '37831' = 02
   '37832' = 02
   '37833' = 02
   '37834' = 02
   '37835' = 02
   '37840' = 02
   '37841' = 02
   '37842' = 02
   '37843' = 02
   '37844' = 02
   '37845' = 02
   '37850' = 02
   '37851' = 02
   '37852' = 02
   '37853' = 02
   '37854' = 02
   '37855' = 02
   '37856' = 02
   '37860' = 02
   '37861' = 02
   '37862' = 02
   '37863' = 02
   '37871' = 02
   '37872' = 02
   '37873' = 02
   '37881' = 02
   '37882' = 02
   '37883' = 02
   '37884' = 02
   '37885' = 02
   '37886' = 01
   '37887' = 02
   '3789'  = 02
   '37900' = 02
   '37901' = 02
   '37902' = 02
   '37903' = 02
   '37904' = 02
   '37905' = 02
   '37906' = 02
   '37907' = 02
   '37909' = 02
   '37911' = 02
   '37912' = 02
   '37913' = 02
   '37914' = 02
   '37915' = 02
   '37916' = 02
   '37919' = 02
   '37921' = 02
   '37922' = 02
   '37923' = 02
   '37924' = 02
   '37925' = 02
   '37926' = 02
   '37927' = 02
   '37929' = 02
   '37931' = 02
   '37932' = 02
   '37933' = 02
   '37934' = 02
   '37939' = 02
   '37940' = 02
   '37941' = 02
   '37942' = 02
   '37943' = 02
   '37945' = 01
   '37946' = 02
   '37949' = 02
   '37950' = 02
   '37951' = 02
   '37952' = 02
   '37953' = 02
   '37954' = 02
   '37955' = 02
   '37956' = 02
   '37957' = 02
   '37958' = 02
   '37959' = 02
   '37960' = 02
   '37961' = 02
   '37962' = 02
   '37963' = 02
   '3798'  = 02
   '37990' = 02
   '37991' = 02
   '37992' = 02
   '37993' = 02
   '37999' = 02
   '38000' = 03
   '38001' = 08
   '38002' = 08
   '38003' = 08
   '38010' = 03
   '38011' = 03
   '38012' = 03
   '38013' = 03
   '38014' = 03
   '38015' = 03
   '38016' = 03
   '38021' = 03
   '38022' = 03
   '38023' = 03
   '38030' = 03
   '38031' = 03
   '38032' = 03
   '38039' = 03
   '3804'  = 03
   '38050' = 03
   '38051' = 03
   '38052' = 03
   '38053' = 03
   '38081' = 03
   '38089' = 03
   '3809'  = 03
   '38100' = 03
   '38101' = 03
   '38102' = 03
   '38103' = 03
   '38104' = 03
   '38105' = 03
   '38106' = 03
   '38110' = 03
   '38119' = 03
   '38120' = 03
   '38129' = 03
   '3813'  = 03
   '3814'  = 03
   '38150' = 03
   '38151' = 03
   '38152' = 03
   '38160' = 03
   '38161' = 03
   '38162' = 03
   '38163' = 03
   '3817'  = 03
   '38181' = 03
   '38189' = 03
   '3819'  = 03
   '38200' = 03
   '38201' = 03
   '38202' = 03
   '3821'  = 03
   '3822'  = 03
   '3823'  = 03
   '3824'  = 03
   '3829'  = 03
   '38300' = 03
   '38301' = 03
   '38302' = 03
   '3831'  = 03
   '38320' = 03
   '38321' = 03
   '38322' = 03
   '38330' = 03
   '38331' = 03
   '38332' = 03
   '38333' = 03
   '38381' = 03
   '38389' = 03
   '3839'  = 03
   '38400' = 03
   '38401' = 03
   '38409' = 03
   '3841'  = 03
   '38420' = 03
   '38421' = 03
   '38422' = 03
   '38423' = 03
   '38424' = 03
   '38425' = 03
   '38481' = 03
   '38482' = 03
   '3849'  = 03
   '38500' = 03
   '38501' = 03
   '38502' = 03
   '38503' = 03
   '38509' = 03
   '38510' = 03
   '38511' = 03
   '38512' = 03
   '38513' = 03
   '38519' = 03
   '38521' = 03
   '38522' = 03
   '38523' = 03
   '38524' = 03
   '38530' = 03
   '38531' = 03
   '38532' = 03
   '38533' = 03
   '38535' = 03
   '38582' = 03
   '38583' = 03
   '38589' = 03
   '3859'  = 03
   '38600' = 03
   '38601' = 03
   '38602' = 03
   '38603' = 03
   '38604' = 03
   '38610' = 03
   '38611' = 03
   '38612' = 03
   '38619' = 03
   '3862'  = 03
   '38630' = 03
   '38631' = 03
   '38632' = 03
   '38633' = 03
   '38634' = 03
   '38635' = 03
   '38640' = 03
   '38641' = 03
   '38642' = 03
   '38643' = 03
   '38648' = 03
   '38650' = 03
   '38651' = 03
   '38652' = 03
   '38653' = 03
   '38654' = 03
   '38655' = 03
   '38656' = 03
   '38658' = 03
   '3868'  = 03
   '3869'  = 03
   '3870'  = 03
   '3871'  = 03
   '3872'  = 03
   '3878'  = 03
   '3879'  = 03
   '38800' = 03
   '38801' = 03
   '38802' = 03
   '38810' = 03
   '38811' = 03
   '38812' = 03
   '3882'  = 03
   '38830' = 03
   '38831' = 03
   '38832' = 03
   '38840' = 03
   '38841' = 03
   '38842' = 03
   '38843' = 03
   '38844' = 03
   '38845' = 19
   '3885'  = 03
   '38860' = 03
   '38861' = 01
   '38869' = 03
   '38870' = 03
   '38871' = 03
   '38872' = 03
   '3888'  = 03
   '3889'  = 03
   '38900' = 03
   '38901' = 03
   '38902' = 03
   '38903' = 03
   '38904' = 03
   '38905' = 03
   '38906' = 03
   '38908' = 03
   '38910' = 03
   '38911' = 03
   '38912' = 03
   '38913' = 03
   '38914' = 03
   '38915' = 03
   '38916' = 03
   '38917' = 03
   '38918' = 03
   '38920' = 03
   '38921' = 03
   '38922' = 03
   '3897'  = 03
   '3898'  = 03
   '3899'  = 03
   '390'   = 08
   '3910'  = 05
   '3911'  = 05
   '3912'  = 05
   '3918'  = 05
   '3919'  = 05
   '3920'  = 05
   '3929'  = 05
   '393'   = 05
   '3940'  = 05
   '3941'  = 05
   '3942'  = 05
   '3949'  = 05
   '3950'  = 05
   '3951'  = 05
   '3952'  = 05
   '3959'  = 05
   '3960'  = 05
   '3961'  = 05
   '3962'  = 05
   '3963'  = 05
   '3968'  = 05
   '3969'  = 05
   '3970'  = 05
   '3971'  = 05
   '3979'  = 05
   '3980'  = 05
   '39890' = 05
   '39891' = 05
   '39899' = 05
   '4010'  = 05
   '4011'  = 05
   '4019'  = 05
   '40200' = 05
   '40201' = 05
   '40210' = 05
   '40211' = 05
   '40290' = 05
   '40291' = 05
   '40300' = 11
   '40301' = 11
   '40310' = 11
   '40311' = 11
   '40390' = 11
   '40391' = 11
   '40400' = 05
   '40401' = 05
   '40402' = 11
   '40403' = 05
   '40410' = 05
   '40411' = 05
   '40412' = 11
   '40413' = 05
   '40490' = 05
   '40491' = 05
   '40492' = 11
   '40493' = 05
   '40501' = 05
   '40509' = 05
   '40511' = 05
   '40519' = 05
   '40591' = 05
   '40599' = 05
   '41000' = 05
   '41001' = 05
   '41002' = 05
   '41010' = 05
   '41011' = 05
   '41012' = 05
   '41020' = 05
   '41021' = 05
   '41022' = 05
   '41030' = 05
   '41031' = 05
   '41032' = 05
   '41040' = 05
   '41041' = 05
   '41042' = 05
   '41050' = 05
   '41051' = 05
   '41052' = 05
   '41060' = 05
   '41061' = 05
   '41062' = 05
   '41070' = 05
   '41071' = 05
   '41072' = 05
   '41080' = 05
   '41081' = 05
   '41082' = 05
   '41090' = 05
   '41091' = 05
   '41092' = 05
   '4110'  = 05
   '4111'  = 05
   '41181' = 05
   '41189' = 05
   '412'   = 05
   '4130'  = 05
   '4131'  = 05
   '4139'  = 05
   '41400' = 05
   '41401' = 05
   '41402' = 05
   '41403' = 05
   '41404' = 05
   '41405' = 05
   '41406' = 05
   '41407' = 05
   '41410' = 05
   '41411' = 05
   '41412' = 05
   '41419' = 05
   '4142'  = 05
   '4143'  = 05
   '4144'  = 05
   '4148'  = 05
   '4149'  = 05
   '4150'  = 05
   '41511' = 04
   '41512' = 04
   '41513' = 04
   '41519' = 04
   '4160'  = 05
   '4161'  = 05
   '4162'  = 04
   '4168'  = 05
   '4169'  = 05
   '4170'  = 05
   '4171'  = 05
   '4178'  = 05
   '4179'  = 05
   '4200'  = 05
   '42090' = 05
   '42091' = 05
   '42099' = 05
   '4210'  = 05
   '4211'  = 05
   '4219'  = 05
   '4220'  = 05
   '42290' = 05
   '42291' = 05
   '42292' = 05
   '42293' = 05
   '42299' = 05
   '4230'  = 05
   '4231'  = 05
   '4232'  = 05
   '4233'  = 05
   '4238'  = 05
   '4239'  = 05
   '4240'  = 05
   '4241'  = 05
   '4242'  = 05
   '4243'  = 05
   '42490' = 05
   '42491' = 05
   '42499' = 05
   '4250'  = 05
   '42511' = 05
   '42518' = 05
   '4252'  = 05
   '4253'  = 05
   '4254'  = 05
   '4255'  = 05
   '4257'  = 05
   '4258'  = 05
   '4259'  = 05
   '4260'  = 05
   '42610' = 05
   '42611' = 05
   '42612' = 05
   '42613' = 05
   '4262'  = 05
   '4263'  = 05
   '4264'  = 05
   '42650' = 05
   '42651' = 05
   '42652' = 05
   '42653' = 05
   '42654' = 05
   '4266'  = 05
   '4267'  = 05
   '42681' = 05
   '42682' = 05
   '42689' = 05
   '4269'  = 05
   '4270'  = 05
   '4271'  = 05
   '4272'  = 05
   '42731' = 05
   '42732' = 05
   '42741' = 05
   '42742' = 05
   '4275'  = 05
   '42760' = 05
   '42761' = 05
   '42769' = 05
   '42781' = 05
   '42789' = 05
   '4279'  = 05
   '4280'  = 05
   '4281'  = 05
   '42820' = 05
   '42821' = 05
   '42822' = 05
   '42823' = 05
   '42830' = 05
   '42831' = 05
   '42832' = 05
   '42833' = 05
   '42840' = 05
   '42841' = 05
   '42842' = 05
   '42843' = 05
   '4289'  = 05
   '4290'  = 05
   '4291'  = 05
   '4292'  = 05
   '4293'  = 05
   '4294'  = 05
   '4295'  = 05
   '4296'  = 05
   '42971' = 05
   '42979' = 05
   '42981' = 05
   '42982' = 05
   '42983' = 05
   '42989' = 05
   '4299'  = 05
   '430'   = 01
   '431'   = 01
   '4320'  = 01
   '4321'  = 01
   '4329'  = 01
   '43300' = 01
   '43301' = 01
   '43310' = 01
   '43311' = 01
   '43320' = 01
   '43321' = 01
   '43330' = 01
   '43331' = 01
   '43380' = 01
   '43381' = 01
   '43390' = 01
   '43391' = 01
   '43400' = 01
   '43401' = 01
   '43410' = 01
   '43411' = 01
   '43490' = 01
   '43491' = 01
   '4350'  = 01
   '4351'  = 01
   '4352'  = 01
   '4353'  = 01
   '4358'  = 01
   '4359'  = 01
   '436'   = 01
   '4370'  = 01
   '4371'  = 01
   '4372'  = 01
   '4373'  = 01
   '4374'  = 01
   '4375'  = 01
   '4376'  = 01
   '4377'  = 01
   '4378'  = 01
   '4379'  = 01
   '4380'  = 01
   '43810' = 01
   '43811' = 01
   '43812' = 01
   '43813' = 01
   '43814' = 01
   '43819' = 01
   '43820' = 01
   '43821' = 01
   '43822' = 01
   '43830' = 01
   '43831' = 01
   '43832' = 01
   '43840' = 01
   '43841' = 01
   '43842' = 01
   '43850' = 01
   '43851' = 01
   '43852' = 01
   '43853' = 01
   '4386'  = 01
   '4387'  = 01
   '43881' = 01
   '43882' = 01
   '43883' = 01
   '43884' = 01
   '43885' = 01
   '43889' = 01
   '4389'  = 01
   '4400'  = 05
   '4401'  = 11
   '44020' = 05
   '44021' = 05
   '44022' = 05
   '44023' = 05
   '44024' = 05
   '44029' = 05
   '44030' = 05
   '44031' = 05
   '44032' = 05
   '4404'  = 05
   '4408'  = 05
   '4409'  = 05
   '44100' = 05
   '44101' = 05
   '44102' = 05
   '44103' = 05
   '4411'  = 05
   '4412'  = 05
   '4413'  = 05
   '4414'  = 05
   '4415'  = 05
   '4416'  = 05
   '4417'  = 05
   '4419'  = 05
   '4420'  = 05
   '4421'  = 11
   '4422'  = 05
   '4423'  = 05
   '44281' = 05
   '44282' = 05
   '44283' = 05
   '44284' = 05
   '44289' = 05
   '4429'  = 05
   '4430'  = 08
   '4431'  = 05
   '44321' = 05
   '44322' = 05
   '44323' = 11
   '44324' = 05
   '44329' = 05
   '44381' = 05
   '44382' = 05
   '44389' = 05
   '4439'  = 05
   '44401' = 05
   '44409' = 05
   '4441'  = 05
   '44421' = 05
   '44422' = 05
   '44481' = 05
   '44489' = 05
   '4449'  = 05
   '44501' = 05
   '44502' = 05
   '44581' = 11
   '44589' = 05
   '4460'  = 08
   '4461'  = 08
   '44620' = 08
   '44621' = 08
   '44629' = 08
   '4463'  = 08
   '4464'  = 08
   '4465'  = 08
   '4466'  = 08
   '4467'  = 08
   '4470'  = 05
   '4471'  = 05
   '4472'  = 05
   '4473'  = 11
   '4474'  = 06
   '4475'  = 05
   '4476'  = 08
   '44770' = 05
   '44771' = 05
   '44772' = 05
   '44773' = 05
   '4478'  = 05
   '4479'  = 05
   '4480'  = 05
   '4481'  = 09
   '4489'  = 05
   '449'   = 05
   '4510'  = 05
   '45111' = 05
   '45119' = 05
   '4512'  = 05
   '45181' = 05
   '45182' = 05
   '45183' = 05
   '45184' = 05
   '45189' = 05
   '4519'  = 05
   '452'   = 07
   '4530'  = 07
   '4531'  = 05
   '4532'  = 05
   '4533'  = 11
   '45340' = 05
   '45341' = 05
   '45342' = 05
   '45350' = 05
   '45351' = 05
   '45352' = 05
   '4536'  = 05
   '45371' = 05
   '45372' = 05
   '45373' = 05
   '45374' = 05
   '45375' = 05
   '45376' = 05
   '45377' = 05
   '45379' = 05
   '45381' = 05
   '45382' = 05
   '45383' = 05
   '45384' = 05
   '45385' = 05
   '45386' = 05
   '45387' = 05
   '45389' = 05
   '4539'  = 05
   '4540'  = 05
   '4541'  = 05
   '4542'  = 05
   '4548'  = 05
   '4549'  = 05
   '4550'  = 06
   '4551'  = 06
   '4552'  = 06
   '4553'  = 06
   '4554'  = 06
   '4555'  = 06
   '4556'  = 06
   '4557'  = 06
   '4558'  = 06
   '4559'  = 06
   '4560'  = 06
   '4561'  = 06
   '45620' = 06
   '45621' = 06
   '4563'  = 05
   '4564'  = 12
   '4565'  = 12
   '4566'  = 13
   '4568'  = 05
   '4570'  = 09
   '4571'  = 09
   '4572'  = 09
   '4578'  = 16
   '4579'  = 16
   '4580'  = 05
   '4581'  = 05
   '45821' = 05
   '45829' = 05
   '4588'  = 05
   '4589'  = 05
   '4590'  = 05
   '45910' = 05
   '45911' = 05
   '45912' = 05
   '45913' = 05
   '45919' = 05
   '4592'  = 05
   '45930' = 05
   '45931' = 05
   '45932' = 05
   '45933' = 05
   '45939' = 05
   '45981' = 05
   '45989' = 05
   '4599'  = 05
   '460'   = 03
   '4610'  = 03
   '4611'  = 03
   '4612'  = 03
   '4613'  = 03
   '4618'  = 03
   '4619'  = 03
   '462'   = 03
   '463'   = 03
   '46400' = 03
   '46401' = 03
   '46410' = 04
   '46411' = 04
   '46420' = 03
   '46421' = 03
   '46430' = 03
   '46431' = 03
   '4644'  = 03
   '46450' = 03
   '46451' = 03
   '4650'  = 03
   '4658'  = 03
   '4659'  = 03
   '4660'  = 04
   '46611' = 04
   '46619' = 04
   '470'   = 03
   '4710'  = 03
   '4711'  = 03
   '4718'  = 03
   '4719'  = 03
   '4720'  = 03
   '4721'  = 03
   '4722'  = 03
   '4730'  = 03
   '4731'  = 03
   '4732'  = 03
   '4733'  = 03
   '4738'  = 03
   '4739'  = 03
   '47400' = 03
   '47401' = 03
   '47402' = 03
   '47410' = 03
   '47411' = 03
   '47412' = 03
   '4742'  = 03
   '4748'  = 03
   '4749'  = 03
   '475'   = 03
   '4760'  = 03
   '4761'  = 03
   '4770'  = 03
   '4771'  = 03
   '4772'  = 03
   '4778'  = 03
   '4779'  = 03
   '4780'  = 03
   '47811' = 03
   '47819' = 03
   '47820' = 03
   '47821' = 03
   '47822' = 03
   '47824' = 03
   '47825' = 03
   '47826' = 03
   '47829' = 03
   '47830' = 03
   '47831' = 03
   '47832' = 03
   '47833' = 03
   '47834' = 03
   '4784'  = 03
   '4785'  = 03
   '4786'  = 03
   '47870' = 03
   '47871' = 03
   '47874' = 03
   '47875' = 03
   '47879' = 03
   '4788'  = 03
   '4789'  = 03
   '4800'  = 04
   '4801'  = 04
   '4802'  = 04
   '4803'  = 04
   '4808'  = 04
   '4809'  = 04
   '481'   = 04
   '4820'  = 04
   '4821'  = 04
   '4822'  = 04
   '48230' = 04
   '48231' = 04
   '48232' = 04
   '48239' = 04
   '48240' = 04
   '48241' = 04
   '48242' = 04
   '48249' = 04
   '48281' = 04
   '48282' = 04
   '48283' = 04
   '48284' = 04
   '48289' = 04
   '4829'  = 04
   '4830'  = 04
   '4831'  = 04
   '4838'  = 04
   '4841'  = 04
   '4843'  = 04
   '4845'  = 04
   '4846'  = 04
   '4847'  = 04
   '4848'  = 04
   '485'   = 04
   '486'   = 04
   '4870'  = 04
   '4871'  = 03
   '4878'  = 18
   '48801' = 04
   '48802' = 04
   '48809' = 18
   '48811' = 04
   '48812' = 04
   '48819' = 18
   '48881' = 04
   '48882' = 04
   '48889' = 18
   '490'   = 04
   '4910'  = 04
   '4911'  = 04
   '49120' = 04
   '49121' = 04
   '49122' = 04
   '4918'  = 04
   '4919'  = 04
   '4920'  = 04
   '4928'  = 04
   '49300' = 04
   '49301' = 04
   '49302' = 04
   '49310' = 04
   '49311' = 04
   '49312' = 04
   '49320' = 04
   '49321' = 04
   '49322' = 04
   '49381' = 04
   '49382' = 04
   '49390' = 04
   '49391' = 04
   '49392' = 04
   '4940'  = 04
   '4941'  = 04
   '4950'  = 04
   '4951'  = 04
   '4952'  = 04
   '4953'  = 04
   '4954'  = 04
   '4955'  = 04
   '4956'  = 04
   '4957'  = 04
   '4958'  = 04
   '4959'  = 04
   '496'   = 04
   '500'   = 04
   '501'   = 04
   '502'   = 04
   '503'   = 04
   '504'   = 04
   '505'   = 04
   '5060'  = 04
   '5061'  = 04
   '5062'  = 04
   '5063'  = 04
   '5064'  = 04
   '5069'  = 04
   '5070'  = 04
   '5071'  = 04
   '5078'  = 04
   '5080'  = 04
   '5081'  = 04
   '5082'  = 04
   '5088'  = 04
   '5089'  = 04
   '5100'  = 04
   '5109'  = 04
   '5110'  = 04
   '5111'  = 04
   '51181' = 04
   '51189' = 04
   '5119'  = 04
   '5120'  = 04
   '5121'  = 04
   '5122'  = 04
   '51281' = 04
   '51282' = 04
   '51283' = 04
   '51284' = 04
   '51289' = 04
   '5130'  = 04
   '5131'  = 04
   '514'   = 04
   '515'   = 04
   '5160'  = 04
   '5161'  = 04
   '5162'  = 04
   '51630' = 04
   '51631' = 04
   '51632' = 04
   '51633' = 04
   '51634' = 04
   '51635' = 04
   '51636' = 04
   '51637' = 04
   '5164'  = 04
   '5165'  = 04
   '51661' = 04
   '51662' = 04
   '51663' = 04
   '51664' = 04
   '51669' = 04
   '5168'  = 04
   '5169'  = 04
   '5171'  = 04
   '5172'  = 04
   '5173'  = 04
   '5178'  = 04
   '5180'  = 04
   '5181'  = 04
   '5182'  = 04
   '5183'  = 04
   '5184'  = 04
   '51851' = 04
   '51852' = 04
   '51853' = 04
   '5186'  = 04
   '5187'  = 04
   '51881' = 04
   '51882' = 04
   '51883' = 04
   '51884' = 04
   '51889' = 04
   '51900' = 04
   '51901' = 04
   '51902' = 04
   '51909' = 04
   '51911' = 04
   '51919' = 04
   '5192'  = 04
   '5193'  = 04
   '5194'  = 04
   '5198'  = 04
   '5199'  = 04
   '5200'  = 03
   '5201'  = 03
   '5202'  = 03
   '5203'  = 03
   '5204'  = 03
   '5205'  = 03
   '5206'  = 03
   '5207'  = 03
   '5208'  = 03
   '5209'  = 03
   '52100' = 03
   '52101' = 03
   '52102' = 03
   '52103' = 03
   '52104' = 03
   '52105' = 03
   '52106' = 03
   '52107' = 03
   '52108' = 03
   '52109' = 03
   '52110' = 03
   '52111' = 03
   '52112' = 03
   '52113' = 03
   '52114' = 03
   '52115' = 03
   '52120' = 03
   '52121' = 03
   '52122' = 03
   '52123' = 03
   '52124' = 03
   '52125' = 03
   '52130' = 03
   '52131' = 03
   '52132' = 03
   '52133' = 03
   '52134' = 03
   '52135' = 03
   '52140' = 03
   '52141' = 03
   '52142' = 03
   '52149' = 03
   '5215'  = 03
   '5216'  = 03
   '5217'  = 03
   '52181' = 03
   '52189' = 03
   '5219'  = 03
   '5220'  = 03
   '5221'  = 03
   '5222'  = 03
   '5223'  = 03
   '5224'  = 03
   '5225'  = 03
   '5226'  = 03
   '5227'  = 03
   '5228'  = 03
   '5229'  = 03
   '52300' = 03
   '52301' = 03
   '52310' = 03
   '52311' = 03
   '52320' = 03
   '52321' = 03
   '52322' = 03
   '52323' = 03
   '52324' = 03
   '52325' = 03
   '52330' = 03
   '52331' = 03
   '52332' = 03
   '52333' = 03
   '52340' = 03
   '52341' = 03
   '52342' = 03
   '5235'  = 03
   '5236'  = 03
   '5238'  = 03
   '5239'  = 03
   '52400' = 03
   '52401' = 03
   '52402' = 03
   '52403' = 03
   '52404' = 03
   '52405' = 03
   '52406' = 03
   '52407' = 03
   '52409' = 03
   '52410' = 03
   '52411' = 03
   '52412' = 03
   '52419' = 03
   '52420' = 03
   '52421' = 03
   '52422' = 03
   '52423' = 03
   '52424' = 03
   '52425' = 03
   '52426' = 03
   '52427' = 03
   '52428' = 03
   '52429' = 03
   '52430' = 03
   '52431' = 03
   '52432' = 03
   '52433' = 03
   '52434' = 03
   '52435' = 03
   '52436' = 03
   '52437' = 03
   '52439' = 03
   '5244'  = 03
   '52450' = 03
   '52451' = 03
   '52452' = 03
   '52453' = 03
   '52454' = 03
   '52455' = 03
   '52456' = 03
   '52457' = 03
   '52459' = 03
   '52460' = 03
   '52461' = 03
   '52462' = 03
   '52463' = 03
   '52464' = 03
   '52469' = 03
   '52470' = 03
   '52471' = 03
   '52472' = 03
   '52473' = 03
   '52474' = 03
   '52475' = 03
   '52476' = 03
   '52479' = 03
   '52481' = 03
   '52482' = 03
   '52489' = 03
   '5249'  = 03
   '5250'  = 03
   '52510' = 03
   '52511' = 03
   '52512' = 03
   '52513' = 03
   '52519' = 03
   '52520' = 03
   '52521' = 03
   '52522' = 03
   '52523' = 03
   '52524' = 03
   '52525' = 03
   '52526' = 03
   '5253'  = 03
   '52540' = 03
   '52541' = 03
   '52542' = 03
   '52543' = 03
   '52544' = 03
   '52550' = 03
   '52551' = 03
   '52552' = 03
   '52553' = 03
   '52554' = 03
   '52560' = 03
   '52561' = 03
   '52562' = 03
   '52563' = 03
   '52564' = 03
   '52565' = 03
   '52566' = 03
   '52567' = 03
   '52569' = 03
   '52571' = 03
   '52572' = 03
   '52573' = 03
   '52579' = 03
   '5258'  = 03
   '5259'  = 03
   '5260'  = 03
   '5261'  = 03
   '5262'  = 03
   '5263'  = 03
   '5264'  = 03
   '5265'  = 03
   '52661' = 03
   '52662' = 03
   '52663' = 03
   '52669' = 03
   '52681' = 03
   '52689' = 03
   '5269'  = 03
   '5270'  = 03
   '5271'  = 03
   '5272'  = 03
   '5273'  = 03
   '5274'  = 03
   '5275'  = 03
   '5276'  = 03
   '5277'  = 03
   '5278'  = 03
   '5279'  = 03
   '52800' = 03
   '52801' = 03
   '52802' = 03
   '52809' = 03
   '5281'  = 03
   '5282'  = 03
   '5283'  = 03
   '5284'  = 03
   '5285'  = 03
   '5286'  = 03
   '52871' = 03
   '52872' = 03
   '52879' = 03
   '5288'  = 03
   '5289'  = 03
   '5290'  = 03
   '5291'  = 03
   '5292'  = 03
   '5293'  = 03
   '5294'  = 03
   '5295'  = 03
   '5296'  = 03
   '5298'  = 03
   '5299'  = 03
   '5300'  = 06
   '53010' = 06
   '53011' = 06
   '53012' = 06
   '53013' = 06
   '53019' = 06
   '53020' = 06
   '53021' = 06
   '5303'  = 06
   '5304'  = 06
   '5305'  = 06
   '5306'  = 06
   '5307'  = 06
   '53081' = 06
   '53082' = 06
   '53083' = 06
   '53084' = 06
   '53085' = 06
   '53086' = 06
   '53087' = 06
   '53089' = 06
   '5309'  = 06
   '53100' = 06
   '53101' = 06
   '53110' = 06
   '53111' = 06
   '53120' = 06
   '53121' = 06
   '53130' = 06
   '53131' = 06
   '53140' = 06
   '53141' = 06
   '53150' = 06
   '53151' = 06
   '53160' = 06
   '53161' = 06
   '53170' = 06
   '53171' = 06
   '53190' = 06
   '53191' = 06
   '53200' = 06
   '53201' = 06
   '53210' = 06
   '53211' = 06
   '53220' = 06
   '53221' = 06
   '53230' = 06
   '53231' = 06
   '53240' = 06
   '53241' = 06
   '53250' = 06
   '53251' = 06
   '53260' = 06
   '53261' = 06
   '53270' = 06
   '53271' = 06
   '53290' = 06
   '53291' = 06
   '53300' = 06
   '53301' = 06
   '53310' = 06
   '53311' = 06
   '53320' = 06
   '53321' = 06
   '53330' = 06
   '53331' = 06
   '53340' = 06
   '53341' = 06
   '53350' = 06
   '53351' = 06
   '53360' = 06
   '53361' = 06
   '53370' = 06
   '53371' = 06
   '53390' = 06
   '53391' = 06
   '53400' = 06
   '53401' = 06
   '53410' = 06
   '53411' = 06
   '53420' = 06
   '53421' = 06
   '53430' = 06
   '53431' = 06
   '53440' = 06
   '53441' = 06
   '53450' = 06
   '53451' = 06
   '53460' = 06
   '53461' = 06
   '53470' = 06
   '53471' = 06
   '53490' = 06
   '53491' = 06
   '53500' = 06
   '53501' = 06
   '53510' = 06
   '53511' = 06
   '53520' = 06
   '53521' = 06
   '53530' = 06
   '53531' = 06
   '53540' = 06
   '53541' = 06
   '53550' = 06
   '53551' = 06
   '53560' = 06
   '53561' = 06
   '53570' = 06
   '53571' = 06
   '5360'  = 06
   '5361'  = 06
   '5362'  = 06
   '5363'  = 06
   '53640' = 06
   '53641' = 06
   '53642' = 06
   '53649' = 06
   '5368'  = 06
   '5369'  = 06
   '5370'  = 06
   '5371'  = 06
   '5372'  = 06
   '5373'  = 06
   '5374'  = 06
   '5375'  = 06
   '5376'  = 06
   '53781' = 06
   '53782' = 06
   '53783' = 06
   '53784' = 06
   '53789' = 06
   '5379'  = 06
   '538'   = 06
   '53901' = 06
   '53909' = 06
   '53981' = 06
   '53989' = 06
   '5400'  = 06
   '5401'  = 06
   '5409'  = 06
   '541'   = 06
   '542'   = 06
   '5430'  = 06
   '5439'  = 06
   '55000' = 06
   '55001' = 06
   '55002' = 06
   '55003' = 06
   '55010' = 06
   '55011' = 06
   '55012' = 06
   '55013' = 06
   '55090' = 06
   '55091' = 06
   '55092' = 06
   '55093' = 06
   '55100' = 06
   '55101' = 06
   '55102' = 06
   '55103' = 06
   '5511'  = 06
   '55120' = 06
   '55121' = 06
   '55129' = 06
   '5513'  = 06
   '5518'  = 06
   '5519'  = 06
   '55200' = 06
   '55201' = 06
   '55202' = 06
   '55203' = 06
   '5521'  = 06
   '55220' = 06
   '55221' = 06
   '55229' = 06
   '5523'  = 06
   '5528'  = 06
   '5529'  = 06
   '55300' = 06
   '55301' = 06
   '55302' = 06
   '55303' = 06
   '5531'  = 06
   '55320' = 06
   '55321' = 06
   '55329' = 06
   '5533'  = 06
   '5538'  = 06
   '5539'  = 06
   '5550'  = 06
   '5551'  = 06
   '5552'  = 06
   '5559'  = 06
   '5560'  = 06
   '5561'  = 06
   '5562'  = 06
   '5563'  = 06
   '5564'  = 06
   '5565'  = 06
   '5566'  = 06
   '5568'  = 06
   '5569'  = 06
   '5570'  = 06
   '5571'  = 06
   '5579'  = 06
   '5581'  = 06
   '5582'  = 06
   '5583'  = 06
   '55841' = 06
   '55842' = 06
   '5589'  = 06
   '5600'  = 06
   '5601'  = 06
   '5602'  = 06
   '56030' = 06
   '56031' = 06
   '56032' = 06
   '56039' = 06
   '56081' = 06
   '56089' = 06
   '5609'  = 06
   '56200' = 06
   '56201' = 06
   '56202' = 06
   '56203' = 06
   '56210' = 06
   '56211' = 06
   '56212' = 06
   '56213' = 06
   '56400' = 06
   '56401' = 06
   '56402' = 06
   '56409' = 06
   '5641'  = 06
   '5642'  = 06
   '5643'  = 06
   '5644'  = 06
   '5645'  = 06
   '5646'  = 06
   '5647'  = 06
   '56481' = 06
   '56489' = 06
   '5649'  = 06
   '5650'  = 06
   '5651'  = 06
   '566'   = 06
   '5670'  = 06
   '5671'  = 06
   '56721' = 06
   '56722' = 06
   '56723' = 06
   '56729' = 06
   '56731' = 06
   '56738' = 06
   '56739' = 06
   '56781' = 06
   '56782' = 06
   '56789' = 06
   '5679'  = 06
   '5680'  = 06
   '56881' = 06
   '56882' = 06
   '56889' = 06
   '5689'  = 06
   '5690'  = 06
   '5691'  = 06
   '5692'  = 06
   '5693'  = 06
   '56941' = 06
   '56942' = 06
   '56943' = 06
   '56944' = 06
   '56949' = 06
   '5695'  = 06
   '56960' = 06
   '56961' = 06
   '56962' = 06
   '56969' = 06
   '56971' = 06
   '56979' = 06
   '56981' = 06
   '56982' = 06
   '56983' = 06
   '56984' = 06
   '56985' = 06
   '56986' = 06
   '56987' = 06
   '56989' = 06
   '5699'  = 06
   '570'   = 07
   '5710'  = 07
   '5711'  = 07
   '5712'  = 07
   '5713'  = 07
   '57140' = 07
   '57141' = 07
   '57142' = 07
   '57149' = 07
   '5715'  = 07
   '5716'  = 07
   '5718'  = 07
   '5719'  = 07
   '5720'  = 07
   '5721'  = 07
   '5722'  = 07
   '5723'  = 07
   '5724'  = 07
   '5728'  = 07
   '5730'  = 07
   '5731'  = 07
   '5732'  = 07
   '5733'  = 07
   '5734'  = 07
   '5735'  = 04
   '5738'  = 07
   '5739'  = 07
   '57400' = 07
   '57401' = 07
   '57410' = 07
   '57411' = 07
   '57420' = 07
   '57421' = 07
   '57430' = 07
   '57431' = 07
   '57440' = 07
   '57441' = 07
   '57450' = 07
   '57451' = 07
   '57460' = 07
   '57461' = 07
   '57470' = 07
   '57471' = 07
   '57480' = 07
   '57481' = 07
   '57490' = 07
   '57491' = 07
   '5750'  = 07
   '57510' = 07
   '57511' = 07
   '57512' = 07
   '5752'  = 07
   '5753'  = 07
   '5754'  = 07
   '5755'  = 07
   '5756'  = 07
   '5758'  = 07
   '5759'  = 07
   '5760'  = 07
   '5761'  = 07
   '5762'  = 07
   '5763'  = 07
   '5764'  = 07
   '5765'  = 07
   '5768'  = 07
   '5769'  = 07
   '5770'  = 07
   '5771'  = 07
   '5772'  = 07
   '5778'  = 07
   '5779'  = 07
   '5780'  = 06
   '5781'  = 06
   '5789'  = 06
   '5790'  = 06
   '5791'  = 06
   '5792'  = 06
   '5793'  = 06
   '5794'  = 06
   '5798'  = 06
   '5799'  = 06
   '5800'  = 11
   '5804'  = 11
   '58081' = 11
   '58089' = 11
   '5809'  = 11
   '5810'  = 11
   '5811'  = 11
   '5812'  = 11
   '5813'  = 11
   '58181' = 11
   '58189' = 11
   '5819'  = 11
   '5820'  = 11
   '5821'  = 11
   '5822'  = 11
   '5824'  = 11
   '58281' = 11
   '58289' = 11
   '5829'  = 11
   '5830'  = 11
   '5831'  = 11
   '5832'  = 11
   '5834'  = 11
   '5836'  = 11
   '5837'  = 11
   '58381' = 11
   '58389' = 11
   '5839'  = 11
   '5845'  = 11
   '5846'  = 11
   '5847'  = 11
   '5848'  = 11
   '5849'  = 11
   '5851'  = 11
   '5852'  = 11
   '5853'  = 11
   '5854'  = 11
   '5855'  = 11
   '5856'  = 11
   '5859'  = 11
   '586'   = 11
   '587'   = 11
   '5880'  = 11
   '5881'  = 11
   '58881' = 11
   '58889' = 11
   '5889'  = 11
   '5890'  = 11
   '5891'  = 11
   '5899'  = 11
   '59000' = 11
   '59001' = 11
   '59010' = 11
   '59011' = 11
   '5902'  = 11
   '5903'  = 11
   '59080' = 11
   '59081' = 11
   '5909'  = 11
   '591'   = 11
   '5920'  = 11
   '5921'  = 11
   '5929'  = 11
   '5930'  = 11
   '5931'  = 11
   '5932'  = 11
   '5933'  = 11
   '5934'  = 11
   '5935'  = 11
   '5936'  = 11
   '59370' = 11
   '59371' = 11
   '59372' = 11
   '59373' = 11
   '59381' = 11
   '59382' = 11
   '59389' = 11
   '5939'  = 11
   '5940'  = 11
   '5941'  = 11
   '5942'  = 11
   '5948'  = 11
   '5949'  = 11
   '5950'  = 11
   '5951'  = 11
   '5952'  = 11
   '5953'  = 11
   '5954'  = 11
   '59581' = 11
   '59582' = 11
   '59589' = 11
   '5959'  = 11
   '5960'  = 11
   '5961'  = 11
   '5962'  = 11
   '5963'  = 11
   '5964'  = 11
   '59651' = 11
   '59652' = 11
   '59653' = 11
   '59654' = 11
   '59655' = 11
   '59659' = 11
   '5966'  = 11
   '5967'  = 11
   '59681' = 11
   '59682' = 11
   '59683' = 11
   '59689' = 11
   '5969'  = 11
   '5970'  = 11
   '59780' = 11
   '59781' = 11
   '59789' = 11
   '59800' = 11
   '59801' = 11
   '5981'  = 11
   '5982'  = 11
   '5988'  = 11
   '5989'  = 11
   '5990'  = 11
   '5991'  = 11
   '5992'  = 11
   '5993'  = 11
   '5994'  = 11
   '5995'  = 11
   '59960' = 11
   '59969' = 11
   '59970' = 11
   '59971' = 11
   '59972' = 11
   '59981' = 11
   '59982' = 11
   '59983' = 11
   '59984' = 11
   '59989' = 11
   '5999'  = 11
   '60000' = 12
   '60001' = 12
   '60010' = 12
   '60011' = 12
   '60020' = 12
   '60021' = 12
   '6003'  = 12
   '60090' = 12
   '60091' = 12
   '6010'  = 12
   '6011'  = 12
   '6012'  = 12
   '6013'  = 12
   '6014'  = 12
   '6018'  = 12
   '6019'  = 12
   '6020'  = 12
   '6021'  = 12
   '6022'  = 12
   '6023'  = 12
   '6028'  = 12
   '6029'  = 12
   '6030'  = 12
   '6031'  = 12
   '6038'  = 12
   '6039'  = 12
   '6040'  = 12
   '60490' = 12
   '60491' = 12
   '60499' = 12
   '605'   = 12
   '6060'  = 12
   '6061'  = 12
   '6068'  = 12
   '6069'  = 12
   '6070'  = 12
   '6071'  = 12
   '6072'  = 12
   '6073'  = 12
   '60781' = 12
   '60782' = 12
   '60783' = 12
   '60784' = 12
   '60785' = 12
   '60789' = 12
   '6079'  = 12
   '6080'  = 12
   '6081'  = 12
   '60820' = 12
   '60821' = 12
   '60822' = 12
   '60823' = 12
   '60824' = 12
   '6083'  = 12
   '6084'  = 12
   '60881' = 12
   '60882' = 12
   '60883' = 12
   '60884' = 12
   '60885' = 12
   '60886' = 12
   '60887' = 12
   '60889' = 12
   '6089'  = 12
   '6100'  = 09
   '6101'  = 09
   '6102'  = 09
   '6103'  = 09
   '6104'  = 09
   '6108'  = 09
   '6109'  = 09
   '6110'  = 09
   '6111'  = 09
   '6112'  = 09
   '6113'  = 09
   '6114'  = 09
   '6115'  = 09
   '6116'  = 09
   '61171' = 09
   '61172' = 09
   '61179' = 09
   '61181' = 09
   '61182' = 09
   '61183' = 09
   '61189' = 09
   '6119'  = 09
   '6120'  = 09
   '6121'  = 09
   '6140'  = 13
   '6141'  = 13
   '6142'  = 13
   '6143'  = 13
   '6144'  = 13
   '6145'  = 13
   '6146'  = 13
   '6147'  = 13
   '6148'  = 13
   '6149'  = 13
   '6150'  = 13
   '6151'  = 13
   '6159'  = 13
   '6160'  = 13
   '61610' = 13
   '61611' = 13
   '6162'  = 13
   '6163'  = 13
   '6164'  = 13
   '61650' = 13
   '61651' = 13
   '61681' = 13
   '61689' = 13
   '6169'  = 13
   '6170'  = 13
   '6171'  = 13
   '6172'  = 13
   '6173'  = 13
   '6174'  = 13
   '6175'  = 06
   '6176'  = 09
   '6178'  = 13
   '6179'  = 13
   '61800' = 13
   '61801' = 13
   '61802' = 13
   '61803' = 13
   '61804' = 13
   '61805' = 13
   '61809' = 13
   '6181'  = 13
   '6182'  = 13
   '6183'  = 13
   '6184'  = 13
   '6185'  = 13
   '6186'  = 13
   '6187'  = 13
   '61881' = 13
   '61882' = 13
   '61883' = 13
   '61884' = 13
   '61889' = 13
   '6189'  = 13
   '6190'  = 13
   '6191'  = 06
   '6192'  = 13
   '6198'  = 13
   '6199'  = 13
   '6200'  = 13
   '6201'  = 13
   '6202'  = 13
   '6203'  = 13
   '6204'  = 13
   '6205'  = 13
   '6206'  = 13
   '6207'  = 13
   '6208'  = 13
   '6209'  = 13
   '6210'  = 13
   '6211'  = 13
   '6212'  = 13
   '62130' = 13
   '62131' = 13
   '62132' = 13
   '62133' = 13
   '62134' = 13
   '62135' = 13
   '6214'  = 13
   '6215'  = 13
   '6216'  = 13
   '6217'  = 13
   '6218'  = 13
   '6219'  = 13
   '6220'  = 13
   '62210' = 13
   '62211' = 13
   '62212' = 13
   '6222'  = 13
   '6223'  = 13
   '6224'  = 13
   '6225'  = 13
   '6226'  = 13
   '6227'  = 13
   '6228'  = 13
   '6229'  = 13
   '6230'  = 13
   '6231'  = 13
   '6232'  = 13
   '6233'  = 13
   '6234'  = 13
   '6235'  = 13
   '6236'  = 13
   '6237'  = 13
   '6238'  = 13
   '6239'  = 13
   '62401' = 13
   '62402' = 13
   '62409' = 13
   '6241'  = 13
   '6242'  = 13
   '6243'  = 13
   '6244'  = 13
   '6245'  = 13
   '6246'  = 13
   '6248'  = 13
   '6249'  = 13
   '6250'  = 13
   '6251'  = 13
   '6252'  = 13
   '6253'  = 13
   '6254'  = 13
   '6255'  = 13
   '6256'  = 13
   '62570' = 13
   '62571' = 13
   '62579' = 13
   '6258'  = 13
   '6259'  = 13
   '6260'  = 13
   '6261'  = 13
   '6262'  = 13
   '6263'  = 13
   '6264'  = 13
   '6265'  = 13
   '6266'  = 13
   '6267'  = 13
   '6268'  = 13
   '6269'  = 13
   '6270'  = 13
   '6271'  = 13
   '6272'  = 13
   '6273'  = 13
   '6274'  = 13
   '6278'  = 13
   '6279'  = 13
   '6280'  = 13
   '6281'  = 13
   '6282'  = 13
   '6283'  = 13
   '6284'  = 13
   '6288'  = 13
   '6289'  = 13
   '6290'  = 13
   '6291'  = 13
   '62920' = 13
   '62921' = 13
   '62922' = 13
   '62923' = 13
   '62929' = 13
   '62931' = 13
   '62932' = 13
   '62981' = 13
   '62989' = 13
   '6299'  = 13
   '630'   = 14
   '6310'  = 14
   '6318'  = 14
   '632'   = 14
   '63300' = 14
   '63301' = 14
   '63310' = 14
   '63311' = 14
   '63320' = 14
   '63321' = 14
   '63380' = 14
   '63381' = 14
   '63390' = 14
   '63391' = 14
   '63400' = 14
   '63401' = 14
   '63402' = 14
   '63410' = 14
   '63411' = 14
   '63412' = 14
   '63420' = 14
   '63421' = 14
   '63422' = 14
   '63430' = 14
   '63431' = 14
   '63432' = 14
   '63440' = 14
   '63441' = 14
   '63442' = 14
   '63450' = 14
   '63451' = 14
   '63452' = 14
   '63460' = 14
   '63461' = 14
   '63462' = 14
   '63470' = 14
   '63471' = 14
   '63472' = 14
   '63480' = 14
   '63481' = 14
   '63482' = 14
   '63490' = 14
   '63491' = 14
   '63492' = 14
   '63500' = 14
   '63501' = 14
   '63502' = 14
   '63510' = 14
   '63511' = 14
   '63512' = 14
   '63520' = 14
   '63521' = 14
   '63522' = 14
   '63530' = 14
   '63531' = 14
   '63532' = 14
   '63540' = 14
   '63541' = 14
   '63542' = 14
   '63550' = 14
   '63551' = 14
   '63552' = 14
   '63560' = 14
   '63561' = 14
   '63562' = 14
   '63570' = 14
   '63571' = 14
   '63572' = 14
   '63580' = 14
   '63581' = 14
   '63582' = 14
   '63590' = 14
   '63591' = 14
   '63592' = 14
   '63600' = 14
   '63601' = 14
   '63602' = 14
   '63610' = 14
   '63611' = 14
   '63612' = 14
   '63620' = 14
   '63621' = 14
   '63622' = 14
   '63630' = 14
   '63631' = 14
   '63632' = 14
   '63640' = 14
   '63641' = 14
   '63642' = 14
   '63650' = 14
   '63651' = 14
   '63652' = 14
   '63660' = 14
   '63661' = 14
   '63662' = 14
   '63670' = 14
   '63671' = 14
   '63672' = 14
   '63680' = 14
   '63681' = 14
   '63682' = 14
   '63690' = 14
   '63691' = 14
   '63692' = 14
   '63700' = 14
   '63701' = 14
   '63702' = 14
   '63710' = 14
   '63711' = 14
   '63712' = 14
   '63720' = 14
   '63721' = 14
   '63722' = 14
   '63730' = 14
   '63731' = 14
   '63732' = 14
   '63740' = 14
   '63741' = 14
   '63742' = 14
   '63750' = 14
   '63751' = 14
   '63752' = 14
   '63760' = 14
   '63761' = 14
   '63762' = 14
   '63770' = 14
   '63771' = 14
   '63772' = 14
   '63780' = 14
   '63781' = 14
   '63782' = 14
   '63790' = 14
   '63791' = 14
   '63792' = 14
   '6380'  = 14
   '6381'  = 14
   '6382'  = 14
   '6383'  = 14
   '6384'  = 14
   '6385'  = 14
   '6386'  = 14
   '6387'  = 14
   '6388'  = 14
   '6389'  = 14
   '6390'  = 14
   '6391'  = 14
   '6392'  = 14
   '6393'  = 14
   '6394'  = 14
   '6395'  = 14
   '6396'  = 14
   '6398'  = 14
   '6399'  = 14
   '64000' = 14
   '64001' = 14
   '64003' = 14
   '64080' = 14
   '64081' = 14
   '64083' = 14
   '64090' = 14
   '64091' = 14
   '64093' = 14
   '64100' = 14
   '64101' = 14
   '64103' = 14
   '64110' = 14
   '64111' = 14
   '64113' = 14
   '64120' = 14
   '64121' = 14
   '64123' = 14
   '64130' = 14
   '64131' = 14
   '64133' = 14
   '64180' = 14
   '64181' = 14
   '64183' = 14
   '64190' = 14
   '64191' = 14
   '64193' = 14
   '64200' = 14
   '64201' = 14
   '64202' = 14
   '64203' = 14
   '64204' = 14
   '64210' = 14
   '64211' = 14
   '64212' = 14
   '64213' = 14
   '64214' = 14
   '64220' = 14
   '64221' = 14
   '64222' = 14
   '64223' = 14
   '64224' = 14
   '64230' = 14
   '64231' = 14
   '64232' = 14
   '64233' = 14
   '64234' = 14
   '64240' = 14
   '64241' = 14
   '64242' = 14
   '64243' = 14
   '64244' = 14
   '64250' = 14
   '64251' = 14
   '64252' = 14
   '64253' = 14
   '64254' = 14
   '64260' = 14
   '64261' = 14
   '64262' = 14
   '64263' = 14
   '64264' = 14
   '64270' = 14
   '64271' = 14
   '64272' = 14
   '64273' = 14
   '64274' = 14
   '64290' = 14
   '64291' = 14
   '64292' = 14
   '64293' = 14
   '64294' = 14
   '64300' = 14
   '64301' = 14
   '64303' = 14
   '64310' = 14
   '64311' = 14
   '64313' = 14
   '64320' = 14
   '64321' = 14
   '64323' = 14
   '64380' = 14
   '64381' = 14
   '64383' = 14
   '64390' = 14
   '64391' = 14
   '64393' = 14
   '64400' = 14
   '64403' = 14
   '64410' = 14
   '64413' = 14
   '64420' = 14
   '64421' = 14
   '64510' = 14
   '64511' = 14
   '64513' = 14
   '64520' = 14
   '64521' = 14
   '64523' = 14
   '64600' = 14
   '64601' = 14
   '64603' = 14
   '64610' = 14
   '64611' = 14
   '64612' = 14
   '64613' = 14
   '64614' = 14
   '64620' = 14
   '64621' = 14
   '64622' = 14
   '64623' = 14
   '64624' = 14
   '64630' = 14
   '64631' = 14
   '64633' = 14
   '64640' = 14
   '64641' = 14
   '64642' = 14
   '64643' = 14
   '64644' = 14
   '64650' = 14
   '64651' = 14
   '64652' = 14
   '64653' = 14
   '64654' = 14
   '64660' = 14
   '64661' = 14
   '64662' = 14
   '64663' = 14
   '64664' = 14
   '64670' = 14
   '64671' = 14
   '64673' = 14
   '64680' = 14
   '64681' = 14
   '64682' = 14
   '64683' = 14
   '64684' = 14
   '64690' = 14
   '64691' = 14
   '64693' = 14
   '64700' = 14
   '64701' = 14
   '64702' = 14
   '64703' = 14
   '64704' = 14
   '64710' = 14
   '64711' = 14
   '64712' = 14
   '64713' = 14
   '64714' = 14
   '64720' = 14
   '64721' = 14
   '64722' = 14
   '64723' = 14
   '64724' = 14
   '64730' = 14
   '64731' = 14
   '64732' = 14
   '64733' = 14
   '64734' = 14
   '64740' = 14
   '64741' = 14
   '64742' = 14
   '64743' = 14
   '64744' = 14
   '64750' = 14
   '64751' = 14
   '64752' = 14
   '64753' = 14
   '64754' = 14
   '64760' = 14
   '64761' = 14
   '64762' = 14
   '64763' = 14
   '64764' = 14
   '64780' = 14
   '64781' = 14
   '64782' = 14
   '64783' = 14
   '64784' = 14
   '64790' = 14
   '64791' = 14
   '64792' = 14
   '64793' = 14
   '64794' = 14
   '64800' = 14
   '64801' = 14
   '64802' = 14
   '64803' = 14
   '64804' = 14
   '64810' = 14
   '64811' = 14
   '64812' = 14
   '64813' = 14
   '64814' = 14
   '64820' = 14
   '64821' = 14
   '64822' = 14
   '64823' = 14
   '64824' = 14
   '64830' = 14
   '64831' = 14
   '64832' = 14
   '64833' = 14
   '64834' = 14
   '64840' = 14
   '64841' = 14
   '64842' = 14
   '64843' = 14
   '64844' = 14
   '64850' = 14
   '64851' = 14
   '64852' = 14
   '64853' = 14
   '64854' = 14
   '64860' = 14
   '64861' = 14
   '64862' = 14
   '64863' = 14
   '64864' = 14
   '64870' = 14
   '64871' = 14
   '64872' = 14
   '64873' = 14
   '64874' = 14
   '64880' = 14
   '64881' = 14
   '64882' = 14
   '64883' = 14
   '64884' = 14
   '64890' = 14
   '64891' = 14
   '64892' = 14
   '64893' = 14
   '64894' = 14
   '64900' = 14
   '64901' = 14
   '64902' = 14
   '64903' = 14
   '64904' = 14
   '64910' = 14
   '64911' = 14
   '64912' = 14
   '64913' = 14
   '64914' = 14
   '64920' = 14
   '64921' = 14
   '64922' = 14
   '64923' = 14
   '64924' = 14
   '64930' = 14
   '64931' = 14
   '64932' = 14
   '64933' = 14
   '64934' = 14
   '64940' = 14
   '64941' = 14
   '64942' = 14
   '64943' = 14
   '64944' = 14
   '64950' = 14
   '64951' = 14
   '64953' = 14
   '64960' = 14
   '64961' = 14
   '64962' = 14
   '64963' = 14
   '64964' = 14
   '64970' = 14
   '64971' = 14
   '64973' = 14
   '64981' = 14
   '64982' = 14
   '650'   = 14
   '65100' = 14
   '65101' = 14
   '65103' = 14
   '65110' = 14
   '65111' = 14
   '65113' = 14
   '65120' = 14
   '65121' = 14
   '65123' = 14
   '65130' = 14
   '65131' = 14
   '65133' = 14
   '65140' = 14
   '65141' = 14
   '65143' = 14
   '65150' = 14
   '65151' = 14
   '65153' = 14
   '65160' = 14
   '65161' = 14
   '65163' = 14
   '65170' = 14
   '65171' = 14
   '65173' = 14
   '65180' = 14
   '65181' = 14
   '65183' = 14
   '65190' = 14
   '65191' = 14
   '65193' = 14
   '65200' = 14
   '65201' = 14
   '65203' = 14
   '65210' = 14
   '65211' = 14
   '65213' = 14
   '65220' = 14
   '65221' = 14
   '65223' = 14
   '65230' = 14
   '65231' = 14
   '65233' = 14
   '65240' = 14
   '65241' = 14
   '65243' = 14
   '65250' = 14
   '65251' = 14
   '65253' = 14
   '65260' = 14
   '65261' = 14
   '65263' = 14
   '65270' = 14
   '65271' = 14
   '65273' = 14
   '65280' = 14
   '65281' = 14
   '65283' = 14
   '65290' = 14
   '65291' = 14
   '65293' = 14
   '65300' = 14
   '65301' = 14
   '65303' = 14
   '65310' = 14
   '65311' = 14
   '65313' = 14
   '65320' = 14
   '65321' = 14
   '65323' = 14
   '65330' = 14
   '65331' = 14
   '65333' = 14
   '65340' = 14
   '65341' = 14
   '65343' = 14
   '65350' = 14
   '65351' = 14
   '65353' = 14
   '65360' = 14
   '65361' = 14
   '65363' = 14
   '65370' = 14
   '65371' = 14
   '65373' = 14
   '65380' = 14
   '65381' = 14
   '65383' = 14
   '65390' = 14
   '65391' = 14
   '65393' = 14
   '65400' = 14
   '65401' = 14
   '65402' = 14
   '65403' = 14
   '65404' = 14
   '65410' = 14
   '65411' = 14
   '65412' = 14
   '65413' = 14
   '65414' = 14
   '65420' = 14
   '65421' = 14
   '65423' = 14
   '65430' = 14
   '65431' = 14
   '65432' = 14
   '65433' = 14
   '65434' = 14
   '65440' = 14
   '65441' = 14
   '65442' = 14
   '65443' = 14
   '65444' = 14
   '65450' = 14
   '65451' = 14
   '65452' = 14
   '65453' = 14
   '65454' = 14
   '65460' = 14
   '65461' = 14
   '65462' = 14
   '65463' = 14
   '65464' = 14
   '65470' = 14
   '65471' = 14
   '65472' = 14
   '65473' = 14
   '65474' = 14
   '65480' = 14
   '65481' = 14
   '65482' = 14
   '65483' = 14
   '65484' = 14
   '65490' = 14
   '65491' = 14
   '65492' = 14
   '65493' = 14
   '65494' = 14
   '65500' = 14
   '65501' = 14
   '65503' = 14
   '65510' = 14
   '65511' = 14
   '65513' = 14
   '65520' = 14
   '65521' = 14
   '65523' = 14
   '65530' = 14
   '65531' = 14
   '65533' = 14
   '65540' = 14
   '65541' = 14
   '65543' = 14
   '65550' = 14
   '65551' = 14
   '65553' = 14
   '65560' = 14
   '65561' = 14
   '65563' = 14
   '65570' = 14
   '65571' = 14
   '65573' = 14
   '65580' = 14
   '65581' = 14
   '65583' = 14
   '65590' = 14
   '65591' = 14
   '65593' = 14
   '65600' = 14
   '65601' = 14
   '65603' = 14
   '65610' = 14
   '65611' = 14
   '65613' = 14
   '65620' = 14
   '65621' = 14
   '65623' = 14
   '65630' = 14
   '65631' = 14
   '65633' = 14
   '65640' = 14
   '65641' = 14
   '65643' = 14
   '65650' = 14
   '65651' = 14
   '65653' = 14
   '65660' = 14
   '65661' = 14
   '65663' = 14
   '65670' = 14
   '65671' = 14
   '65673' = 14
   '65680' = 14
   '65681' = 14
   '65683' = 14
   '65690' = 14
   '65691' = 14
   '65693' = 14
   '65700' = 14
   '65701' = 14
   '65703' = 14
   '65800' = 14
   '65801' = 14
   '65803' = 14
   '65810' = 14
   '65811' = 14
   '65813' = 14
   '65820' = 14
   '65821' = 14
   '65823' = 14
   '65830' = 14
   '65831' = 14
   '65833' = 14
   '65840' = 14
   '65841' = 14
   '65843' = 14
   '65880' = 14
   '65881' = 14
   '65883' = 14
   '65890' = 14
   '65891' = 14
   '65893' = 14
   '65900' = 14
   '65901' = 14
   '65903' = 14
   '65910' = 14
   '65911' = 14
   '65913' = 14
   '65920' = 14
   '65921' = 14
   '65923' = 14
   '65930' = 14
   '65931' = 14
   '65933' = 14
   '65940' = 14
   '65941' = 14
   '65943' = 14
   '65950' = 14
   '65951' = 14
   '65953' = 14
   '65960' = 14
   '65961' = 14
   '65963' = 14
   '65970' = 14
   '65971' = 14
   '65973' = 14
   '65980' = 14
   '65981' = 14
   '65983' = 14
   '65990' = 14
   '65991' = 14
   '65993' = 14
   '66000' = 14
   '66001' = 14
   '66003' = 14
   '66010' = 14
   '66011' = 14
   '66013' = 14
   '66020' = 14
   '66021' = 14
   '66023' = 14
   '66030' = 14
   '66031' = 14
   '66033' = 14
   '66040' = 14
   '66041' = 14
   '66043' = 14
   '66050' = 14
   '66051' = 14
   '66053' = 14
   '66060' = 14
   '66061' = 14
   '66063' = 14
   '66070' = 14
   '66071' = 14
   '66073' = 14
   '66080' = 14
   '66081' = 14
   '66083' = 14
   '66090' = 14
   '66091' = 14
   '66093' = 14
   '66100' = 14
   '66101' = 14
   '66103' = 14
   '66110' = 14
   '66111' = 14
   '66113' = 14
   '66120' = 14
   '66121' = 14
   '66123' = 14
   '66130' = 14
   '66131' = 14
   '66133' = 14
   '66140' = 14
   '66141' = 14
   '66143' = 14
   '66190' = 14
   '66191' = 14
   '66193' = 14
   '66200' = 14
   '66201' = 14
   '66203' = 14
   '66210' = 14
   '66211' = 14
   '66213' = 14
   '66220' = 14
   '66221' = 14
   '66223' = 14
   '66230' = 14
   '66231' = 14
   '66233' = 14
   '66300' = 14
   '66301' = 14
   '66303' = 14
   '66310' = 14
   '66311' = 14
   '66313' = 14
   '66320' = 14
   '66321' = 14
   '66323' = 14
   '66330' = 14
   '66331' = 14
   '66333' = 14
   '66340' = 14
   '66341' = 14
   '66343' = 14
   '66350' = 14
   '66351' = 14
   '66353' = 14
   '66360' = 14
   '66361' = 14
   '66363' = 14
   '66380' = 14
   '66381' = 14
   '66383' = 14
   '66390' = 14
   '66391' = 14
   '66393' = 14
   '66400' = 14
   '66401' = 14
   '66404' = 14
   '66410' = 14
   '66411' = 14
   '66414' = 14
   '66420' = 14
   '66421' = 14
   '66424' = 14
   '66430' = 14
   '66431' = 14
   '66434' = 14
   '66440' = 14
   '66441' = 14
   '66444' = 14
   '66450' = 14
   '66451' = 14
   '66454' = 14
   '66460' = 14
   '66461' = 14
   '66464' = 14
   '66480' = 14
   '66481' = 14
   '66484' = 14
   '66490' = 14
   '66491' = 14
   '66494' = 14
   '66500' = 14
   '66501' = 14
   '66503' = 14
   '66510' = 14
   '66511' = 14
   '66520' = 14
   '66522' = 14
   '66524' = 14
   '66530' = 14
   '66531' = 14
   '66534' = 14
   '66540' = 14
   '66541' = 14
   '66544' = 14
   '66550' = 14
   '66551' = 14
   '66554' = 14
   '66560' = 14
   '66561' = 14
   '66564' = 14
   '66570' = 14
   '66571' = 14
   '66572' = 14
   '66574' = 14
   '66580' = 14
   '66581' = 14
   '66582' = 14
   '66583' = 14
   '66584' = 14
   '66590' = 14
   '66591' = 14
   '66592' = 14
   '66593' = 14
   '66594' = 14
   '66600' = 14
   '66602' = 14
   '66604' = 14
   '66610' = 14
   '66612' = 14
   '66614' = 14
   '66620' = 14
   '66622' = 14
   '66624' = 14
   '66630' = 14
   '66632' = 14
   '66634' = 14
   '66700' = 14
   '66702' = 14
   '66704' = 14
   '66710' = 14
   '66712' = 14
   '66714' = 14
   '66800' = 14
   '66801' = 14
   '66802' = 14
   '66803' = 14
   '66804' = 14
   '66810' = 14
   '66811' = 14
   '66812' = 14
   '66813' = 14
   '66814' = 14
   '66820' = 14
   '66821' = 14
   '66822' = 14
   '66823' = 14
   '66824' = 14
   '66880' = 14
   '66881' = 14
   '66882' = 14
   '66883' = 14
   '66884' = 14
   '66890' = 14
   '66891' = 14
   '66892' = 14
   '66893' = 14
   '66894' = 14
   '66900' = 14
   '66901' = 14
   '66902' = 14
   '66903' = 14
   '66904' = 14
   '66910' = 14
   '66911' = 14
   '66912' = 14
   '66913' = 14
   '66914' = 14
   '66920' = 14
   '66921' = 14
   '66922' = 14
   '66923' = 14
   '66924' = 14
   '66930' = 14
   '66932' = 14
   '66934' = 14
   '66940' = 14
   '66941' = 14
   '66942' = 14
   '66943' = 14
   '66944' = 14
   '66950' = 14
   '66951' = 14
   '66960' = 14
   '66961' = 14
   '66970' = 14
   '66971' = 14
   '66980' = 14
   '66981' = 14
   '66982' = 14
   '66983' = 14
   '66984' = 14
   '66990' = 14
   '66991' = 14
   '66992' = 14
   '66993' = 14
   '66994' = 14
   '67000' = 14
   '67002' = 14
   '67004' = 14
   '67010' = 14
   '67012' = 14
   '67014' = 14
   '67020' = 14
   '67022' = 14
   '67024' = 14
   '67030' = 14
   '67032' = 14
   '67034' = 14
   '67080' = 14
   '67082' = 14
   '67084' = 14
   '67100' = 14
   '67101' = 14
   '67102' = 14
   '67103' = 14
   '67104' = 14
   '67110' = 14
   '67111' = 14
   '67112' = 14
   '67113' = 14
   '67114' = 14
   '67120' = 14
   '67121' = 14
   '67122' = 14
   '67123' = 14
   '67124' = 14
   '67130' = 14
   '67131' = 14
   '67133' = 14
   '67140' = 14
   '67142' = 14
   '67144' = 14
   '67150' = 14
   '67151' = 14
   '67152' = 14
   '67153' = 14
   '67154' = 14
   '67180' = 14
   '67181' = 14
   '67182' = 14
   '67183' = 14
   '67184' = 14
   '67190' = 14
   '67191' = 14
   '67192' = 14
   '67193' = 14
   '67194' = 14
   '67200' = 14
   '67202' = 14
   '67204' = 14
   '67300' = 14
   '67301' = 14
   '67302' = 14
   '67303' = 14
   '67304' = 14
   '67310' = 14
   '67311' = 14
   '67312' = 14
   '67313' = 14
   '67314' = 14
   '67320' = 14
   '67321' = 14
   '67322' = 14
   '67323' = 14
   '67324' = 14
   '67330' = 14
   '67331' = 14
   '67332' = 14
   '67333' = 14
   '67334' = 14
   '67380' = 14
   '67381' = 14
   '67382' = 14
   '67383' = 14
   '67384' = 14
   '67400' = 14
   '67401' = 14
   '67402' = 14
   '67403' = 14
   '67404' = 14
   '67410' = 14
   '67412' = 14
   '67414' = 14
   '67420' = 14
   '67422' = 14
   '67424' = 14
   '67430' = 14
   '67432' = 14
   '67434' = 14
   '67440' = 14
   '67442' = 14
   '67444' = 14
   '67450' = 14
   '67451' = 14
   '67452' = 14
   '67453' = 14
   '67454' = 14
   '67480' = 14
   '67482' = 14
   '67484' = 14
   '67490' = 14
   '67492' = 14
   '67494' = 14
   '67500' = 14
   '67501' = 14
   '67502' = 14
   '67503' = 14
   '67504' = 14
   '67510' = 14
   '67511' = 14
   '67512' = 14
   '67513' = 14
   '67514' = 14
   '67520' = 14
   '67521' = 14
   '67522' = 14
   '67523' = 14
   '67524' = 14
   '67580' = 14
   '67581' = 14
   '67582' = 14
   '67583' = 14
   '67584' = 14
   '67590' = 14
   '67591' = 14
   '67592' = 14
   '67593' = 14
   '67594' = 14
   '67600' = 14
   '67601' = 14
   '67602' = 14
   '67603' = 14
   '67604' = 14
   '67610' = 14
   '67611' = 14
   '67612' = 14
   '67613' = 14
   '67614' = 14
   '67620' = 14
   '67621' = 14
   '67622' = 14
   '67623' = 14
   '67624' = 14
   '67630' = 14
   '67631' = 14
   '67632' = 14
   '67633' = 14
   '67634' = 14
   '67640' = 14
   '67641' = 14
   '67642' = 14
   '67643' = 14
   '67644' = 14
   '67650' = 14
   '67651' = 14
   '67652' = 14
   '67653' = 14
   '67654' = 14
   '67660' = 14
   '67661' = 14
   '67662' = 14
   '67663' = 14
   '67664' = 14
   '67680' = 14
   '67681' = 14
   '67682' = 14
   '67683' = 14
   '67684' = 14
   '67690' = 14
   '67691' = 14
   '67692' = 14
   '67693' = 14
   '67694' = 14
   '677'   = 14
   '67800' = 14
   '67801' = 14
   '67803' = 14
   '67810' = 14
   '67811' = 14
   '67813' = 14
   '67900' = 14
   '67901' = 14
   '67902' = 14
   '67903' = 14
   '67904' = 14
   '67910' = 14
   '67911' = 14
   '67912' = 14
   '67913' = 14
   '67914' = 14
   '6800'  = 09
   '6801'  = 09
   '6802'  = 09
   '6803'  = 09
   '6804'  = 09
   '6805'  = 09
   '6806'  = 09
   '6807'  = 09
   '6808'  = 09
   '6809'  = 09
   '68100' = 09
   '68101' = 09
   '68102' = 09
   '68110' = 09
   '68111' = 09
   '6819'  = 09
   '6820'  = 09
   '6821'  = 09
   '6822'  = 09
   '6823'  = 09
   '6824'  = 09
   '6825'  = 09
   '6826'  = 09
   '6827'  = 09
   '6828'  = 09
   '6829'  = 09
   '683'   = 16
   '684'   = 09
   '6850'  = 09
   '6851'  = 09
   '68600' = 09
   '68601' = 09
   '68609' = 09
   '6861'  = 09
   '6868'  = 09
   '6869'  = 09
   '69010' = 09
   '69011' = 09
   '69012' = 09
   '69018' = 09
   '6908'  = 09
   '6910'  = 09
   '6918'  = 09
   '6920'  = 09
   '6921'  = 09
   '6922'  = 09
   '6923'  = 09
   '6924'  = 09
   '6925'  = 09
   '6926'  = 09
   '69270' = 09
   '69271' = 09
   '69272' = 09
   '69273' = 09
   '69274' = 09
   '69275' = 09
   '69276' = 09
   '69277' = 09
   '69279' = 09
   '69281' = 09
   '69282' = 09
   '69283' = 09
   '69284' = 09
   '69289' = 09
   '6929'  = 09
   '6930'  = 09
   '6931'  = 09
   '6938'  = 09
   '6939'  = 09
   '6940'  = 09
   '6941'  = 09
   '6942'  = 09
   '6943'  = 09
   '6944'  = 09
   '6945'  = 09
   '69460' = 09
   '69461' = 02
   '6948'  = 09
   '6949'  = 09
   '6950'  = 09
   '69510' = 09
   '69511' = 09
   '69512' = 09
   '69513' = 09
   '69514' = 09
   '69515' = 09
   '69519' = 09
   '6952'  = 09
   '6953'  = 09
   '6954'  = 09
   '69550' = 09
   '69551' = 09
   '69552' = 09
   '69553' = 09
   '69554' = 09
   '69555' = 09
   '69556' = 09
   '69557' = 09
   '69558' = 09
   '69559' = 09
   '69581' = 09
   '69589' = 09
   '6959'  = 09
   '6960'  = 08
   '6961'  = 09
   '6962'  = 09
   '6963'  = 09
   '6964'  = 09
   '6965'  = 09
   '6968'  = 09
   '6970'  = 09
   '6971'  = 09
   '6978'  = 09
   '6979'  = 09
   '6980'  = 09
   '6981'  = 12
   '6982'  = 09
   '6983'  = 09
   '6984'  = 09
   '6988'  = 09
   '6989'  = 09
   '700'   = 09
   '7010'  = 09
   '7011'  = 09
   '7012'  = 09
   '7013'  = 09
   '7014'  = 09
   '7015'  = 09
   '7018'  = 09
   '7019'  = 09
   '7020'  = 09
   '70211' = 09
   '70219' = 09
   '7028'  = 09
   '7030'  = 09
   '7038'  = 09
   '7039'  = 09
   '70400' = 09
   '70401' = 09
   '70402' = 09
   '70409' = 09
   '7041'  = 09
   '7042'  = 09
   '7043'  = 09
   '70441' = 09
   '70442' = 09
   '7048'  = 09
   '7049'  = 09
   '7050'  = 09
   '7051'  = 09
   '70521' = 09
   '70522' = 09
   '70581' = 09
   '70582' = 09
   '70583' = 09
   '70589' = 09
   '7059'  = 09
   '7060'  = 09
   '7061'  = 09
   '7062'  = 09
   '7063'  = 09
   '7068'  = 09
   '7069'  = 09
   '70700' = 09
   '70701' = 09
   '70702' = 09
   '70703' = 09
   '70704' = 09
   '70705' = 09
   '70706' = 09
   '70707' = 09
   '70709' = 09
   '70710' = 09
   '70711' = 09
   '70712' = 09
   '70713' = 09
   '70714' = 09
   '70715' = 09
   '70719' = 09
   '70720' = 09
   '70721' = 09
   '70722' = 09
   '70723' = 09
   '70724' = 09
   '70725' = 09
   '7078'  = 09
   '7079'  = 09
   '7080'  = 09
   '7081'  = 09
   '7082'  = 09
   '7083'  = 09
   '7084'  = 09
   '7085'  = 09
   '7088'  = 09
   '7089'  = 09
   '70900' = 09
   '70901' = 09
   '70909' = 09
   '7091'  = 09
   '7092'  = 09
   '7093'  = 09
   '7094'  = 09
   '7098'  = 09
   '7099'  = 09
   '7100'  = 08
   '7101'  = 08
   '7102'  = 08
   '7103'  = 08
   '7104'  = 08
   '7105'  = 08
   '7108'  = 08
   '7109'  = 08
   '71100' = 08
   '71101' = 08
   '71102' = 08
   '71103' = 08
   '71104' = 08
   '71105' = 08
   '71106' = 08
   '71107' = 08
   '71108' = 08
   '71109' = 08
   '71110' = 08
   '71111' = 08
   '71112' = 08
   '71113' = 08
   '71114' = 08
   '71115' = 08
   '71116' = 08
   '71117' = 08
   '71118' = 08
   '71119' = 08
   '71120' = 08
   '71121' = 08
   '71122' = 08
   '71123' = 08
   '71124' = 08
   '71125' = 08
   '71126' = 08
   '71127' = 08
   '71128' = 08
   '71129' = 08
   '71130' = 08
   '71131' = 08
   '71132' = 08
   '71133' = 08
   '71134' = 08
   '71135' = 08
   '71136' = 08
   '71137' = 08
   '71138' = 08
   '71139' = 08
   '71140' = 08
   '71141' = 08
   '71142' = 08
   '71143' = 08
   '71144' = 08
   '71145' = 08
   '71146' = 08
   '71147' = 08
   '71148' = 08
   '71149' = 08
   '71150' = 08
   '71151' = 08
   '71152' = 08
   '71153' = 08
   '71154' = 08
   '71155' = 08
   '71156' = 08
   '71157' = 08
   '71158' = 08
   '71159' = 08
   '71160' = 08
   '71161' = 08
   '71162' = 08
   '71163' = 08
   '71164' = 08
   '71165' = 08
   '71166' = 08
   '71167' = 08
   '71168' = 08
   '71169' = 08
   '71170' = 08
   '71171' = 08
   '71172' = 08
   '71173' = 08
   '71174' = 08
   '71175' = 08
   '71176' = 08
   '71177' = 08
   '71178' = 08
   '71179' = 08
   '71180' = 08
   '71181' = 08
   '71182' = 08
   '71183' = 08
   '71184' = 08
   '71185' = 08
   '71186' = 08
   '71187' = 08
   '71188' = 08
   '71189' = 08
   '71190' = 08
   '71191' = 08
   '71192' = 08
   '71193' = 08
   '71194' = 08
   '71195' = 08
   '71196' = 08
   '71197' = 08
   '71198' = 08
   '71199' = 08
   '71210' = 08
   '71211' = 08
   '71212' = 08
   '71213' = 08
   '71214' = 08
   '71215' = 08
   '71216' = 08
   '71217' = 08
   '71218' = 08
   '71219' = 08
   '71220' = 08
   '71221' = 08
   '71222' = 08
   '71223' = 08
   '71224' = 08
   '71225' = 08
   '71226' = 08
   '71227' = 08
   '71228' = 08
   '71229' = 08
   '71230' = 08
   '71231' = 08
   '71232' = 08
   '71233' = 08
   '71234' = 08
   '71235' = 08
   '71236' = 08
   '71237' = 08
   '71238' = 08
   '71239' = 08
   '71280' = 08
   '71281' = 08
   '71282' = 08
   '71283' = 08
   '71284' = 08
   '71285' = 08
   '71286' = 08
   '71287' = 08
   '71288' = 08
   '71289' = 08
   '71290' = 08
   '71291' = 08
   '71292' = 08
   '71293' = 08
   '71294' = 08
   '71295' = 08
   '71296' = 08
   '71297' = 08
   '71298' = 08
   '71299' = 08
   '7130'  = 08
   '7131'  = 08
   '7132'  = 08
   '7133'  = 08
   '7134'  = 08
   '7135'  = 08
   '7136'  = 08
   '7137'  = 08
   '7138'  = 08
   '7140'  = 08
   '7141'  = 08
   '7142'  = 08
   '71430' = 08
   '71431' = 08
   '71432' = 08
   '71433' = 08
   '7144'  = 08
   '71481' = 04
   '71489' = 08
   '7149'  = 08
   '71500' = 08
   '71504' = 08
   '71509' = 08
   '71510' = 08
   '71511' = 08
   '71512' = 08
   '71513' = 08
   '71514' = 08
   '71515' = 08
   '71516' = 08
   '71517' = 08
   '71518' = 08
   '71520' = 08
   '71521' = 08
   '71522' = 08
   '71523' = 08
   '71524' = 08
   '71525' = 08
   '71526' = 08
   '71527' = 08
   '71528' = 08
   '71530' = 08
   '71531' = 08
   '71532' = 08
   '71533' = 08
   '71534' = 08
   '71535' = 08
   '71536' = 08
   '71537' = 08
   '71538' = 08
   '71580' = 08
   '71589' = 08
   '71590' = 08
   '71591' = 08
   '71592' = 08
   '71593' = 08
   '71594' = 08
   '71595' = 08
   '71596' = 08
   '71597' = 08
   '71598' = 08
   '71600' = 08
   '71601' = 08
   '71602' = 08
   '71603' = 08
   '71604' = 08
   '71605' = 08
   '71606' = 08
   '71607' = 08
   '71608' = 08
   '71609' = 08
   '71610' = 08
   '71611' = 08
   '71612' = 08
   '71613' = 08
   '71614' = 08
   '71615' = 08
   '71616' = 08
   '71617' = 08
   '71618' = 08
   '71619' = 08
   '71620' = 08
   '71621' = 08
   '71622' = 08
   '71623' = 08
   '71624' = 08
   '71625' = 08
   '71626' = 08
   '71627' = 08
   '71628' = 08
   '71629' = 08
   '71630' = 08
   '71631' = 08
   '71632' = 08
   '71633' = 08
   '71634' = 08
   '71635' = 08
   '71636' = 08
   '71637' = 08
   '71638' = 08
   '71639' = 08
   '71640' = 08
   '71641' = 08
   '71642' = 08
   '71643' = 08
   '71644' = 08
   '71645' = 08
   '71646' = 08
   '71647' = 08
   '71648' = 08
   '71649' = 08
   '71650' = 08
   '71651' = 08
   '71652' = 08
   '71653' = 08
   '71654' = 08
   '71655' = 08
   '71656' = 08
   '71657' = 08
   '71658' = 08
   '71659' = 08
   '71660' = 08
   '71661' = 08
   '71662' = 08
   '71663' = 08
   '71664' = 08
   '71665' = 08
   '71666' = 08
   '71667' = 08
   '71668' = 08
   '71680' = 08
   '71681' = 08
   '71682' = 08
   '71683' = 08
   '71684' = 08
   '71685' = 08
   '71686' = 08
   '71687' = 08
   '71688' = 08
   '71689' = 08
   '71690' = 08
   '71691' = 08
   '71692' = 08
   '71693' = 08
   '71694' = 08
   '71695' = 08
   '71696' = 08
   '71697' = 08
   '71698' = 08
   '71699' = 08
   '7170'  = 08
   '7171'  = 08
   '7172'  = 08
   '7173'  = 08
   '71740' = 08
   '71741' = 08
   '71742' = 08
   '71743' = 08
   '71749' = 08
   '7175'  = 08
   '7176'  = 08
   '7177'  = 08
   '71781' = 08
   '71782' = 08
   '71783' = 08
   '71784' = 08
   '71785' = 08
   '71789' = 08
   '7179'  = 08
   '71800' = 08
   '71801' = 08
   '71802' = 08
   '71803' = 08
   '71804' = 08
   '71805' = 08
   '71807' = 08
   '71808' = 08
   '71809' = 08
   '71810' = 08
   '71811' = 08
   '71812' = 08
   '71813' = 08
   '71814' = 08
   '71815' = 08
   '71817' = 08
   '71818' = 08
   '71819' = 08
   '71820' = 08
   '71821' = 08
   '71822' = 08
   '71823' = 08
   '71824' = 08
   '71825' = 08
   '71826' = 08
   '71827' = 08
   '71828' = 08
   '71829' = 08
   '71830' = 08
   '71831' = 08
   '71832' = 08
   '71833' = 08
   '71834' = 08
   '71835' = 08
   '71836' = 08
   '71837' = 08
   '71838' = 08
   '71839' = 08
   '71840' = 08
   '71841' = 08
   '71842' = 08
   '71843' = 08
   '71844' = 08
   '71845' = 08
   '71846' = 08
   '71847' = 08
   '71848' = 08
   '71849' = 08
   '71850' = 08
   '71851' = 08
   '71852' = 08
   '71853' = 08
   '71854' = 08
   '71855' = 08
   '71856' = 08
   '71857' = 08
   '71858' = 08
   '71859' = 08
   '71865' = 08
   '71870' = 08
   '71871' = 08
   '71872' = 08
   '71873' = 08
   '71874' = 08
   '71875' = 08
   '71876' = 08
   '71877' = 08
   '71878' = 08
   '71879' = 08
   '71880' = 08
   '71881' = 08
   '71882' = 08
   '71883' = 08
   '71884' = 08
   '71885' = 08
   '71886' = 08
   '71887' = 08
   '71888' = 08
   '71889' = 08
   '71890' = 08
   '71891' = 08
   '71892' = 08
   '71893' = 08
   '71894' = 08
   '71895' = 08
   '71897' = 08
   '71898' = 08
   '71899' = 08
   '71900' = 08
   '71901' = 08
   '71902' = 08
   '71903' = 08
   '71904' = 08
   '71905' = 08
   '71906' = 08
   '71907' = 08
   '71908' = 08
   '71909' = 08
   '71910' = 08
   '71911' = 08
   '71912' = 08
   '71913' = 08
   '71914' = 08
   '71915' = 08
   '71916' = 08
   '71917' = 08
   '71918' = 08
   '71919' = 08
   '71920' = 08
   '71921' = 08
   '71922' = 08
   '71923' = 08
   '71924' = 08
   '71925' = 08
   '71926' = 08
   '71927' = 08
   '71928' = 08
   '71929' = 08
   '71930' = 08
   '71931' = 08
   '71932' = 08
   '71933' = 08
   '71934' = 08
   '71935' = 08
   '71936' = 08
   '71937' = 08
   '71938' = 08
   '71939' = 08
   '71940' = 08
   '71941' = 08
   '71942' = 08
   '71943' = 08
   '71944' = 08
   '71945' = 08
   '71946' = 08
   '71947' = 08
   '71948' = 08
   '71949' = 08
   '71950' = 08
   '71951' = 08
   '71952' = 08
   '71953' = 08
   '71954' = 08
   '71955' = 08
   '71956' = 08
   '71957' = 08
   '71958' = 08
   '71959' = 08
   '71960' = 08
   '71961' = 08
   '71962' = 08
   '71963' = 08
   '71964' = 08
   '71965' = 08
   '71966' = 08
   '71967' = 08
   '71968' = 08
   '71969' = 08
   '7197'  = 08
   '71980' = 08
   '71981' = 08
   '71982' = 08
   '71983' = 08
   '71984' = 08
   '71985' = 08
   '71986' = 08
   '71987' = 08
   '71988' = 08
   '71989' = 08
   '71990' = 08
   '71991' = 08
   '71992' = 08
   '71993' = 08
   '71994' = 08
   '71995' = 08
   '71996' = 08
   '71997' = 08
   '71998' = 08
   '71999' = 08
   '7200'  = 08
   '7201'  = 08
   '7202'  = 08
   '72081' = 08
   '72089' = 08
   '7209'  = 08
   '7210'  = 08
   '7211'  = 08
   '7212'  = 08
   '7213'  = 08
   '72141' = 08
   '72142' = 08
   '7215'  = 08
   '7216'  = 08
   '7217'  = 08
   '7218'  = 08
   '72190' = 08
   '72191' = 08
   '7220'  = 08
   '72210' = 08
   '72211' = 08
   '7222'  = 08
   '72230' = 08
   '72231' = 08
   '72232' = 08
   '72239' = 08
   '7224'  = 08
   '72251' = 08
   '72252' = 08
   '7226'  = 08
   '72270' = 08
   '72271' = 08
   '72272' = 08
   '72273' = 08
   '72280' = 08
   '72281' = 08
   '72282' = 08
   '72283' = 08
   '72290' = 08
   '72291' = 08
   '72292' = 08
   '72293' = 08
   '7230'  = 08
   '7231'  = 08
   '7232'  = 01
   '7233'  = 01
   '7234'  = 01
   '7235'  = 08
   '7236'  = 09
   '7237'  = 08
   '7238'  = 08
   '7239'  = 08
   '72400' = 08
   '72401' = 08
   '72402' = 08
   '72403' = 08
   '72409' = 08
   '7241'  = 08
   '7242'  = 08
   '7243'  = 08
   '7244'  = 08
   '7245'  = 08
   '7246'  = 08
   '72470' = 08
   '72471' = 08
   '72479' = 08
   '7248'  = 08
   '7249'  = 08
   '725'   = 08
   '7260'  = 08
   '72610' = 08
   '72611' = 08
   '72612' = 08
   '72613' = 08
   '72619' = 08
   '7262'  = 08
   '72630' = 08
   '72631' = 08
   '72632' = 08
   '72633' = 08
   '72639' = 08
   '7264'  = 08
   '7265'  = 08
   '72660' = 08
   '72661' = 08
   '72662' = 08
   '72663' = 08
   '72664' = 08
   '72665' = 08
   '72669' = 08
   '72670' = 08
   '72671' = 08
   '72672' = 08
   '72673' = 08
   '72679' = 08
   '7268'  = 08
   '72690' = 08
   '72691' = 08
   '72700' = 08
   '72701' = 08
   '72702' = 08
   '72703' = 08
   '72704' = 08
   '72705' = 08
   '72706' = 08
   '72709' = 08
   '7271'  = 08
   '7272'  = 08
   '7273'  = 08
   '72740' = 08
   '72741' = 08
   '72742' = 08
   '72743' = 08
   '72749' = 08
   '72750' = 08
   '72751' = 08
   '72759' = 08
   '72760' = 08
   '72761' = 08
   '72762' = 08
   '72763' = 08
   '72764' = 08
   '72765' = 08
   '72766' = 08
   '72767' = 08
   '72768' = 08
   '72769' = 08
   '72781' = 08
   '72782' = 08
   '72783' = 08
   '72789' = 08
   '7279'  = 08
   '7280'  = 08
   '72810' = 08
   '72811' = 08
   '72812' = 08
   '72813' = 08
   '72819' = 08
   '7282'  = 08
   '7283'  = 08
   '7284'  = 08
   '7285'  = 08
   '7286'  = 08
   '72871' = 08
   '72879' = 08
   '72881' = 08
   '72882' = 08
   '72883' = 08
   '72884' = 08
   '72885' = 08
   '72886' = 08
   '72887' = 08
   '72888' = 08
   '72889' = 08
   '7289'  = 08
   '7290'  = 08
   '7291'  = 08
   '7292'  = 01
   '72930' = 09
   '72931' = 09
   '72939' = 09
   '7294'  = 08
   '7295'  = 08
   '7296'  = 08
   '72971' = 08
   '72972' = 08
   '72973' = 08
   '72979' = 08
   '72981' = 08
   '72982' = 08
   '72989' = 08
   '72990' = 08
   '72991' = 08
   '72992' = 08
   '72999' = 08
   '73000' = 08
   '73001' = 08
   '73002' = 08
   '73003' = 08
   '73004' = 08
   '73005' = 08
   '73006' = 08
   '73007' = 08
   '73008' = 08
   '73009' = 08
   '73010' = 08
   '73011' = 08
   '73012' = 08
   '73013' = 08
   '73014' = 08
   '73015' = 08
   '73016' = 08
   '73017' = 08
   '73018' = 08
   '73019' = 08
   '73020' = 08
   '73021' = 08
   '73022' = 08
   '73023' = 08
   '73024' = 08
   '73025' = 08
   '73026' = 08
   '73027' = 08
   '73028' = 08
   '73029' = 08
   '73030' = 08
   '73031' = 08
   '73032' = 08
   '73033' = 08
   '73034' = 08
   '73035' = 08
   '73036' = 08
   '73037' = 08
   '73038' = 08
   '73039' = 08
   '73070' = 08
   '73071' = 08
   '73072' = 08
   '73073' = 08
   '73074' = 08
   '73075' = 08
   '73076' = 08
   '73077' = 08
   '73078' = 08
   '73079' = 08
   '73080' = 08
   '73081' = 08
   '73082' = 08
   '73083' = 08
   '73084' = 08
   '73085' = 08
   '73086' = 08
   '73087' = 08
   '73088' = 08
   '73089' = 08
   '73090' = 08
   '73091' = 08
   '73092' = 08
   '73093' = 08
   '73094' = 08
   '73095' = 08
   '73096' = 08
   '73097' = 08
   '73098' = 08
   '73099' = 08
   '7310'  = 08
   '7311'  = 08
   '7312'  = 08
   '7313'  = 08
   '7318'  = 08
   '7320'  = 08
   '7321'  = 08
   '7322'  = 08
   '7323'  = 08
   '7324'  = 08
   '7325'  = 08
   '7326'  = 08
   '7327'  = 08
   '7328'  = 08
   '7329'  = 08
   '73300' = 08
   '73301' = 08
   '73302' = 08
   '73303' = 08
   '73309' = 08
   '73310' = 08
   '73311' = 08
   '73312' = 08
   '73313' = 08
   '73314' = 08
   '73315' = 08
   '73316' = 08
   '73319' = 08
   '73320' = 08
   '73321' = 08
   '73322' = 08
   '73329' = 08
   '7333'  = 08
   '73340' = 08
   '73341' = 08
   '73342' = 08
   '73343' = 08
   '73344' = 08
   '73345' = 08
   '73349' = 08
   '7335'  = 08
   '7336'  = 04
   '7337'  = 08
   '73381' = 08
   '73382' = 08
   '73390' = 08
   '73391' = 08
   '73392' = 08
   '73393' = 08
   '73394' = 08
   '73395' = 08
   '73396' = 08
   '73397' = 08
   '73398' = 08
   '73399' = 08
   '734'   = 08
   '7350'  = 08
   '7351'  = 08
   '7352'  = 08
   '7353'  = 08
   '7354'  = 08
   '7355'  = 08
   '7358'  = 08
   '7359'  = 08
   '73600' = 08
   '73601' = 08
   '73602' = 08
   '73603' = 08
   '73604' = 08
   '73605' = 01
   '73606' = 01
   '73607' = 01
   '73609' = 08
   '7361'  = 08
   '73620' = 08
   '73621' = 08
   '73622' = 08
   '73629' = 08
   '73630' = 08
   '73631' = 08
   '73632' = 08
   '73639' = 08
   '73641' = 08
   '73642' = 08
   '7365'  = 08
   '7366'  = 08
   '73670' = 08
   '73671' = 08
   '73672' = 08
   '73673' = 08
   '73674' = 01
   '73675' = 08
   '73676' = 08
   '73679' = 08
   '73681' = 08
   '73689' = 08
   '7369'  = 08
   '7370'  = 08
   '73710' = 08
   '73711' = 08
   '73712' = 08
   '73719' = 08
   '73720' = 08
   '73721' = 08
   '73722' = 08
   '73729' = 08
   '73730' = 08
   '73731' = 08
   '73732' = 08
   '73733' = 08
   '73734' = 08
   '73739' = 08
   '73740' = 08
   '73741' = 08
   '73742' = 08
   '73743' = 08
   '7378'  = 08
   '7379'  = 08
   '7380'  = 03
   '73810' = 08
   '73811' = 08
   '73812' = 08
   '73819' = 08
   '7382'  = 08
   '7383'  = 08
   '7384'  = 08
   '7385'  = 08
   '7386'  = 08
   '7387'  = 03
   '7388'  = 08
   '7389'  = 08
   '7390'  = 08
   '7391'  = 08
   '7392'  = 08
   '7393'  = 08
   '7394'  = 08
   '7395'  = 08
   '7396'  = 08
   '7397'  = 08
   '7398'  = 08
   '7399'  = 08
   '7400'  = 01
   '7401'  = 01
   '7402'  = 01
   '74100' = 01
   '74101' = 01
   '74102' = 01
   '74103' = 01
   '74190' = 01
   '74191' = 01
   '74192' = 01
   '74193' = 01
   '7420'  = 01
   '7421'  = 01
   '7422'  = 01
   '7423'  = 01
   '7424'  = 01
   '74251' = 01
   '74253' = 01
   '74259' = 01
   '7428'  = 01
   '7429'  = 01
   '74300' = 02
   '74303' = 02
   '74306' = 02
   '74310' = 02
   '74311' = 02
   '74312' = 02
   '74320' = 02
   '74321' = 02
   '74322' = 02
   '74330' = 02
   '74331' = 02
   '74332' = 02
   '74333' = 02
   '74334' = 02
   '74335' = 02
   '74336' = 02
   '74337' = 02
   '74339' = 02
   '74341' = 02
   '74342' = 02
   '74343' = 02
   '74344' = 02
   '74345' = 02
   '74346' = 02
   '74347' = 02
   '74348' = 02
   '74349' = 02
   '74351' = 02
   '74352' = 02
   '74353' = 02
   '74354' = 02
   '74355' = 02
   '74356' = 02
   '74357' = 02
   '74358' = 02
   '74359' = 02
   '74361' = 02
   '74362' = 02
   '74363' = 02
   '74364' = 02
   '74365' = 02
   '74366' = 02
   '74369' = 02
   '7438'  = 02
   '7439'  = 02
   '74400' = 03
   '74401' = 03
   '74402' = 03
   '74403' = 03
   '74404' = 03
   '74405' = 03
   '74409' = 03
   '7441'  = 03
   '74421' = 03
   '74422' = 03
   '74423' = 03
   '74424' = 03
   '74429' = 03
   '7443'  = 03
   '74441' = 03
   '74442' = 03
   '74443' = 03
   '74446' = 03
   '74447' = 03
   '74449' = 03
   '7445'  = 09
   '74481' = 03
   '74482' = 03
   '74483' = 03
   '74484' = 03
   '74489' = 03
   '7449'  = 09
   '7450'  = 05
   '74510' = 05
   '74511' = 05
   '74512' = 05
   '74519' = 05
   '7452'  = 05
   '7453'  = 05
   '7454'  = 05
   '7455'  = 05
   '74560' = 05
   '74561' = 05
   '74569' = 05
   '7457'  = 05
   '7458'  = 05
   '7459'  = 05
   '74600' = 05
   '74601' = 05
   '74602' = 05
   '74609' = 05
   '7461'  = 05
   '7462'  = 05
   '7463'  = 05
   '7464'  = 05
   '7465'  = 05
   '7466'  = 05
   '7467'  = 05
   '74681' = 05
   '74682' = 05
   '74683' = 05
   '74684' = 05
   '74685' = 05
   '74686' = 05
   '74687' = 05
   '74689' = 05
   '7469'  = 05
   '7470'  = 05
   '74710' = 05
   '74711' = 05
   '74720' = 05
   '74721' = 05
   '74722' = 05
   '74729' = 05
   '74731' = 05
   '74732' = 05
   '74739' = 05
   '74740' = 05
   '74741' = 05
   '74742' = 05
   '74749' = 05
   '7475'  = 05
   '74760' = 05
   '74761' = 05
   '74762' = 05
   '74763' = 05
   '74764' = 05
   '74769' = 05
   '74781' = 01
   '74782' = 01
   '74783' = 15
   '74789' = 05
   '7479'  = 05
   '7480'  = 03
   '7481'  = 03
   '7482'  = 03
   '7483'  = 03
   '7484'  = 04
   '7485'  = 04
   '74860' = 04
   '74861' = 04
   '74869' = 04
   '7488'  = 04
   '7489'  = 04
   '74900' = 03
   '74901' = 03
   '74902' = 03
   '74903' = 03
   '74904' = 03
   '74910' = 03
   '74911' = 03
   '74912' = 03
   '74913' = 03
   '74914' = 03
   '74920' = 03
   '74921' = 03
   '74922' = 03
   '74923' = 03
   '74924' = 03
   '74925' = 03
   '7500'  = 03
   '75010' = 03
   '75011' = 03
   '75012' = 03
   '75013' = 03
   '75015' = 03
   '75016' = 03
   '75019' = 03
   '75021' = 03
   '75022' = 03
   '75023' = 03
   '75024' = 03
   '75025' = 03
   '75026' = 03
   '75027' = 03
   '75029' = 03
   '7503'  = 06
   '7504'  = 06
   '7505'  = 06
   '7506'  = 06
   '7507'  = 06
   '7508'  = 06
   '7509'  = 06
   '7510'  = 06
   '7511'  = 06
   '7512'  = 06
   '7513'  = 06
   '7514'  = 06
   '7515'  = 06
   '75160' = 07
   '75161' = 07
   '75162' = 07
   '75169' = 07
   '7517'  = 07
   '7518'  = 06
   '7519'  = 06
   '7520'  = 13
   '75210' = 13
   '75211' = 13
   '75219' = 13
   '7522'  = 13
   '75231' = 13
   '75232' = 13
   '75233' = 13
   '75234' = 13
   '75235' = 13
   '75236' = 13
   '75239' = 13
   '75240' = 13
   '75241' = 13
   '75242' = 13
   '75243' = 13
   '75244' = 13
   '75245' = 13
   '75246' = 13
   '75247' = 13
   '75249' = 13
   '75251' = 12
   '75252' = 12
   '75261' = 12
   '75262' = 12
   '75263' = 12
   '75264' = 12
   '75265' = 12
   '75269' = 12
   '7527'  = 12
   '75281' = 12
   '75289' = 12
   '7529'  = 12
   '7530'  = 11
   '75310' = 11
   '75311' = 11
   '75312' = 11
   '75313' = 11
   '75314' = 11
   '75315' = 11
   '75316' = 11
   '75317' = 11
   '75319' = 11
   '75320' = 11
   '75321' = 11
   '75322' = 11
   '75323' = 11
   '75329' = 11
   '7533'  = 11
   '7534'  = 11
   '7535'  = 11
   '7536'  = 11
   '7537'  = 11
   '7538'  = 11
   '7539'  = 11
   '7540'  = 08
   '7541'  = 08
   '7542'  = 08
   '75430' = 08
   '75431' = 08
   '75432' = 08
   '75433' = 08
   '75435' = 08
   '75440' = 08
   '75441' = 08
   '75442' = 08
   '75443' = 08
   '75444' = 08
   '75450' = 08
   '75451' = 08
   '75452' = 08
   '75453' = 08
   '75459' = 08
   '75460' = 08
   '75461' = 08
   '75462' = 08
   '75469' = 08
   '75470' = 08
   '75471' = 08
   '75479' = 08
   '75481' = 04
   '75482' = 04
   '75489' = 08
   '75500' = 08
   '75501' = 08
   '75502' = 08
   '75510' = 08
   '75511' = 08
   '75512' = 08
   '75513' = 08
   '75514' = 08
   '75520' = 08
   '75521' = 08
   '75522' = 08
   '75523' = 08
   '75524' = 08
   '75525' = 08
   '75526' = 08
   '75527' = 08
   '75528' = 08
   '75529' = 08
   '75530' = 08
   '75531' = 08
   '75532' = 08
   '75533' = 08
   '75534' = 08
   '75535' = 08
   '75536' = 08
   '75537' = 08
   '75538' = 08
   '75539' = 08
   '7554'  = 08
   '75550' = 08
   '75551' = 08
   '75552' = 08
   '75553' = 08
   '75554' = 08
   '75555' = 08
   '75556' = 08
   '75557' = 08
   '75558' = 08
   '75559' = 08
   '75560' = 08
   '75561' = 08
   '75562' = 08
   '75563' = 08
   '75564' = 08
   '75565' = 08
   '75566' = 08
   '75567' = 08
   '75569' = 08
   '7558'  = 08
   '7559'  = 08
   '7560'  = 08
   '75610' = 08
   '75611' = 08
   '75612' = 08
   '75613' = 08
   '75614' = 08
   '75615' = 08
   '75616' = 08
   '75617' = 01
   '75619' = 08
   '7562'  = 08
   '7563'  = 04
   '7564'  = 08
   '75650' = 08
   '75651' = 08
   '75652' = 08
   '75653' = 08
   '75654' = 08
   '75655' = 08
   '75656' = 08
   '75659' = 08
   '7566'  = 04
   '75670' = 06
   '75671' = 06
   '75672' = 06
   '75673' = 06
   '75679' = 06
   '75681' = 08
   '75682' = 08
   '75683' = 08
   '75689' = 08
   '7569'  = 08
   '7570'  = 09
   '7571'  = 09
   '7572'  = 09
   '75731' = 09
   '75732' = 09
   '75733' = 09
   '75739' = 09
   '7574'  = 09
   '7575'  = 09
   '7576'  = 09
   '7578'  = 09
   '7579'  = 09
   '7580'  = 19
   '7581'  = 19
   '7582'  = 19
   '75831' = 19
   '75832' = 19
   '75833' = 19
   '75839' = 19
   '7584'  = 23
   '7585'  = 23
   '7586'  = 12
   '7587'  = 12
   '75881' = 12
   '75889' = 12
   '7589'  = 23
   '7590'  = 16
   '7591'  = 10
   '7592'  = 10
   '7593'  = 06
   '7594'  = 06
   '7595'  = 01
   '7596'  = 17
   '7597'  = 08
   '75981' = 08
   '75982' = 05
   '75983' = 19
   '75989' = 08
   '7599'  = 23
   '7600'  = 15
   '7601'  = 15
   '7602'  = 15
   '7603'  = 15
   '7604'  = 15
   '7605'  = 15
   '76061' = 15
   '76062' = 15
   '76063' = 15
   '76064' = 15
   '76070' = 15
   '76071' = 15
   '76072' = 15
   '76073' = 15
   '76074' = 15
   '76075' = 15
   '76076' = 15
   '76077' = 15
   '76078' = 15
   '76079' = 15
   '7608'  = 15
   '7609'  = 15
   '7610'  = 15
   '7611'  = 15
   '7612'  = 15
   '7613'  = 15
   '7614'  = 15
   '7615'  = 15
   '7616'  = 15
   '7617'  = 15
   '7618'  = 15
   '7619'  = 15
   '7620'  = 15
   '7621'  = 15
   '7622'  = 15
   '7623'  = 15
   '7624'  = 15
   '7625'  = 15
   '7626'  = 15
   '7627'  = 15
   '7628'  = 15
   '7629'  = 15
   '7630'  = 15
   '7631'  = 15
   '7632'  = 15
   '7633'  = 15
   '7634'  = 15
   '7635'  = 15
   '7636'  = 15
   '7637'  = 15
   '76381' = 15
   '76382' = 15
   '76383' = 15
   '76384' = 15
   '76389' = 15
   '7639'  = 15
   '76400' = 15
   '76401' = 15
   '76402' = 15
   '76403' = 15
   '76404' = 15
   '76405' = 15
   '76406' = 15
   '76407' = 15
   '76408' = 15
   '76409' = 15
   '76410' = 15
   '76411' = 15
   '76412' = 15
   '76413' = 15
   '76414' = 15
   '76415' = 15
   '76416' = 15
   '76417' = 15
   '76418' = 15
   '76419' = 15
   '76420' = 15
   '76421' = 15
   '76422' = 15
   '76423' = 15
   '76424' = 15
   '76425' = 15
   '76426' = 15
   '76427' = 15
   '76428' = 15
   '76429' = 15
   '76490' = 15
   '76491' = 15
   '76492' = 15
   '76493' = 15
   '76494' = 15
   '76495' = 15
   '76496' = 15
   '76497' = 15
   '76498' = 15
   '76499' = 15
   '76500' = 15
   '76501' = 15
   '76502' = 15
   '76503' = 15
   '76504' = 15
   '76505' = 15
   '76506' = 15
   '76507' = 15
   '76508' = 15
   '76509' = 15
   '76510' = 15
   '76511' = 15
   '76512' = 15
   '76513' = 15
   '76514' = 15
   '76515' = 15
   '76516' = 15
   '76517' = 15
   '76518' = 15
   '76519' = 15
   '76520' = 15
   '76521' = 15
   '76522' = 15
   '76523' = 15
   '76524' = 15
   '76525' = 15
   '76526' = 15
   '76527' = 15
   '76528' = 15
   '76529' = 15
   '7660'  = 15
   '7661'  = 15
   '76621' = 15
   '76622' = 15
   '7670'  = 15
   '76711' = 15
   '76719' = 15
   '7672'  = 15
   '7673'  = 15
   '7674'  = 15
   '7675'  = 15
   '7676'  = 15
   '7677'  = 15
   '7678'  = 15
   '7679'  = 15
   '7680'  = 15
   '7681'  = 15
   '7682'  = 15
   '7683'  = 15
   '7684'  = 15
   '7685'  = 15
   '7686'  = 15
   '76870' = 15
   '76871' = 15
   '76872' = 15
   '76873' = 15
   '7689'  = 15
   '769'   = 15
   '7700'  = 15
   '77010' = 15
   '77011' = 15
   '77012' = 15
   '77013' = 15
   '77014' = 15
   '77015' = 15
   '77016' = 15
   '77017' = 15
   '77018' = 15
   '7702'  = 15
   '7703'  = 15
   '7704'  = 15
   '7705'  = 15
   '7706'  = 15
   '7707'  = 04
   '77081' = 15
   '77082' = 15
   '77083' = 15
   '77084' = 15
   '77085' = 15
   '77086' = 15
   '77087' = 15
   '77088' = 15
   '77089' = 15
   '7709'  = 15
   '7710'  = 15
   '7711'  = 15
   '7712'  = 15
   '7713'  = 15
   '7714'  = 15
   '7715'  = 15
   '7716'  = 15
   '7717'  = 15
   '77181' = 15
   '77182' = 15
   '77183' = 15
   '77189' = 15
   '7720'  = 15
   '77210' = 15
   '77211' = 15
   '77212' = 15
   '77213' = 15
   '77214' = 15
   '7722'  = 15
   '7723'  = 15
   '7724'  = 15
   '7725'  = 15
   '7726'  = 15
   '7728'  = 15
   '7729'  = 15
   '7730'  = 15
   '7731'  = 15
   '7732'  = 15
   '7733'  = 15
   '7734'  = 15
   '7735'  = 15
   '7740'  = 15
   '7741'  = 15
   '7742'  = 15
   '77430' = 15
   '77431' = 15
   '77439' = 15
   '7744'  = 15
   '7745'  = 15
   '7746'  = 15
   '7747'  = 15
   '7750'  = 15
   '7751'  = 15
   '7752'  = 15
   '7753'  = 15
   '7754'  = 15
   '7755'  = 15
   '7756'  = 15
   '7757'  = 15
   '77581' = 15
   '77589' = 15
   '7759'  = 15
   '7760'  = 15
   '7761'  = 15
   '7762'  = 15
   '7763'  = 15
   '7764'  = 15
   '7765'  = 15
   '7766'  = 15
   '7767'  = 15
   '7768'  = 15
   '7769'  = 15
   '7771'  = 15
   '7772'  = 15
   '7773'  = 15
   '7774'  = 15
   '77750' = 15
   '77751' = 15
   '77752' = 15
   '77753' = 15
   '7776'  = 15
   '7778'  = 15
   '7779'  = 15
   '7780'  = 15
   '7781'  = 15
   '7782'  = 15
   '7783'  = 15
   '7784'  = 15
   '7785'  = 15
   '7786'  = 15
   '7787'  = 15
   '7788'  = 15
   '7789'  = 15
   '7790'  = 15
   '7791'  = 15
   '7792'  = 15
   '77931' = 15
   '77932' = 15
   '77933' = 15
   '77934' = 10
   '7794'  = 15
   '7795'  = 15
   '7796'  = 15
   '7797'  = 01
   '77981' = 15
   '77982' = 15
   '77983' = 15
   '77984' = 15
   '77985' = 15
   '77989' = 15
   '7799'  = 15
   '78001' = 01
   '78002' = 19
   '78003' = 01
   '78009' = 01
   '7801'  = 19
   '7802'  = 05
   '78031' = 01
   '78032' = 01
   '78033' = 01
   '78039' = 01
   '7804'  = 03
   '78050' = 19
   '78051' = 03
   '78052' = 19
   '78053' = 03
   '78054' = 19
   '78055' = 19
   '78056' = 19
   '78057' = 03
   '78058' = 19
   '78059' = 19
   '78060' = 18
   '78061' = 18
   '78062' = 18
   '78063' = 18
   '78064' = 23
   '78065' = 23
   '78066' = 18
   '78071' = 23
   '78072' = 01
   '78079' = 23
   '7808'  = 09
   '78091' = 23
   '78092' = 23
   '78093' = 23
   '78094' = 23
   '78095' = 23
   '78096' = 23
   '78097' = 23
   '78099' = 23
   '7810'  = 01
   '7811'  = 01
   '7812'  = 01
   '7813'  = 01
   '7814'  = 01
   '7815'  = 04
   '7816'  = 01
   '7817'  = 10
   '7818'  = 01
   '78191' = 01
   '78192' = 01
   '78193' = 08
   '78194' = 01
   '78199' = 01
   '7820'  = 01
   '7821'  = 09
   '7822'  = 09
   '7823'  = 23
   '7824'  = 07
   '7825'  = 23
   '78261' = 23
   '78262' = 23
   '7827'  = 16
   '7828'  = 09
   '7829'  = 09
   '7830'  = 10
   '7831'  = 10
   '78321' = 10
   '78322' = 10
   '7833'  = 10
   '78340' = 10
   '78341' = 10
   '78342' = 10
   '78343' = 10
   '7835'  = 10
   '7836'  = 10
   '7837'  = 10
   '7839'  = 10
   '7840'  = 01
   '7841'  = 03
   '7842'  = 09
   '7843'  = 01
   '78440' = 03
   '78441' = 03
   '78442' = 03
   '78443' = 03
   '78444' = 03
   '78449' = 03
   '78451' = 01
   '78452' = 01
   '78459' = 01
   '78460' = 19
   '78461' = 19
   '78469' = 19
   '7847'  = 03
   '7848'  = 03
   '78491' = 03
   '78492' = 03
   '78499' = 03
   '7850'  = 05
   '7851'  = 05
   '7852'  = 05
   '7853'  = 05
   '7854'  = 05
   '78550' = 05
   '78551' = 05
   '78552' = 18
   '78559' = 18
   '7856'  = 16
   '7859'  = 05
   '78600' = 04
   '78601' = 04
   '78602' = 04
   '78603' = 04
   '78604' = 04
   '78605' = 04
   '78606' = 04
   '78607' = 04
   '78609' = 04
   '7861'  = 04
   '7862'  = 04
   '78630' = 04
   '78631' = 04
   '78639' = 04
   '7864'  = 04
   '78650' = 05
   '78651' = 05
   '78652' = 04
   '78659' = 05
   '7866'  = 04
   '7867'  = 04
   '7868'  = 04
   '7869'  = 04
   '78701' = 06
   '78702' = 06
   '78703' = 06
   '78704' = 06
   '7871'  = 06
   '78720' = 06
   '78721' = 06
   '78722' = 06
   '78723' = 06
   '78724' = 06
   '78729' = 06
   '7873'  = 06
   '7874'  = 06
   '7875'  = 06
   '78760' = 06
   '78761' = 06
   '78762' = 06
   '78763' = 06
   '7877'  = 06
   '78791' = 06
   '78799' = 06
   '7880'  = 11
   '7881'  = 11
   '78820' = 11
   '78821' = 11
   '78829' = 11
   '78830' = 11
   '78831' = 11
   '78832' = 11
   '78833' = 11
   '78834' = 11
   '78835' = 11
   '78836' = 11
   '78837' = 11
   '78838' = 11
   '78839' = 11
   '78841' = 11
   '78842' = 11
   '78843' = 11
   '7885'  = 11
   '78861' = 11
   '78862' = 11
   '78863' = 11
   '78864' = 11
   '78865' = 11
   '78869' = 11
   '7887'  = 11
   '7888'  = 11
   '78891' = 11
   '78899' = 11
   '78900' = 06
   '78901' = 06
   '78902' = 06
   '78903' = 06
   '78904' = 06
   '78905' = 06
   '78906' = 06
   '78907' = 06
   '78909' = 06
   '7891'  = 07
   '7892'  = 16
   '78930' = 06
   '78931' = 06
   '78932' = 06
   '78933' = 06
   '78934' = 06
   '78935' = 06
   '78936' = 06
   '78937' = 06
   '78939' = 06
   '78940' = 06
   '78941' = 06
   '78942' = 06
   '78943' = 06
   '78944' = 06
   '78945' = 06
   '78946' = 06
   '78947' = 06
   '78949' = 06
   '78951' = 23
   '78959' = 23
   '78960' = 06
   '78961' = 06
   '78962' = 06
   '78963' = 06
   '78964' = 06
   '78965' = 06
   '78966' = 06
   '78967' = 06
   '78969' = 06
   '7897'  = 06
   '7899'  = 06
   '79001' = 16
   '79009' = 16
   '7901'  = 23
   '79021' = 10
   '79022' = 10
   '79029' = 10
   '7903'  = 20
   '7904'  = 23
   '7905'  = 23
   '7906'  = 23
   '7907'  = 18
   '7908'  = 18
   '79091' = 23
   '79092' = 23
   '79093' = 23
   '79094' = 23
   '79095' = 23
   '79099' = 23
   '7910'  = 11
   '7911'  = 11
   '7912'  = 11
   '7913'  = 23
   '7914'  = 07
   '7915'  = 10
   '7916'  = 10
   '7917'  = 11
   '7919'  = 11
   '7920'  = 01
   '7921'  = 06
   '7922'  = 12
   '7923'  = 14
   '7924'  = 03
   '7925'  = 23
   '7929'  = 23
   '7930'  = 01
   '79311' = 04
   '79319' = 04
   '7932'  = 05
   '7933'  = 07
   '7934'  = 06
   '7935'  = 11
   '7936'  = 06
   '7937'  = 08
   '79380' = 09
   '79381' = 09
   '79382' = 09
   '79389' = 09
   '79391' = 23
   '79399' = 23
   '79400' = 01
   '79401' = 01
   '79402' = 01
   '79409' = 01
   '79410' = 01
   '79411' = 02
   '79412' = 02
   '79413' = 02
   '79414' = 02
   '79415' = 03
   '79416' = 03
   '79417' = 08
   '79419' = 01
   '7942'  = 04
   '79430' = 05
   '79431' = 05
   '79439' = 05
   '7944'  = 11
   '7945'  = 10
   '7946'  = 10
   '7947'  = 10
   '7948'  = 07
   '7949'  = 11
   '79500' = 13
   '79501' = 13
   '79502' = 13
   '79503' = 13
   '79504' = 13
   '79505' = 13
   '79506' = 13
   '79507' = 13
   '79508' = 13
   '79509' = 13
   '79510' = 13
   '79511' = 13
   '79512' = 13
   '79513' = 13
   '79514' = 13
   '79515' = 13
   '79516' = 13
   '79518' = 13
   '79519' = 13
   '7952'  = 23
   '79531' = 18
   '79539' = 18
   '7954'  = 23
   '79551' = 04
   '79552' = 04
   '7956'  = 08
   '79571' = 16
   '79579' = 16
   '79581' = 23
   '79582' = 23
   '79589' = 23
   '7960'  = 21
   '7961'  = 01
   '7962'  = 05
   '7963'  = 05
   '7964'  = 23
   '7965'  = 14
   '7966'  = 23
   '79670' = 06
   '79671' = 06
   '79672' = 06
   '79673' = 06
   '79674' = 06
   '79675' = 06
   '79676' = 06
   '79677' = 06
   '79678' = 06
   '79679' = 06
   '7969'  = 23
   '797'   = 19
   '7980'  = 01
   '7981'  = 05
   '7982'  = 05
   '7989'  = 23
   '79901' = 04
   '79902' = 04
   '7991'  = 04
   '79921' = 19
   '79922' = 19
   '79923' = 19
   '79924' = 19
   '79925' = 19
   '79929' = 19
   '7993'  = 23
   '7994'  = 23
   '79951' = 19
   '79952' = 19
   '79953' = 01
   '79954' = 19
   '79955' = 19
   '79959' = 19
   '79981' = 23
   '79982' = 23
   '79989' = 23
   '7999'  = 23
   '80000' = 01
   '80001' = 01
   '80002' = 01
   '80003' = 01
   '80004' = 01
   '80005' = 01
   '80006' = 01
   '80009' = 01
   '80010' = 01
   '80011' = 01
   '80012' = 01
   '80013' = 01
   '80014' = 01
   '80015' = 01
   '80016' = 01
   '80019' = 01
   '80020' = 01
   '80021' = 01
   '80022' = 01
   '80023' = 01
   '80024' = 01
   '80025' = 01
   '80026' = 01
   '80029' = 01
   '80030' = 01
   '80031' = 01
   '80032' = 01
   '80033' = 01
   '80034' = 01
   '80035' = 01
   '80036' = 01
   '80039' = 01
   '80040' = 01
   '80041' = 01
   '80042' = 01
   '80043' = 01
   '80044' = 01
   '80045' = 01
   '80046' = 01
   '80049' = 01
   '80050' = 01
   '80051' = 01
   '80052' = 01
   '80053' = 01
   '80054' = 01
   '80055' = 01
   '80056' = 01
   '80059' = 01
   '80060' = 01
   '80061' = 01
   '80062' = 01
   '80063' = 01
   '80064' = 01
   '80065' = 01
   '80066' = 01
   '80069' = 01
   '80070' = 01
   '80071' = 01
   '80072' = 01
   '80073' = 01
   '80074' = 01
   '80075' = 01
   '80076' = 01
   '80079' = 01
   '80080' = 01
   '80081' = 01
   '80082' = 01
   '80083' = 01
   '80084' = 01
   '80085' = 01
   '80086' = 01
   '80089' = 01
   '80090' = 01
   '80091' = 01
   '80092' = 01
   '80093' = 01
   '80094' = 01
   '80095' = 01
   '80096' = 01
   '80099' = 01
   '80100' = 01
   '80101' = 01
   '80102' = 01
   '80103' = 01
   '80104' = 01
   '80105' = 01
   '80106' = 01
   '80109' = 01
   '80110' = 01
   '80111' = 01
   '80112' = 01
   '80113' = 01
   '80114' = 01
   '80115' = 01
   '80116' = 01
   '80119' = 01
   '80120' = 01
   '80121' = 01
   '80122' = 01
   '80123' = 01
   '80124' = 01
   '80125' = 01
   '80126' = 01
   '80129' = 01
   '80130' = 01
   '80131' = 01
   '80132' = 01
   '80133' = 01
   '80134' = 01
   '80135' = 01
   '80136' = 01
   '80139' = 01
   '80140' = 01
   '80141' = 01
   '80142' = 01
   '80143' = 01
   '80144' = 01
   '80145' = 01
   '80146' = 01
   '80149' = 01
   '80150' = 01
   '80151' = 01
   '80152' = 01
   '80153' = 01
   '80154' = 01
   '80155' = 01
   '80156' = 01
   '80159' = 01
   '80160' = 01
   '80161' = 01
   '80162' = 01
   '80163' = 01
   '80164' = 01
   '80165' = 01
   '80166' = 01
   '80169' = 01
   '80170' = 01
   '80171' = 01
   '80172' = 01
   '80173' = 01
   '80174' = 01
   '80175' = 01
   '80176' = 01
   '80179' = 01
   '80180' = 01
   '80181' = 01
   '80182' = 01
   '80183' = 01
   '80184' = 01
   '80185' = 01
   '80186' = 01
   '80189' = 01
   '80190' = 01
   '80191' = 01
   '80192' = 01
   '80193' = 01
   '80194' = 01
   '80195' = 01
   '80196' = 01
   '80199' = 01
   '8020'  = 03
   '8021'  = 03
   '80220' = 03
   '80221' = 03
   '80222' = 03
   '80223' = 03
   '80224' = 03
   '80225' = 03
   '80226' = 03
   '80227' = 03
   '80228' = 03
   '80229' = 03
   '80230' = 03
   '80231' = 03
   '80232' = 03
   '80233' = 03
   '80234' = 03
   '80235' = 03
   '80236' = 03
   '80237' = 03
   '80238' = 03
   '80239' = 03
   '8024'  = 03
   '8025'  = 03
   '8026'  = 02
   '8027'  = 02
   '8028'  = 08
   '8029'  = 08
   '80300' = 01
   '80301' = 01
   '80302' = 01
   '80303' = 01
   '80304' = 01
   '80305' = 01
   '80306' = 01
   '80309' = 01
   '80310' = 01
   '80311' = 01
   '80312' = 01
   '80313' = 01
   '80314' = 01
   '80315' = 01
   '80316' = 01
   '80319' = 01
   '80320' = 01
   '80321' = 01
   '80322' = 01
   '80323' = 01
   '80324' = 01
   '80325' = 01
   '80326' = 01
   '80329' = 01
   '80330' = 01
   '80331' = 01
   '80332' = 01
   '80333' = 01
   '80334' = 01
   '80335' = 01
   '80336' = 01
   '80339' = 01
   '80340' = 01
   '80341' = 01
   '80342' = 01
   '80343' = 01
   '80344' = 01
   '80345' = 01
   '80346' = 01
   '80349' = 01
   '80350' = 01
   '80351' = 01
   '80352' = 01
   '80353' = 01
   '80354' = 01
   '80355' = 01
   '80356' = 01
   '80359' = 01
   '80360' = 01
   '80361' = 01
   '80362' = 01
   '80363' = 01
   '80364' = 01
   '80365' = 01
   '80366' = 01
   '80369' = 01
   '80370' = 01
   '80371' = 01
   '80372' = 01
   '80373' = 01
   '80374' = 01
   '80375' = 01
   '80376' = 01
   '80379' = 01
   '80380' = 01
   '80381' = 01
   '80382' = 01
   '80383' = 01
   '80384' = 01
   '80385' = 01
   '80386' = 01
   '80389' = 01
   '80390' = 01
   '80391' = 01
   '80392' = 01
   '80393' = 01
   '80394' = 01
   '80395' = 01
   '80396' = 01
   '80399' = 01
   '80400' = 01
   '80401' = 01
   '80402' = 01
   '80403' = 01
   '80404' = 01
   '80405' = 01
   '80406' = 01
   '80409' = 01
   '80410' = 01
   '80411' = 01
   '80412' = 01
   '80413' = 01
   '80414' = 01
   '80415' = 01
   '80416' = 01
   '80419' = 01
   '80420' = 01
   '80421' = 01
   '80422' = 01
   '80423' = 01
   '80424' = 01
   '80425' = 01
   '80426' = 01
   '80429' = 01
   '80430' = 01
   '80431' = 01
   '80432' = 01
   '80433' = 01
   '80434' = 01
   '80435' = 01
   '80436' = 01
   '80439' = 01
   '80440' = 01
   '80441' = 01
   '80442' = 01
   '80443' = 01
   '80444' = 01
   '80445' = 01
   '80446' = 01
   '80449' = 01
   '80450' = 01
   '80451' = 01
   '80452' = 01
   '80453' = 01
   '80454' = 01
   '80455' = 01
   '80456' = 01
   '80459' = 01
   '80460' = 01
   '80461' = 01
   '80462' = 01
   '80463' = 01
   '80464' = 01
   '80465' = 01
   '80466' = 01
   '80469' = 01
   '80470' = 01
   '80471' = 01
   '80472' = 01
   '80473' = 01
   '80474' = 01
   '80475' = 01
   '80476' = 01
   '80479' = 01
   '80480' = 01
   '80481' = 01
   '80482' = 01
   '80483' = 01
   '80484' = 01
   '80485' = 01
   '80486' = 01
   '80489' = 01
   '80490' = 01
   '80491' = 01
   '80492' = 01
   '80493' = 01
   '80494' = 01
   '80495' = 01
   '80496' = 01
   '80499' = 01
   '80500' = 08
   '80501' = 08
   '80502' = 08
   '80503' = 08
   '80504' = 08
   '80505' = 08
   '80506' = 08
   '80507' = 08
   '80508' = 08
   '80510' = 08
   '80511' = 08
   '80512' = 08
   '80513' = 08
   '80514' = 08
   '80515' = 08
   '80516' = 08
   '80517' = 08
   '80518' = 08
   '8052'  = 08
   '8053'  = 08
   '8054'  = 08
   '8055'  = 08
   '8056'  = 08
   '8057'  = 08
   '8058'  = 08
   '8059'  = 08
   '80600' = 01
   '80601' = 01
   '80602' = 01
   '80603' = 01
   '80604' = 01
   '80605' = 01
   '80606' = 01
   '80607' = 01
   '80608' = 01
   '80609' = 01
   '80610' = 01
   '80611' = 01
   '80612' = 01
   '80613' = 01
   '80614' = 01
   '80615' = 01
   '80616' = 01
   '80617' = 01
   '80618' = 01
   '80619' = 01
   '80620' = 01
   '80621' = 01
   '80622' = 01
   '80623' = 01
   '80624' = 01
   '80625' = 01
   '80626' = 01
   '80627' = 01
   '80628' = 01
   '80629' = 01
   '80630' = 01
   '80631' = 01
   '80632' = 01
   '80633' = 01
   '80634' = 01
   '80635' = 01
   '80636' = 01
   '80637' = 01
   '80638' = 01
   '80639' = 01
   '8064'  = 01
   '8065'  = 01
   '80660' = 01
   '80661' = 01
   '80662' = 01
   '80669' = 01
   '80670' = 01
   '80671' = 01
   '80672' = 01
   '80679' = 01
   '8068'  = 01
   '8069'  = 01
   '80700' = 04
   '80701' = 04
   '80702' = 04
   '80703' = 04
   '80704' = 04
   '80705' = 04
   '80706' = 04
   '80707' = 04
   '80708' = 04
   '80709' = 04
   '80710' = 04
   '80711' = 04
   '80712' = 04
   '80713' = 04
   '80714' = 04
   '80715' = 04
   '80716' = 04
   '80717' = 04
   '80718' = 04
   '80719' = 04
   '8072'  = 04
   '8073'  = 04
   '8074'  = 04
   '8075'  = 03
   '8076'  = 03
   '8080'  = 08
   '8081'  = 08
   '8082'  = 08
   '8083'  = 08
   '80841' = 08
   '80842' = 08
   '80843' = 08
   '80844' = 08
   '80849' = 08
   '80851' = 08
   '80852' = 08
   '80853' = 08
   '80854' = 08
   '80859' = 08
   '8088'  = 08
   '8089'  = 08
   '8090'  = 08
   '8091'  = 08
   '81000' = 08
   '81001' = 08
   '81002' = 08
   '81003' = 08
   '81010' = 08
   '81011' = 08
   '81012' = 08
   '81013' = 08
   '81100' = 08
   '81101' = 08
   '81102' = 08
   '81103' = 08
   '81109' = 08
   '81110' = 08
   '81111' = 08
   '81112' = 08
   '81113' = 08
   '81119' = 08
   '81200' = 08
   '81201' = 08
   '81202' = 08
   '81203' = 08
   '81209' = 08
   '81210' = 08
   '81211' = 08
   '81212' = 08
   '81213' = 08
   '81219' = 08
   '81220' = 08
   '81221' = 08
   '81230' = 08
   '81231' = 08
   '81240' = 08
   '81241' = 08
   '81242' = 08
   '81243' = 08
   '81244' = 08
   '81249' = 08
   '81250' = 08
   '81251' = 08
   '81252' = 08
   '81253' = 08
   '81254' = 08
   '81259' = 08
   '81300' = 08
   '81301' = 08
   '81302' = 08
   '81303' = 08
   '81304' = 08
   '81305' = 08
   '81306' = 08
   '81307' = 08
   '81308' = 08
   '81310' = 08
   '81311' = 08
   '81312' = 08
   '81313' = 08
   '81314' = 08
   '81315' = 08
   '81316' = 08
   '81317' = 08
   '81318' = 08
   '81320' = 08
   '81321' = 08
   '81322' = 08
   '81323' = 08
   '81330' = 08
   '81331' = 08
   '81332' = 08
   '81333' = 08
   '81340' = 08
   '81341' = 08
   '81342' = 08
   '81343' = 08
   '81344' = 08
   '81345' = 08
   '81346' = 08
   '81347' = 08
   '81350' = 08
   '81351' = 08
   '81352' = 08
   '81353' = 08
   '81354' = 08
   '81380' = 08
   '81381' = 08
   '81382' = 08
   '81383' = 08
   '81390' = 08
   '81391' = 08
   '81392' = 08
   '81393' = 08
   '81400' = 08
   '81401' = 08
   '81402' = 08
   '81403' = 08
   '81404' = 08
   '81405' = 08
   '81406' = 08
   '81407' = 08
   '81408' = 08
   '81409' = 08
   '81410' = 08
   '81411' = 08
   '81412' = 08
   '81413' = 08
   '81414' = 08
   '81415' = 08
   '81416' = 08
   '81417' = 08
   '81418' = 08
   '81419' = 08
   '81500' = 08
   '81501' = 08
   '81502' = 08
   '81503' = 08
   '81504' = 08
   '81509' = 08
   '81510' = 08
   '81511' = 08
   '81512' = 08
   '81513' = 08
   '81514' = 08
   '81519' = 08
   '81600' = 08
   '81601' = 08
   '81602' = 08
   '81603' = 08
   '81610' = 08
   '81611' = 08
   '81612' = 08
   '81613' = 08
   '8170'  = 08
   '8171'  = 08
   '8180'  = 08
   '8181'  = 08
   '8190'  = 21
   '8191'  = 21
   '82000' = 08
   '82001' = 08
   '82002' = 08
   '82003' = 08
   '82009' = 08
   '82010' = 08
   '82011' = 08
   '82012' = 08
   '82013' = 08
   '82019' = 08
   '82020' = 08
   '82021' = 08
   '82022' = 08
   '82030' = 08
   '82031' = 08
   '82032' = 08
   '8208'  = 08
   '8209'  = 08
   '82100' = 08
   '82101' = 08
   '82110' = 08
   '82111' = 08
   '82120' = 08
   '82121' = 08
   '82122' = 08
   '82123' = 08
   '82129' = 08
   '82130' = 08
   '82131' = 08
   '82132' = 08
   '82133' = 08
   '82139' = 08
   '8220'  = 08
   '8221'  = 08
   '82300' = 08
   '82301' = 08
   '82302' = 08
   '82310' = 08
   '82311' = 08
   '82312' = 08
   '82320' = 08
   '82321' = 08
   '82322' = 08
   '82330' = 08
   '82331' = 08
   '82332' = 08
   '82340' = 08
   '82341' = 08
   '82342' = 08
   '82380' = 08
   '82381' = 08
   '82382' = 08
   '82390' = 08
   '82391' = 08
   '82392' = 08
   '8240'  = 08
   '8241'  = 08
   '8242'  = 08
   '8243'  = 08
   '8244'  = 08
   '8245'  = 08
   '8246'  = 08
   '8247'  = 08
   '8248'  = 08
   '8249'  = 08
   '8250'  = 08
   '8251'  = 08
   '82520' = 08
   '82521' = 08
   '82522' = 08
   '82523' = 08
   '82524' = 08
   '82525' = 08
   '82529' = 08
   '82530' = 08
   '82531' = 08
   '82532' = 08
   '82533' = 08
   '82534' = 08
   '82535' = 08
   '82539' = 08
   '8260'  = 08
   '8261'  = 08
   '8270'  = 08
   '8271'  = 08
   '8280'  = 21
   '8281'  = 21
   '8290'  = 08
   '8291'  = 08
   '8300'  = 03
   '8301'  = 03
   '83100' = 08
   '83101' = 08
   '83102' = 08
   '83103' = 08
   '83104' = 08
   '83109' = 08
   '83110' = 08
   '83111' = 08
   '83112' = 08
   '83113' = 08
   '83114' = 08
   '83119' = 08
   '83200' = 08
   '83201' = 08
   '83202' = 08
   '83203' = 08
   '83204' = 08
   '83209' = 08
   '83210' = 08
   '83211' = 08
   '83212' = 08
   '83213' = 08
   '83214' = 08
   '83219' = 08
   '8322'  = 08
   '83300' = 08
   '83301' = 08
   '83302' = 08
   '83303' = 08
   '83304' = 08
   '83305' = 08
   '83309' = 08
   '83310' = 08
   '83311' = 08
   '83312' = 08
   '83313' = 08
   '83314' = 08
   '83315' = 08
   '83319' = 08
   '83400' = 08
   '83401' = 08
   '83402' = 08
   '83410' = 08
   '83411' = 08
   '83412' = 08
   '83500' = 08
   '83501' = 08
   '83502' = 08
   '83503' = 08
   '83510' = 08
   '83511' = 08
   '83512' = 08
   '83513' = 08
   '8360'  = 08
   '8361'  = 08
   '8362'  = 08
   '8363'  = 08
   '8364'  = 08
   '83650' = 08
   '83651' = 08
   '83652' = 08
   '83653' = 08
   '83654' = 08
   '83659' = 08
   '83660' = 08
   '83661' = 08
   '83662' = 08
   '83663' = 08
   '83664' = 08
   '83669' = 08
   '8370'  = 08
   '8371'  = 08
   '83800' = 08
   '83801' = 08
   '83802' = 08
   '83803' = 08
   '83804' = 08
   '83805' = 08
   '83806' = 08
   '83809' = 08
   '83810' = 08
   '83811' = 08
   '83812' = 08
   '83813' = 08
   '83814' = 08
   '83815' = 08
   '83816' = 08
   '83819' = 08
   '83900' = 08
   '83901' = 08
   '83902' = 08
   '83903' = 08
   '83904' = 08
   '83905' = 08
   '83906' = 08
   '83907' = 08
   '83908' = 08
   '83910' = 08
   '83911' = 08
   '83912' = 08
   '83913' = 08
   '83914' = 08
   '83915' = 08
   '83916' = 08
   '83917' = 08
   '83918' = 08
   '83920' = 08
   '83921' = 08
   '83930' = 08
   '83931' = 08
   '83940' = 08
   '83941' = 08
   '83942' = 08
   '83949' = 08
   '83950' = 08
   '83951' = 08
   '83952' = 08
   '83959' = 08
   '83961' = 04
   '83969' = 08
   '83971' = 04
   '83979' = 08
   '8398'  = 08
   '8399'  = 08
   '8400'  = 08
   '8401'  = 08
   '8402'  = 08
   '8403'  = 08
   '8404'  = 08
   '8405'  = 08
   '8406'  = 08
   '8407'  = 08
   '8408'  = 08
   '8409'  = 08
   '8410'  = 08
   '8411'  = 08
   '8412'  = 08
   '8413'  = 08
   '8418'  = 08
   '8419'  = 08
   '84200' = 08
   '84201' = 08
   '84202' = 08
   '84209' = 08
   '84210' = 08
   '84211' = 08
   '84212' = 08
   '84213' = 08
   '84219' = 08
   '8430'  = 08
   '8431'  = 08
   '8438'  = 08
   '8439'  = 08
   '8440'  = 08
   '8441'  = 08
   '8442'  = 08
   '8443'  = 08
   '8448'  = 08
   '8449'  = 08
   '84500' = 08
   '84501' = 08
   '84502' = 08
   '84503' = 08
   '84509' = 08
   '84510' = 08
   '84511' = 08
   '84512' = 08
   '84513' = 08
   '84519' = 08
   '8460'  = 08
   '8461'  = 08
   '8462'  = 08
   '8463'  = 08
   '8468'  = 08
   '8469'  = 08
   '8470'  = 08
   '8471'  = 08
   '8472'  = 08
   '8473'  = 08
   '8474'  = 08
   '8479'  = 08
   '8480'  = 08
   '8481'  = 03
   '8482'  = 08
   '8483'  = 04
   '84840' = 04
   '84841' = 04
   '84842' = 04
   '84849' = 04
   '8485'  = 08
   '8488'  = 08
   '8489'  = 08
   '8500'  = 01
   '85011' = 01
   '85012' = 01
   '8502'  = 01
   '8503'  = 01
   '8504'  = 01
   '8505'  = 01
   '8509'  = 01
   '85100' = 01
   '85101' = 01
   '85102' = 01
   '85103' = 01
   '85104' = 01
   '85105' = 01
   '85106' = 01
   '85109' = 01
   '85110' = 01
   '85111' = 01
   '85112' = 01
   '85113' = 01
   '85114' = 01
   '85115' = 01
   '85116' = 01
   '85119' = 01
   '85120' = 01
   '85121' = 01
   '85122' = 01
   '85123' = 01
   '85124' = 01
   '85125' = 01
   '85126' = 01
   '85129' = 01
   '85130' = 01
   '85131' = 01
   '85132' = 01
   '85133' = 01
   '85134' = 01
   '85135' = 01
   '85136' = 01
   '85139' = 01
   '85140' = 01
   '85141' = 01
   '85142' = 01
   '85143' = 01
   '85144' = 01
   '85145' = 01
   '85146' = 01
   '85149' = 01
   '85150' = 01
   '85151' = 01
   '85152' = 01
   '85153' = 01
   '85154' = 01
   '85155' = 01
   '85156' = 01
   '85159' = 01
   '85160' = 01
   '85161' = 01
   '85162' = 01
   '85163' = 01
   '85164' = 01
   '85165' = 01
   '85166' = 01
   '85169' = 01
   '85170' = 01
   '85171' = 01
   '85172' = 01
   '85173' = 01
   '85174' = 01
   '85175' = 01
   '85176' = 01
   '85179' = 01
   '85180' = 01
   '85181' = 01
   '85182' = 01
   '85183' = 01
   '85184' = 01
   '85185' = 01
   '85186' = 01
   '85189' = 01
   '85190' = 01
   '85191' = 01
   '85192' = 01
   '85193' = 01
   '85194' = 01
   '85195' = 01
   '85196' = 01
   '85199' = 01
   '85200' = 01
   '85201' = 01
   '85202' = 01
   '85203' = 01
   '85204' = 01
   '85205' = 01
   '85206' = 01
   '85209' = 01
   '85210' = 01
   '85211' = 01
   '85212' = 01
   '85213' = 01
   '85214' = 01
   '85215' = 01
   '85216' = 01
   '85219' = 01
   '85220' = 01
   '85221' = 01
   '85222' = 01
   '85223' = 01
   '85224' = 01
   '85225' = 01
   '85226' = 01
   '85229' = 01
   '85230' = 01
   '85231' = 01
   '85232' = 01
   '85233' = 01
   '85234' = 01
   '85235' = 01
   '85236' = 01
   '85239' = 01
   '85240' = 01
   '85241' = 01
   '85242' = 01
   '85243' = 01
   '85244' = 01
   '85245' = 01
   '85246' = 01
   '85249' = 01
   '85250' = 01
   '85251' = 01
   '85252' = 01
   '85253' = 01
   '85254' = 01
   '85255' = 01
   '85256' = 01
   '85259' = 01
   '85300' = 01
   '85301' = 01
   '85302' = 01
   '85303' = 01
   '85304' = 01
   '85305' = 01
   '85306' = 01
   '85309' = 01
   '85310' = 01
   '85311' = 01
   '85312' = 01
   '85313' = 01
   '85314' = 01
   '85315' = 01
   '85316' = 01
   '85319' = 01
   '85400' = 01
   '85401' = 01
   '85402' = 01
   '85403' = 01
   '85404' = 01
   '85405' = 01
   '85406' = 01
   '85409' = 01
   '85410' = 01
   '85411' = 01
   '85412' = 01
   '85413' = 01
   '85414' = 01
   '85415' = 01
   '85416' = 01
   '85419' = 01
   '8600'  = 04
   '8601'  = 04
   '8602'  = 04
   '8603'  = 04
   '8604'  = 04
   '8605'  = 04
   '86100' = 05
   '86101' = 05
   '86102' = 05
   '86103' = 05
   '86110' = 05
   '86111' = 05
   '86112' = 05
   '86113' = 05
   '86120' = 04
   '86121' = 04
   '86122' = 04
   '86130' = 04
   '86131' = 04
   '86132' = 04
   '8620'  = 04
   '8621'  = 04
   '86221' = 04
   '86222' = 06
   '86229' = 04
   '86231' = 04
   '86232' = 06
   '86239' = 04
   '8628'  = 21
   '8629'  = 21
   '8630'  = 06
   '8631'  = 06
   '86320' = 06
   '86321' = 06
   '86329' = 06
   '86330' = 06
   '86331' = 06
   '86339' = 06
   '86340' = 06
   '86341' = 06
   '86342' = 06
   '86343' = 06
   '86344' = 06
   '86345' = 06
   '86346' = 06
   '86349' = 06
   '86350' = 06
   '86351' = 06
   '86352' = 06
   '86353' = 06
   '86354' = 06
   '86355' = 06
   '86356' = 06
   '86359' = 06
   '86380' = 06
   '86381' = 07
   '86382' = 07
   '86383' = 07
   '86384' = 07
   '86385' = 06
   '86389' = 06
   '86390' = 06
   '86391' = 07
   '86392' = 07
   '86393' = 07
   '86394' = 07
   '86395' = 06
   '86399' = 06
   '86400' = 07
   '86401' = 07
   '86402' = 07
   '86403' = 07
   '86404' = 07
   '86405' = 07
   '86409' = 07
   '86410' = 07
   '86411' = 07
   '86412' = 07
   '86413' = 07
   '86414' = 07
   '86415' = 07
   '86419' = 07
   '86500' = 16
   '86501' = 16
   '86502' = 16
   '86503' = 16
   '86504' = 16
   '86509' = 16
   '86510' = 16
   '86511' = 16
   '86512' = 16
   '86513' = 16
   '86514' = 16
   '86519' = 16
   '86600' = 11
   '86601' = 11
   '86602' = 11
   '86603' = 11
   '86610' = 11
   '86611' = 11
   '86612' = 11
   '86613' = 11
   '8670'  = 11
   '8671'  = 11
   '8672'  = 11
   '8673'  = 11
   '8674'  = 13
   '8675'  = 13
   '8676'  = 12
   '8677'  = 12
   '8678'  = 12
   '8679'  = 12
   '86800' = 06
   '86801' = 10
   '86802' = 07
   '86803' = 06
   '86804' = 11
   '86809' = 21
   '86810' = 06
   '86811' = 10
   '86812' = 07
   '86813' = 06
   '86814' = 11
   '86819' = 21
   '8690'  = 21
   '8691'  = 21
   '8700'  = 02
   '8701'  = 02
   '8702'  = 02
   '8703'  = 02
   '8704'  = 02
   '8708'  = 02
   '8709'  = 02
   '8710'  = 02
   '8711'  = 02
   '8712'  = 02
   '8713'  = 02
   '8714'  = 02
   '8715'  = 02
   '8716'  = 02
   '8717'  = 02
   '8719'  = 02
   '87200' = 03
   '87201' = 03
   '87202' = 03
   '87210' = 03
   '87211' = 03
   '87212' = 03
   '87261' = 03
   '87262' = 03
   '87263' = 03
   '87264' = 03
   '87269' = 03
   '87271' = 03
   '87272' = 03
   '87273' = 03
   '87274' = 03
   '87279' = 03
   '8728'  = 03
   '8729'  = 03
   '8730'  = 09
   '8731'  = 09
   '87320' = 03
   '87321' = 03
   '87322' = 03
   '87323' = 03
   '87329' = 03
   '87330' = 03
   '87331' = 03
   '87332' = 03
   '87333' = 03
   '87339' = 03
   '87340' = 09
   '87341' = 09
   '87342' = 09
   '87343' = 03
   '87344' = 03
   '87349' = 09
   '87350' = 09
   '87351' = 09
   '87352' = 09
   '87353' = 03
   '87354' = 03
   '87359' = 09
   '87360' = 03
   '87361' = 03
   '87362' = 03
   '87363' = 03
   '87364' = 03
   '87365' = 03
   '87369' = 03
   '87370' = 03
   '87371' = 03
   '87372' = 03
   '87373' = 03
   '87374' = 03
   '87375' = 03
   '87379' = 03
   '8738'  = 09
   '8739'  = 09
   '87400' = 03
   '87401' = 03
   '87402' = 04
   '87410' = 03
   '87411' = 03
   '87412' = 04
   '8742'  = 10
   '8743'  = 10
   '8744'  = 03
   '8745'  = 03
   '8748'  = 09
   '8749'  = 09
   '8750'  = 09
   '8751'  = 21
   '8760'  = 09
   '8761'  = 09
   '8770'  = 09
   '8771'  = 09
   '8780'  = 12
   '8781'  = 12
   '8782'  = 12
   '8783'  = 12
   '8784'  = 13
   '8785'  = 13
   '8786'  = 13
   '8787'  = 13
   '8788'  = 12
   '8789'  = 12
   '8790'  = 09
   '8791'  = 09
   '8792'  = 09
   '8793'  = 21
   '8794'  = 09
   '8795'  = 21
   '8796'  = 09
   '8797'  = 21
   '8798'  = 09
   '8799'  = 21
   '88000' = 09
   '88001' = 09
   '88002' = 09
   '88003' = 09
   '88009' = 09
   '88010' = 21
   '88011' = 21
   '88012' = 21
   '88013' = 21
   '88019' = 21
   '88020' = 08
   '88021' = 08
   '88022' = 08
   '88023' = 08
   '88029' = 08
   '88100' = 09
   '88101' = 09
   '88102' = 09
   '88110' = 21
   '88111' = 21
   '88112' = 21
   '88120' = 08
   '88121' = 08
   '88122' = 08
   '8820'  = 09
   '8821'  = 21
   '8822'  = 08
   '8830'  = 09
   '8831'  = 21
   '8832'  = 08
   '8840'  = 09
   '8841'  = 21
   '8842'  = 08
   '8850'  = 21
   '8851'  = 21
   '8860'  = 21
   '8861'  = 21
   '8870'  = 21
   '8871'  = 21
   '8872'  = 21
   '8873'  = 21
   '8874'  = 21
   '8875'  = 21
   '8876'  = 21
   '8877'  = 21
   '8900'  = 09
   '8901'  = 21
   '8902'  = 08
   '8910'  = 09
   '8911'  = 21
   '8912'  = 08
   '8920'  = 09
   '8921'  = 21
   '8922'  = 08
   '8930'  = 09
   '8931'  = 21
   '8932'  = 08
   '8940'  = 09
   '8941'  = 21
   '8942'  = 08
   '8950'  = 21
   '8951'  = 21
   '8960'  = 21
   '8961'  = 21
   '8962'  = 21
   '8963'  = 21
   '8970'  = 21
   '8971'  = 21
   '8972'  = 21
   '8973'  = 21
   '8974'  = 21
   '8975'  = 21
   '8976'  = 21
   '8977'  = 21
   '90000' = 21
   '90001' = 21
   '90002' = 21
   '90003' = 21
   '9001'  = 21
   '90081' = 21
   '90082' = 21
   '90089' = 21
   '9009'  = 21
   '9010'  = 21
   '9011'  = 21
   '9012'  = 21
   '9013'  = 21
   '90140' = 21
   '90141' = 21
   '90142' = 21
   '90181' = 21
   '90182' = 21
   '90183' = 21
   '90189' = 21
   '9019'  = 21
   '9020'  = 21
   '90210' = 21
   '90211' = 21
   '90219' = 21
   '90220' = 21
   '90221' = 21
   '90222' = 21
   '90223' = 21
   '90224' = 21
   '90225' = 21
   '90226' = 21
   '90227' = 21
   '90229' = 21
   '90231' = 21
   '90232' = 21
   '90233' = 21
   '90234' = 21
   '90239' = 21
   '90240' = 21
   '90241' = 21
   '90242' = 21
   '90249' = 21
   '90250' = 21
   '90251' = 21
   '90252' = 21
   '90253' = 21
   '90254' = 21
   '90255' = 21
   '90256' = 21
   '90259' = 21
   '90281' = 21
   '90282' = 21
   '90287' = 21
   '90289' = 21
   '9029'  = 21
   '90300' = 21
   '90301' = 21
   '90302' = 21
   '9031'  = 21
   '9032'  = 21
   '9033'  = 21
   '9034'  = 21
   '9035'  = 21
   '9038'  = 21
   '9039'  = 21
   '9040'  = 21
   '9041'  = 21
   '9042'  = 21
   '9043'  = 21
   '90440' = 21
   '90441' = 21
   '90442' = 21
   '90450' = 21
   '90451' = 21
   '90452' = 21
   '90453' = 21
   '90454' = 21
   '9046'  = 21
   '9047'  = 21
   '9048'  = 21
   '9049'  = 21
   '9050'  = 01
   '9051'  = 08
   '9052'  = 08
   '9053'  = 08
   '9054'  = 08
   '9055'  = 08
   '9056'  = 08
   '9057'  = 08
   '9058'  = 08
   '9059'  = 08
   '9060'  = 09
   '9061'  = 09
   '9062'  = 09
   '9063'  = 09
   '9064'  = 09
   '9065'  = 09
   '9066'  = 09
   '9067'  = 09
   '9068'  = 09
   '9069'  = 09
   '9070'  = 01
   '9071'  = 01
   '9072'  = 01
   '9073'  = 01
   '9074'  = 01
   '9075'  = 01
   '9079'  = 01
   '9080'  = 04
   '9081'  = 06
   '9082'  = 12
   '9083'  = 05
   '9084'  = 05
   '9085'  = 21
   '9086'  = 21
   '9089'  = 21
   '9090'  = 21
   '9091'  = 21
   '9092'  = 21
   '9093'  = 21
   '9094'  = 21
   '9095'  = 21
   '9099'  = 21
   '9100'  = 09
   '9101'  = 09
   '9102'  = 09
   '9103'  = 09
   '9104'  = 09
   '9105'  = 09
   '9106'  = 09
   '9107'  = 09
   '9108'  = 09
   '9109'  = 09
   '9110'  = 09
   '9111'  = 09
   '9112'  = 09
   '9113'  = 09
   '9114'  = 09
   '9115'  = 09
   '9116'  = 09
   '9117'  = 09
   '9118'  = 09
   '9119'  = 09
   '9120'  = 09
   '9121'  = 09
   '9122'  = 09
   '9123'  = 09
   '9124'  = 09
   '9125'  = 09
   '9126'  = 09
   '9127'  = 09
   '9128'  = 09
   '9129'  = 09
   '9130'  = 09
   '9131'  = 09
   '9132'  = 09
   '9133'  = 09
   '9134'  = 09
   '9135'  = 09
   '9136'  = 09
   '9137'  = 09
   '9138'  = 09
   '9139'  = 09
   '9140'  = 09
   '9141'  = 09
   '9142'  = 09
   '9143'  = 09
   '9144'  = 09
   '9145'  = 09
   '9146'  = 09
   '9147'  = 09
   '9148'  = 09
   '9149'  = 09
   '9150'  = 09
   '9151'  = 09
   '9152'  = 09
   '9153'  = 09
   '9154'  = 09
   '9155'  = 09
   '9156'  = 09
   '9157'  = 09
   '9158'  = 09
   '9159'  = 09
   '9160'  = 09
   '9161'  = 09
   '9162'  = 09
   '9163'  = 09
   '9164'  = 09
   '9165'  = 09
   '9166'  = 09
   '9167'  = 09
   '9168'  = 09
   '9169'  = 09
   '9170'  = 09
   '9171'  = 09
   '9172'  = 09
   '9173'  = 09
   '9174'  = 09
   '9175'  = 09
   '9176'  = 09
   '9177'  = 09
   '9178'  = 09
   '9179'  = 09
   '9180'  = 02
   '9181'  = 02
   '9182'  = 02
   '9189'  = 02
   '9190'  = 09
   '9191'  = 09
   '9192'  = 09
   '9193'  = 09
   '9194'  = 09
   '9195'  = 09
   '9196'  = 09
   '9197'  = 09
   '9198'  = 09
   '9199'  = 09
   '920'   = 09
   '9210'  = 02
   '9211'  = 02
   '9212'  = 02
   '9213'  = 02
   '9219'  = 02
   '9220'  = 09
   '9221'  = 09
   '9222'  = 09
   '92231' = 09
   '92232' = 09
   '92233' = 09
   '9224'  = 12
   '9228'  = 09
   '9229'  = 09
   '92300' = 09
   '92301' = 09
   '92302' = 09
   '92303' = 09
   '92309' = 09
   '92310' = 09
   '92311' = 09
   '92320' = 09
   '92321' = 09
   '9233'  = 09
   '9238'  = 09
   '9239'  = 09
   '92400' = 09
   '92401' = 09
   '92410' = 09
   '92411' = 09
   '92420' = 09
   '92421' = 09
   '9243'  = 09
   '9244'  = 09
   '9245'  = 09
   '9248'  = 09
   '9249'  = 09
   '9251'  = 21
   '9252'  = 21
   '9260'  = 12
   '92611' = 21
   '92612' = 21
   '92619' = 21
   '9268'  = 21
   '9269'  = 21
   '92700' = 21
   '92701' = 21
   '92702' = 21
   '92703' = 21
   '92709' = 21
   '92710' = 21
   '92711' = 21
   '92720' = 21
   '92721' = 21
   '9273'  = 21
   '9278'  = 21
   '9279'  = 21
   '92800' = 21
   '92801' = 21
   '92810' = 21
   '92811' = 21
   '92820' = 21
   '92821' = 21
   '9283'  = 21
   '9288'  = 21
   '9289'  = 21
   '9290'  = 21
   '9299'  = 21
   '9300'  = 02
   '9301'  = 02
   '9302'  = 02
   '9308'  = 02
   '9309'  = 02
   '931'   = 03
   '932'   = 03
   '9330'  = 03
   '9331'  = 03
   '9340'  = 04
   '9341'  = 04
   '9348'  = 04
   '9349'  = 04
   '9350'  = 03
   '9351'  = 06
   '9352'  = 06
   '936'   = 06
   '937'   = 06
   '938'   = 06
   '9390'  = 11
   '9391'  = 13
   '9392'  = 13
   '9393'  = 12
   '9399'  = 11
   '9400'  = 02
   '9401'  = 02
   '9402'  = 02
   '9403'  = 02
   '9404'  = 02
   '9405'  = 02
   '9409'  = 02
   '94100' = 22
   '94101' = 22
   '94102' = 02
   '94103' = 22
   '94104' = 22
   '94105' = 22
   '94106' = 22
   '94107' = 22
   '94108' = 22
   '94109' = 22
   '94110' = 22
   '94111' = 22
   '94112' = 02
   '94113' = 22
   '94114' = 22
   '94115' = 22
   '94116' = 22
   '94117' = 22
   '94118' = 22
   '94119' = 22
   '94120' = 22
   '94121' = 22
   '94122' = 02
   '94123' = 22
   '94124' = 22
   '94125' = 22
   '94126' = 22
   '94127' = 22
   '94128' = 22
   '94129' = 22
   '94130' = 22
   '94131' = 22
   '94132' = 02
   '94133' = 22
   '94134' = 22
   '94135' = 22
   '94136' = 22
   '94137' = 22
   '94138' = 22
   '94139' = 22
   '94140' = 22
   '94141' = 22
   '94142' = 02
   '94143' = 22
   '94144' = 22
   '94145' = 22
   '94146' = 22
   '94147' = 22
   '94148' = 22
   '94149' = 22
   '94150' = 22
   '94151' = 22
   '94152' = 02
   '94153' = 22
   '94154' = 22
   '94155' = 22
   '94156' = 22
   '94157' = 22
   '94158' = 22
   '94159' = 22
   '94200' = 22
   '94201' = 22
   '94202' = 22
   '94203' = 22
   '94204' = 22
   '94205' = 22
   '94209' = 22
   '94210' = 22
   '94211' = 22
   '94212' = 22
   '94213' = 22
   '94214' = 22
   '94215' = 22
   '94219' = 22
   '94220' = 22
   '94221' = 22
   '94222' = 22
   '94223' = 22
   '94224' = 22
   '94225' = 22
   '94229' = 22
   '94230' = 22
   '94231' = 22
   '94232' = 22
   '94233' = 22
   '94234' = 22
   '94235' = 22
   '94239' = 22
   '94240' = 22
   '94241' = 22
   '94242' = 22
   '94243' = 22
   '94244' = 22
   '94245' = 22
   '94249' = 22
   '94250' = 22
   '94251' = 22
   '94252' = 22
   '94253' = 22
   '94254' = 22
   '94255' = 22
   '94259' = 22
   '94300' = 22
   '94301' = 22
   '94302' = 22
   '94303' = 22
   '94304' = 22
   '94305' = 22
   '94306' = 22
   '94309' = 22
   '94310' = 22
   '94311' = 22
   '94312' = 22
   '94313' = 22
   '94314' = 22
   '94315' = 22
   '94316' = 22
   '94319' = 22
   '94320' = 22
   '94321' = 22
   '94322' = 22
   '94323' = 22
   '94324' = 22
   '94325' = 22
   '94326' = 22
   '94329' = 22
   '94330' = 22
   '94331' = 22
   '94332' = 22
   '94333' = 22
   '94334' = 22
   '94335' = 22
   '94336' = 22
   '94339' = 22
   '94340' = 22
   '94341' = 22
   '94342' = 22
   '94343' = 22
   '94344' = 22
   '94345' = 22
   '94346' = 22
   '94349' = 22
   '94350' = 22
   '94351' = 22
   '94352' = 22
   '94353' = 22
   '94354' = 22
   '94355' = 22
   '94356' = 22
   '94359' = 22
   '94400' = 22
   '94401' = 22
   '94402' = 22
   '94403' = 22
   '94404' = 22
   '94405' = 22
   '94406' = 22
   '94407' = 22
   '94408' = 22
   '94410' = 22
   '94411' = 22
   '94412' = 22
   '94413' = 22
   '94414' = 22
   '94415' = 22
   '94416' = 22
   '94417' = 22
   '94418' = 22
   '94420' = 22
   '94421' = 22
   '94422' = 22
   '94423' = 22
   '94424' = 22
   '94425' = 22
   '94426' = 22
   '94427' = 22
   '94428' = 22
   '94430' = 22
   '94431' = 22
   '94432' = 22
   '94433' = 22
   '94434' = 22
   '94435' = 22
   '94436' = 22
   '94437' = 22
   '94438' = 22
   '94440' = 22
   '94441' = 22
   '94442' = 22
   '94443' = 22
   '94444' = 22
   '94445' = 22
   '94446' = 22
   '94447' = 22
   '94448' = 22
   '94450' = 22
   '94451' = 22
   '94452' = 22
   '94453' = 22
   '94454' = 22
   '94455' = 22
   '94456' = 22
   '94457' = 22
   '94458' = 22
   '94500' = 22
   '94501' = 22
   '94502' = 22
   '94503' = 22
   '94504' = 22
   '94505' = 22
   '94506' = 22
   '94509' = 22
   '94510' = 22
   '94511' = 22
   '94512' = 22
   '94513' = 22
   '94514' = 22
   '94515' = 22
   '94516' = 22
   '94519' = 22
   '94520' = 22
   '94521' = 22
   '94522' = 22
   '94523' = 22
   '94524' = 22
   '94525' = 22
   '94526' = 22
   '94529' = 22
   '94530' = 22
   '94531' = 22
   '94532' = 22
   '94533' = 22
   '94534' = 22
   '94535' = 22
   '94536' = 22
   '94539' = 22
   '94540' = 22
   '94541' = 22
   '94542' = 22
   '94543' = 22
   '94544' = 22
   '94545' = 22
   '94546' = 22
   '94549' = 22
   '94550' = 22
   '94551' = 22
   '94552' = 22
   '94553' = 22
   '94554' = 22
   '94555' = 22
   '94556' = 22
   '94559' = 22
   '9460'  = 22
   '9461'  = 22
   '9462'  = 22
   '9463'  = 22
   '9464'  = 22
   '9465'  = 22
   '9470'  = 03
   '9471'  = 04
   '9472'  = 06
   '9473'  = 06
   '9474'  = 13
   '9478'  = 22
   '9479'  = 22
   '94800' = 22
   '94810' = 22
   '94811' = 22
   '94820' = 22
   '94821' = 22
   '94822' = 22
   '94830' = 22
   '94831' = 22
   '94832' = 22
   '94833' = 22
   '94840' = 22
   '94841' = 22
   '94842' = 22
   '94843' = 22
   '94844' = 22
   '94850' = 22
   '94851' = 22
   '94852' = 22
   '94853' = 22
   '94854' = 22
   '94855' = 22
   '94860' = 22
   '94861' = 22
   '94862' = 22
   '94863' = 22
   '94864' = 22
   '94865' = 22
   '94866' = 22
   '94870' = 22
   '94871' = 22
   '94872' = 22
   '94873' = 22
   '94874' = 22
   '94875' = 22
   '94876' = 22
   '94877' = 22
   '94880' = 22
   '94881' = 22
   '94882' = 22
   '94883' = 22
   '94884' = 22
   '94885' = 22
   '94886' = 22
   '94887' = 22
   '94888' = 22
   '94890' = 22
   '94891' = 22
   '94892' = 22
   '94893' = 22
   '94894' = 22
   '94895' = 22
   '94896' = 22
   '94897' = 22
   '94898' = 22
   '94899' = 22
   '9490'  = 22
   '9491'  = 22
   '9492'  = 22
   '9493'  = 22
   '9494'  = 22
   '9495'  = 22
   '9500'  = 02
   '9501'  = 01
   '9502'  = 01
   '9503'  = 01
   '9509'  = 01
   '9510'  = 01
   '9511'  = 01
   '9512'  = 01
   '9513'  = 01
   '9514'  = 01
   '9515'  = 03
   '9516'  = 01
   '9517'  = 01
   '9518'  = 01
   '9519'  = 01
   '95200' = 01
   '95201' = 01
   '95202' = 01
   '95203' = 01
   '95204' = 01
   '95205' = 01
   '95206' = 01
   '95207' = 01
   '95208' = 01
   '95209' = 01
   '95210' = 01
   '95211' = 01
   '95212' = 01
   '95213' = 01
   '95214' = 01
   '95215' = 01
   '95216' = 01
   '95217' = 01
   '95218' = 01
   '95219' = 01
   '9522'  = 01
   '9523'  = 01
   '9524'  = 01
   '9528'  = 01
   '9529'  = 01
   '9530'  = 01
   '9531'  = 01
   '9532'  = 01
   '9533'  = 01
   '9534'  = 01
   '9535'  = 01
   '9538'  = 01
   '9539'  = 01
   '9540'  = 01
   '9541'  = 01
   '9548'  = 01
   '9549'  = 01
   '9550'  = 01
   '9551'  = 01
   '9552'  = 01
   '9553'  = 01
   '9554'  = 01
   '9555'  = 01
   '9556'  = 01
   '9557'  = 01
   '9558'  = 01
   '9559'  = 01
   '9560'  = 01
   '9561'  = 01
   '9562'  = 01
   '9563'  = 01
   '9564'  = 01
   '9565'  = 01
   '9568'  = 01
   '9569'  = 01
   '9570'  = 01
   '9571'  = 01
   '9578'  = 01
   '9579'  = 01
   '9580'  = 04
   '9581'  = 04
   '9582'  = 21
   '9583'  = 18
   '9584'  = 21
   '9585'  = 11
   '9586'  = 08
   '9587'  = 04
   '9588'  = 21
   '95890' = 21
   '95891' = 21
   '95892' = 21
   '95893' = 21
   '95899' = 21
   '95901' = 21
   '95909' = 21
   '95911' = 21
   '95912' = 21
   '95913' = 21
   '95914' = 21
   '95919' = 21
   '9592'  = 21
   '9593'  = 21
   '9594'  = 21
   '9595'  = 21
   '9596'  = 21
   '9597'  = 21
   '9598'  = 21
   '9599'  = 21
   '9600'  = 21
   '9601'  = 21
   '9602'  = 21
   '9603'  = 21
   '9604'  = 21
   '9605'  = 21
   '9606'  = 21
   '9607'  = 21
   '9608'  = 21
   '9609'  = 21
   '9610'  = 21
   '9611'  = 21
   '9612'  = 21
   '9613'  = 21
   '9614'  = 21
   '9615'  = 21
   '9616'  = 21
   '9617'  = 21
   '9618'  = 21
   '9619'  = 21
   '9620'  = 21
   '9621'  = 21
   '9622'  = 21
   '9623'  = 21
   '9624'  = 21
   '9625'  = 21
   '9626'  = 21
   '9627'  = 21
   '9628'  = 21
   '9629'  = 21
   '9630'  = 21
   '9631'  = 21
   '9632'  = 21
   '9633'  = 21
   '9634'  = 21
   '9635'  = 21
   '9638'  = 21
   '9639'  = 21
   '9640'  = 21
   '9641'  = 21
   '9642'  = 21
   '9643'  = 21
   '9644'  = 21
   '9645'  = 21
   '9646'  = 21
   '9647'  = 21
   '9648'  = 21
   '9649'  = 21
   '96500' = 21
   '96501' = 21
   '96502' = 21
   '96509' = 21
   '9651'  = 21
   '9654'  = 21
   '9655'  = 21
   '96561' = 21
   '96569' = 21
   '9657'  = 21
   '9658'  = 21
   '9659'  = 21
   '9660'  = 21
   '9661'  = 21
   '9662'  = 21
   '9663'  = 21
   '9664'  = 21
   '9670'  = 21
   '9671'  = 21
   '9672'  = 21
   '9673'  = 21
   '9674'  = 21
   '9675'  = 21
   '9676'  = 21
   '9678'  = 21
   '9679'  = 21
   '9680'  = 21
   '9681'  = 21
   '9682'  = 21
   '9683'  = 21
   '9684'  = 21
   '9685'  = 21
   '9686'  = 21
   '9687'  = 21
   '9689'  = 21
   '96900' = 21
   '96901' = 21
   '96902' = 21
   '96903' = 21
   '96904' = 21
   '96905' = 21
   '96909' = 21
   '9691'  = 21
   '9692'  = 21
   '9693'  = 21
   '9694'  = 21
   '9695'  = 21
   '9696'  = 21
   '96970' = 21
   '96971' = 21
   '96972' = 21
   '96973' = 21
   '96979' = 21
   '9698'  = 21
   '9699'  = 21
   '9700'  = 21
   '9701'  = 21
   '97081' = 21
   '97089' = 21
   '9709'  = 21
   '9710'  = 21
   '9711'  = 21
   '9712'  = 21
   '9713'  = 21
   '9719'  = 21
   '9720'  = 21
   '9721'  = 21
   '9722'  = 21
   '9723'  = 21
   '9724'  = 21
   '9725'  = 21
   '9726'  = 21
   '9727'  = 21
   '9728'  = 21
   '9729'  = 21
   '9730'  = 21
   '9731'  = 21
   '9732'  = 21
   '9733'  = 21
   '9734'  = 21
   '9735'  = 21
   '9736'  = 21
   '9738'  = 21
   '9739'  = 21
   '9740'  = 21
   '9741'  = 21
   '9742'  = 21
   '9743'  = 21
   '9744'  = 21
   '9745'  = 21
   '9746'  = 21
   '9747'  = 21
   '9750'  = 21
   '9751'  = 21
   '9752'  = 21
   '9753'  = 21
   '9754'  = 21
   '9755'  = 21
   '9756'  = 21
   '9757'  = 21
   '9758'  = 21
   '9760'  = 21
   '9761'  = 21
   '9762'  = 21
   '9763'  = 21
   '9764'  = 21
   '9765'  = 02
   '9766'  = 21
   '9767'  = 21
   '9768'  = 21
   '9769'  = 21
   '9770'  = 21
   '9771'  = 21
   '9772'  = 21
   '9773'  = 21
   '9774'  = 21
   '9778'  = 21
   '9779'  = 21
   '9780'  = 21
   '9781'  = 21
   '9782'  = 21
   '9783'  = 21
   '9784'  = 21
   '9785'  = 21
   '9786'  = 21
   '9788'  = 21
   '9789'  = 21
   '9790'  = 21
   '9791'  = 21
   '9792'  = 21
   '9793'  = 21
   '9794'  = 21
   '9795'  = 21
   '9796'  = 21
   '9797'  = 21
   '9799'  = 21
   '9800'  = 21
   '9801'  = 21
   '9802'  = 21
   '9803'  = 21
   '9808'  = 21
   '9809'  = 21
   '981'   = 21
   '9820'  = 21
   '9821'  = 21
   '9822'  = 21
   '9823'  = 21
   '9824'  = 21
   '9828'  = 21
   '9830'  = 21
   '9831'  = 21
   '9832'  = 21
   '9839'  = 21
   '9840'  = 21
   '9841'  = 21
   '9848'  = 21
   '9849'  = 21
   '9850'  = 21
   '9851'  = 21
   '9852'  = 21
   '9853'  = 21
   '9854'  = 21
   '9855'  = 21
   '9856'  = 21
   '9858'  = 21
   '9859'  = 21
   '986'   = 21
   '9870'  = 21
   '9871'  = 21
   '9872'  = 21
   '9873'  = 21
   '9874'  = 21
   '9875'  = 21
   '9876'  = 21
   '9877'  = 21
   '9878'  = 21
   '9879'  = 21
   '9880'  = 21
   '9881'  = 21
   '9882'  = 21
   '9888'  = 21
   '9889'  = 21
   '9890'  = 21
   '9891'  = 21
   '9892'  = 21
   '9893'  = 21
   '9894'  = 21
   '9895'  = 21
   '9896'  = 21
   '9897'  = 21
   '98981' = 21
   '98982' = 21
   '98983' = 21
   '98984' = 21
   '98989' = 21
   '9899'  = 21
   '990'   = 21
   '9910'  = 21
   '9911'  = 21
   '9912'  = 21
   '9913'  = 21
   '9914'  = 21
   '9915'  = 21
   '9916'  = 21
   '9918'  = 21
   '9919'  = 21
   '9920'  = 21
   '9921'  = 21
   '9922'  = 21
   '9923'  = 21
   '9924'  = 21
   '9925'  = 21
   '9926'  = 21
   '9927'  = 21
   '9928'  = 21
   '9929'  = 21
   '9930'  = 03
   '9931'  = 03
   '9932'  = 21
   '9933'  = 21
   '9934'  = 21
   '9938'  = 21
   '9939'  = 21
   '9940'  = 21
   '9941'  = 21
   '9942'  = 21
   '9943'  = 21
   '9944'  = 21
   '9945'  = 21
   '9946'  = 03
   '9947'  = 21
   '9948'  = 21
   '9949'  = 21
   '9950'  = 21
   '9951'  = 21
   '99520' = 21
   '99521' = 21
   '99522' = 21
   '99523' = 21
   '99524' = 21
   '99527' = 21
   '99529' = 21
   '9953'  = 21
   '9954'  = 21
   '99550' = 21
   '99551' = 21
   '99552' = 21
   '99553' = 21
   '99554' = 21
   '99555' = 21
   '99559' = 21
   '99560' = 21
   '99561' = 21
   '99562' = 21
   '99563' = 21
   '99564' = 21
   '99565' = 21
   '99566' = 21
   '99567' = 21
   '99568' = 21
   '99569' = 21
   '9957'  = 21
   '99580' = 21
   '99581' = 21
   '99582' = 21
   '99583' = 21
   '99584' = 21
   '99585' = 21
   '99586' = 21
   '99589' = 21
   '99590' = 18
   '99591' = 18
   '99592' = 18
   '99593' = 18
   '99594' = 18
   '99600' = 05
   '99601' = 05
   '99602' = 05
   '99603' = 05
   '99604' = 05
   '99609' = 05
   '9961'  = 05
   '9962'  = 01
   '99630' = 11
   '99631' = 11
   '99632' = 13
   '99639' = 11
   '99640' = 08
   '99641' = 08
   '99642' = 08
   '99643' = 08
   '99644' = 08
   '99645' = 08
   '99646' = 08
   '99647' = 08
   '99649' = 08
   '99651' = 02
   '99652' = 21
   '99653' = 02
   '99654' = 09
   '99655' = 21
   '99656' = 21
   '99657' = 21
   '99659' = 21
   '99660' = 21
   '99661' = 05
   '99662' = 05
   '99663' = 01
   '99664' = 11
   '99665' = 11
   '99666' = 08
   '99667' = 08
   '99668' = 21
   '99669' = 21
   '99670' = 21
   '99671' = 05
   '99672' = 05
   '99673' = 05
   '99674' = 05
   '99675' = 01
   '99676' = 11
   '99677' = 08
   '99678' = 08
   '99679' = 21
   '99680' = 21
   '99681' = 11
   '99682' = 07
   '99683' = 05
   '99684' = 04
   '99685' = 16
   '99686' = 07
   '99687' = 21
   '99688' = 21
   '99689' = 21
   '99690' = 08
   '99691' = 08
   '99692' = 08
   '99693' = 08
   '99694' = 08
   '99695' = 08
   '99696' = 08
   '99699' = 08
   '99700' = 01
   '99701' = 01
   '99702' = 01
   '99709' = 01
   '9971'  = 05
   '9972'  = 05
   '99731' = 04
   '99732' = 04
   '99739' = 04
   '99741' = 06
   '99749' = 06
   '9975'  = 11
   '99760' = 08
   '99761' = 08
   '99762' = 08
   '99769' = 08
   '99771' = 06
   '99772' = 11
   '99779' = 05
   '99791' = 21
   '99799' = 21
   '99800' = 21
   '99801' = 21
   '99802' = 21
   '99809' = 21
   '99811' = 21
   '99812' = 21
   '99813' = 21
   '9982'  = 21
   '99830' = 21
   '99831' = 21
   '99832' = 21
   '99833' = 21
   '9984'  = 21
   '99851' = 18
   '99859' = 18
   '9986'  = 21
   '9987'  = 21
   '99881' = 21
   '99882' = 02
   '99883' = 21
   '99889' = 21
   '9989'  = 21
   '9990'  = 18
   '9991'  = 04
   '9992'  = 05
   '99931' = 05
   '99932' = 05
   '99933' = 05
   '99934' = 18
   '99939' = 18
   '99941' = 21
   '99942' = 21
   '99949' = 21
   '99951' = 21
   '99952' = 21
   '99959' = 21
   '99960' = 16
   '99961' = 16
   '99962' = 16
   '99963' = 16
   '99969' = 16
   '99970' = 16
   '99971' = 16
   '99972' = 16
   '99973' = 16
   '99974' = 16
   '99975' = 16
   '99976' = 16
   '99977' = 16
   '99978' = 16
   '99979' = 16
   '99980' = 16
   '99981' = 05
   '99982' = 05
   '99983' = 16
   '99984' = 16
   '99985' = 16
   '99988' = 05
   '99989' = 16
   '9999'  = 21
   'V010'  = 23
   'V011'  = 23
   'V012'  = 23
   'V013'  = 23
   'V014'  = 23
   'V015'  = 23
   'V016'  = 23
   'V0171' = 23
   'V0179' = 23
   'V0181' = 23
   'V0182' = 23
   'V0183' = 23
   'V0184' = 23
   'V0189' = 23
   'V019'  = 23
   'V020'  = 23
   'V021'  = 23
   'V022'  = 23
   'V023'  = 23
   'V024'  = 23
   'V0251' = 23
   'V0252' = 23
   'V0253' = 23
   'V0254' = 23
   'V0259' = 23
   'V0260' = 07
   'V0261' = 07
   'V0262' = 07
   'V0269' = 07
   'V027'  = 23
   'V028'  = 23
   'V029'  = 23
   'V030'  = 23
   'V031'  = 23
   'V032'  = 23
   'V033'  = 23
   'V034'  = 23
   'V035'  = 23
   'V036'  = 23
   'V037'  = 23
   'V0381' = 23
   'V0382' = 23
   'V0389' = 23
   'V039'  = 23
   'V040'  = 23
   'V041'  = 23
   'V042'  = 23
   'V043'  = 23
   'V044'  = 23
   'V045'  = 23
   'V046'  = 23
   'V047'  = 23
   'V0481' = 23
   'V0482' = 23
   'V0489' = 23
   'V050'  = 23
   'V051'  = 23
   'V052'  = 23
   'V053'  = 23
   'V054'  = 23
   'V058'  = 23
   'V059'  = 23
   'V060'  = 23
   'V061'  = 23
   'V062'  = 23
   'V063'  = 23
   'V064'  = 23
   'V065'  = 23
   'V066'  = 23
   'V068'  = 23
   'V069'  = 23
   'V070'  = 23
   'V071'  = 23
   'V072'  = 23
   'V0731' = 23
   'V0739' = 23
   'V074'  = 23
   'V0751' = 23
   'V0752' = 23
   'V0759' = 23
   'V078'  = 23
   'V079'  = 23
   'V08'   = 18
   'V090'  = 18
   'V091'  = 18
   'V092'  = 18
   'V093'  = 18
   'V094'  = 18
   'V0950' = 18
   'V0951' = 18
   'V096'  = 18
   'V0970' = 18
   'V0971' = 18
   'V0980' = 18
   'V0981' = 18
   'V0990' = 18
   'V0991' = 18
   'V1000' = 17
   'V1001' = 17
   'V1002' = 17
   'V1003' = 17
   'V1004' = 17
   'V1005' = 17
   'V1006' = 17
   'V1007' = 17
   'V1009' = 17
   'V1011' = 17
   'V1012' = 17
   'V1020' = 17
   'V1021' = 17
   'V1022' = 17
   'V1029' = 17
   'V103'  = 17
   'V1040' = 17
   'V1041' = 17
   'V1042' = 17
   'V1043' = 17
   'V1044' = 17
   'V1045' = 17
   'V1046' = 17
   'V1047' = 17
   'V1048' = 17
   'V1049' = 17
   'V1050' = 17
   'V1051' = 17
   'V1052' = 17
   'V1053' = 17
   'V1059' = 17
   'V1060' = 17
   'V1061' = 17
   'V1062' = 17
   'V1063' = 17
   'V1069' = 17
   'V1071' = 17
   'V1072' = 17
   'V1079' = 17
   'V1081' = 17
   'V1082' = 17
   'V1083' = 17
   'V1084' = 17
   'V1085' = 17
   'V1086' = 17
   'V1087' = 17
   'V1088' = 17
   'V1089' = 17
   'V1090' = 17
   'V1091' = 17
   'V110'  = 23
   'V111'  = 23
   'V112'  = 23
   'V113'  = 23
   'V114'  = 23
   'V118'  = 23
   'V119'  = 23
   'V1200' = 23
   'V1201' = 23
   'V1202' = 23
   'V1203' = 23
   'V1204' = 23
   'V1209' = 23
   'V121'  = 23
   'V1221' = 23
   'V1229' = 23
   'V123'  = 23
   'V1240' = 23
   'V1241' = 23
   'V1242' = 23
   'V1249' = 23
   'V1250' = 23
   'V1251' = 23
   'V1252' = 23
   'V1253' = 23
   'V1254' = 23
   'V1255' = 23
   'V1259' = 23
   'V1260' = 23
   'V1261' = 23
   'V1269' = 23
   'V1270' = 23
   'V1271' = 23
   'V1272' = 23
   'V1279' = 23
   'V1300' = 23
   'V1301' = 23
   'V1302' = 23
   'V1303' = 23
   'V1309' = 23
   'V131'  = 23
   'V1321' = 23
   'V1322' = 17
   'V1323' = 23
   'V1324' = 23
   'V1329' = 23
   'V133'  = 23
   'V134'  = 23
   'V1351' = 23
   'V1352' = 23
   'V1359' = 23
   'V1361' = 23
   'V1362' = 23
   'V1363' = 23
   'V1364' = 23
   'V1365' = 23
   'V1366' = 23
   'V1367' = 23
   'V1368' = 23
   'V1369' = 23
   'V137'  = 23
   'V1381' = 23
   'V1389' = 23
   'V139'  = 23
   'V140'  = 23
   'V141'  = 23
   'V142'  = 23
   'V143'  = 23
   'V144'  = 23
   'V145'  = 23
   'V146'  = 23
   'V147'  = 23
   'V148'  = 23
   'V149'  = 23
   'V1501' = 23
   'V1502' = 23
   'V1503' = 23
   'V1504' = 23
   'V1505' = 23
   'V1506' = 23
   'V1507' = 23
   'V1508' = 23
   'V1509' = 23
   'V151'  = 23
   'V1521' = 23
   'V1522' = 23
   'V1529' = 23
   'V153'  = 23
   'V1541' = 23
   'V1542' = 23
   'V1549' = 23
   'V1551' = 23
   'V1552' = 23
   'V1553' = 23
   'V1559' = 23
   'V156'  = 23
   'V157'  = 23
   'V1580' = 23
   'V1581' = 23
   'V1582' = 23
   'V1583' = 23
   'V1584' = 23
   'V1585' = 23
   'V1586' = 23
   'V1587' = 23
   'V1588' = 23
   'V1589' = 23
   'V159'  = 23
   'V160'  = 23
   'V161'  = 23
   'V162'  = 23
   'V163'  = 23
   'V1640' = 23
   'V1641' = 23
   'V1642' = 23
   'V1643' = 23
   'V1649' = 23
   'V1651' = 23
   'V1652' = 23
   'V1659' = 23
   'V166'  = 23
   'V167'  = 23
   'V168'  = 23
   'V169'  = 23
   'V170'  = 23
   'V171'  = 23
   'V172'  = 23
   'V173'  = 23
   'V1741' = 23
   'V1749' = 23
   'V175'  = 23
   'V176'  = 23
   'V177'  = 23
   'V1781' = 23
   'V1789' = 23
   'V180'  = 23
   'V1811' = 23
   'V1819' = 23
   'V182'  = 23
   'V183'  = 23
   'V184'  = 23
   'V1851' = 23
   'V1859' = 23
   'V1861' = 23
   'V1869' = 23
   'V187'  = 23
   'V188'  = 23
   'V189'  = 23
   'V190'  = 23
   'V1911' = 23
   'V1919' = 23
   'V192'  = 23
   'V193'  = 23
   'V194'  = 23
   'V195'  = 23
   'V196'  = 23
   'V197'  = 23
   'V198'  = 23
   'V200'  = 23
   'V201'  = 23
   'V202'  = 23
   'V2031' = 23
   'V2032' = 23
   'V210'  = 23
   'V211'  = 23
   'V212'  = 23
   'V2130' = 23
   'V2131' = 23
   'V2132' = 23
   'V2133' = 23
   'V2134' = 23
   'V2135' = 23
   'V218'  = 23
   'V219'  = 23
   'V220'  = 23
   'V221'  = 23
   'V222'  = 23
   'V230'  = 14
   'V231'  = 14
   'V232'  = 14
   'V233'  = 14
   'V2341' = 14
   'V2342' = 14
   'V2349' = 14
   'V235'  = 14
   'V237'  = 14
   'V2381' = 14
   'V2382' = 14
   'V2383' = 14
   'V2384' = 14
   'V2385' = 14
   'V2386' = 14
   'V2387' = 14
   'V2389' = 14
   'V239'  = 14
   'V240'  = 14
   'V241'  = 23
   'V242'  = 23
   'V2501' = 23
   'V2502' = 23
   'V2503' = 23
   'V2504' = 23
   'V2509' = 23
   'V2511' = 23
   'V2512' = 23
   'V2513' = 23
   'V252'  = 12
   'V253'  = 13
   'V2540' = 23
   'V2541' = 23
   'V2542' = 23
   'V2543' = 23
   'V2549' = 23
   'V255'  = 23
   'V258'  = 23
   'V259'  = 23
   'V260'  = 12
   'V261'  = 23
   'V2621' = 23
   'V2622' = 23
   'V2629' = 23
   'V2631' = 23
   'V2632' = 23
   'V2633' = 23
   'V2634' = 23
   'V2635' = 23
   'V2639' = 23
   'V2641' = 23
   'V2642' = 23
   'V2649' = 23
   'V2651' = 23
   'V2652' = 23
   'V2681' = 23
   'V2682' = 23
   'V2689' = 23
   'V269'  = 23
   'V270'  = 23
   'V271'  = 23
   'V272'  = 23
   'V273'  = 23
   'V274'  = 23
   'V275'  = 23
   'V276'  = 23
   'V277'  = 23
   'V279'  = 23
   'V280'  = 14
   'V281'  = 14
   'V282'  = 14
   'V283'  = 23
   'V284'  = 23
   'V285'  = 23
   'V286'  = 23
   'V2881' = 23
   'V2882' = 23
   'V2889' = 23
   'V289'  = 23
   'V290'  = 23
   'V291'  = 23
   'V292'  = 23
   'V293'  = 23
   'V298'  = 23
   'V299'  = 23
   'V3000' = 15
   'V3001' = 15
   'V301'  = 15
   'V302'  = 15
   'V3100' = 15
   'V3101' = 15
   'V311'  = 15
   'V312'  = 15
   'V3200' = 15
   'V3201' = 15
   'V321'  = 15
   'V322'  = 15
   'V3300' = 15
   'V3301' = 15
   'V331'  = 15
   'V332'  = 15
   'V3400' = 15
   'V3401' = 15
   'V341'  = 15
   'V342'  = 15
   'V3500' = 15
   'V3501' = 15
   'V351'  = 15
   'V352'  = 15
   'V3600' = 15
   'V3601' = 15
   'V361'  = 15
   'V362'  = 15
   'V3700' = 15
   'V3701' = 15
   'V371'  = 15
   'V372'  = 15
   'V3900' = 15
   'V3901' = 15
   'V391'  = 15
   'V392'  = 15
   'V400'  = 23
   'V401'  = 23
   'V402'  = 23
   'V4031' = 23
   'V4039' = 23
   'V409'  = 23
   'V410'  = 23
   'V411'  = 23
   'V412'  = 23
   'V413'  = 23
   'V414'  = 23
   'V415'  = 23
   'V416'  = 23
   'V417'  = 23
   'V418'  = 23
   'V419'  = 23
   'V420'  = 11
   'V421'  = 05
   'V422'  = 05
   'V423'  = 09
   'V424'  = 08
   'V425'  = 02
   'V426'  = 04
   'V427'  = 07
   'V4281' = 16
   'V4282' = 16
   'V4283' = 07
   'V4284' = 23
   'V4289' = 23
   'V429'  = 23
   'V430'  = 02
   'V431'  = 02
   'V4321' = 05
   'V4322' = 05
   'V433'  = 05
   'V434'  = 05
   'V435'  = 11
   'V4360' = 08
   'V4361' = 08
   'V4362' = 08
   'V4363' = 08
   'V4364' = 08
   'V4365' = 08
   'V4366' = 08
   'V4369' = 08
   'V437'  = 08
   'V4381' = 23
   'V4382' = 23
   'V4383' = 23
   'V4389' = 23
   'V440'  = 23
   'V441'  = 23
   'V442'  = 23
   'V443'  = 23
   'V444'  = 23
   'V4450' = 23
   'V4451' = 23
   'V4452' = 23
   'V4459' = 23
   'V446'  = 23
   'V447'  = 23
   'V448'  = 23
   'V449'  = 23
   'V4500' = 23
   'V4501' = 23
   'V4502' = 23
   'V4509' = 23
   'V4511' = 23
   'V4512' = 23
   'V452'  = 23
   'V453'  = 23
   'V454'  = 23
   'V4551' = 23
   'V4552' = 23
   'V4559' = 23
   'V4561' = 23
   'V4569' = 23
   'V4571' = 23
   'V4572' = 23
   'V4573' = 23
   'V4574' = 11
   'V4575' = 23
   'V4576' = 04
   'V4577' = 12
   'V4578' = 02
   'V4579' = 23
   'V4581' = 23
   'V4582' = 23
   'V4583' = 23
   'V4584' = 23
   'V4585' = 23
   'V4586' = 23
   'V4587' = 23
   'V4588' = 23
   'V4589' = 23
   'V460'  = 23
   'V4611' = 23
   'V4612' = 23
   'V4613' = 23
   'V4614' = 23
   'V462'  = 23
   'V463'  = 23
   'V468'  = 23
   'V469'  = 23
   'V470'  = 23
   'V471'  = 23
   'V472'  = 23
   'V473'  = 23
   'V474'  = 23
   'V475'  = 23
   'V479'  = 23
   'V480'  = 23
   'V481'  = 23
   'V482'  = 23
   'V483'  = 23
   'V484'  = 23
   'V485'  = 23
   'V486'  = 23
   'V487'  = 23
   'V488'  = 23
   'V489'  = 23
   'V490'  = 23
   'V491'  = 23
   'V492'  = 23
   'V493'  = 23
   'V494'  = 23
   'V495'  = 23
   'V4960' = 23
   'V4961' = 23
   'V4962' = 23
   'V4963' = 23
   'V4964' = 23
   'V4965' = 23
   'V4966' = 23
   'V4967' = 23
   'V4970' = 23
   'V4971' = 23
   'V4972' = 23
   'V4973' = 23
   'V4974' = 23
   'V4975' = 23
   'V4976' = 23
   'V4977' = 23
   'V4981' = 23
   'V4982' = 23
   'V4983' = 23
   'V4984' = 23
   'V4985' = 23
   'V4986' = 23
   'V4987' = 23
   'V4989' = 23
   'V499'  = 23
   'V500'  = 09
   'V501'  = 09
   'V502'  = 12
   'V503'  = 23
   'V5041' = 09
   'V5042' = 13
   'V5049' = 23
   'V508'  = 23
   'V509'  = 23
   'V510'  = 09
   'V518'  = 09
   'V520'  = 08
   'V521'  = 08
   'V522'  = 23
   'V523'  = 23
   'V524'  = 23
   'V528'  = 23
   'V529'  = 23
   'V5301' = 01
   'V5302' = 01
   'V5309' = 01
   'V531'  = 23
   'V532'  = 23
   'V5331' = 05
   'V5332' = 05
   'V5339' = 05
   'V534'  = 23
   'V5350' = 06
   'V5351' = 06
   'V5359' = 06
   'V536'  = 11
   'V537'  = 08
   'V538'  = 23
   'V5390' = 23
   'V5391' = 23
   'V5399' = 23
   'V5401' = 08
   'V5402' = 08
   'V5409' = 08
   'V5410' = 08
   'V5411' = 08
   'V5412' = 08
   'V5413' = 08
   'V5414' = 08
   'V5415' = 08
   'V5416' = 08
   'V5417' = 08
   'V5419' = 08
   'V5420' = 08
   'V5421' = 08
   'V5422' = 08
   'V5423' = 08
   'V5424' = 08
   'V5425' = 08
   'V5426' = 08
   'V5427' = 08
   'V5429' = 08
   'V5481' = 08
   'V5482' = 08
   'V5489' = 08
   'V549'  = 08
   'V550'  = 04
   'V551'  = 06
   'V552'  = 06
   'V553'  = 06
   'V554'  = 06
   'V555'  = 11
   'V556'  = 11
   'V557'  = 13
   'V558'  = 23
   'V559'  = 23
   'V560'  = 11
   'V561'  = 11
   'V562'  = 11
   'V5631' = 11
   'V5632' = 11
   'V568'  = 11
   'V570'  = 23
   'V571'  = 23
   'V5721' = 23
   'V5722' = 23
   'V573'  = 23
   'V574'  = 23
   'V5781' = 23
   'V5789' = 23
   'V579'  = 23
   'V580'  = 17
   'V5811' = 17
   'V5812' = 17
   'V582'  = 23
   'V5830' = 23
   'V5831' = 23
   'V5832' = 23
   'V5841' = 23
   'V5842' = 23
   'V5843' = 23
   'V5844' = 23
   'V5849' = 23
   'V585'  = 23
   'V5861' = 23
   'V5862' = 23
   'V5863' = 23
   'V5864' = 23
   'V5865' = 23
   'V5866' = 23
   'V5867' = 23
   'V5868' = 23
   'V5869' = 23
   'V5871' = 23
   'V5872' = 23
   'V5873' = 23
   'V5874' = 23
   'V5875' = 23
   'V5876' = 23
   'V5877' = 23
   'V5878' = 23
   'V5881' = 23
   'V5882' = 23
   'V5883' = 23
   'V5889' = 23
   'V589'  = 23
   'V5901' = 23
   'V5902' = 23
   'V5909' = 23
   'V591'  = 09
   'V592'  = 08
   'V593'  = 23
   'V594'  = 11
   'V595'  = 23
   'V596'  = 07
   'V5970' = 23
   'V5971' = 23
   'V5972' = 23
   'V5973' = 23
   'V5974' = 23
   'V598'  = 23
   'V599'  = 23
   'V600'  = 23
   'V601'  = 23
   'V602'  = 23
   'V603'  = 23
   'V604'  = 23
   'V605'  = 23
   'V606'  = 23
   'V6081' = 23
   'V6089' = 23
   'V609'  = 23
   'V6101' = 23
   'V6102' = 23
   'V6103' = 23
   'V6104' = 23
   'V6105' = 23
   'V6106' = 23
   'V6107' = 23
   'V6108' = 23
   'V6109' = 23
   'V6110' = 23
   'V6111' = 23
   'V6112' = 23
   'V6120' = 23
   'V6121' = 23
   'V6122' = 23
   'V6123' = 23
   'V6124' = 23
   'V6125' = 23
   'V6129' = 23
   'V613'  = 23
   'V6141' = 23
   'V6142' = 23
   'V6149' = 23
   'V615'  = 13
   'V616'  = 14
   'V617'  = 14
   'V618'  = 23
   'V619'  = 23
   'V620'  = 23
   'V621'  = 23
   'V6221' = 23
   'V6222' = 23
   'V6229' = 23
   'V623'  = 23
   'V624'  = 23
   'V625'  = 23
   'V626'  = 23
   'V6281' = 23
   'V6282' = 23
   'V6283' = 23
   'V6284' = 19
   'V6285' = 23
   'V6289' = 23
   'V629'  = 23
   'V630'  = 23
   'V631'  = 23
   'V632'  = 23
   'V638'  = 23
   'V639'  = 23
   'V6400' = 23
   'V6401' = 23
   'V6402' = 23
   'V6403' = 23
   'V6404' = 23
   'V6405' = 23
   'V6406' = 23
   'V6407' = 23
   'V6408' = 23
   'V6409' = 23
   'V641'  = 23
   'V642'  = 23
   'V643'  = 23
   'V6441' = 23
   'V6442' = 23
   'V6443' = 23
   'V650'  = 23
   'V6511' = 23
   'V6519' = 23
   'V652'  = 23
   'V653'  = 23
   'V6540' = 23
   'V6541' = 23
   'V6542' = 23
   'V6543' = 23
   'V6544' = 23
   'V6545' = 23
   'V6546' = 23
   'V6549' = 23
   'V655'  = 23
   'V658'  = 23
   'V659'  = 23
   'V660'  = 23
   'V661'  = 23
   'V662'  = 23
   'V663'  = 23
   'V664'  = 23
   'V665'  = 23
   'V666'  = 23
   'V667'  = 23
   'V669'  = 23
   'V6700' = 23
   'V6701' = 23
   'V6709' = 23
   'V671'  = 17
   'V672'  = 17
   'V673'  = 23
   'V674'  = 23
   'V6751' = 23
   'V6759' = 23
   'V676'  = 23
   'V679'  = 23
   'V6801' = 23
   'V6809' = 23
   'V681'  = 23
   'V682'  = 23
   'V6881' = 23
   'V6889' = 23
   'V689'  = 23
   'V690'  = 23
   'V691'  = 23
   'V692'  = 23
   'V693'  = 23
   'V694'  = 23
   'V695'  = 23
   'V698'  = 23
   'V699'  = 23
   'V700'  = 23
   'V701'  = 23
   'V702'  = 23
   'V703'  = 23
   'V704'  = 23
   'V705'  = 23
   'V706'  = 23
   'V707'  = 23
   'V708'  = 23
   'V709'  = 23
   'V7101' = 19
   'V7102' = 19
   'V7109' = 19
   'V711'  = 17
   'V712'  = 04
   'V713'  = 21
   'V714'  = 21
   'V715'  = 23
   'V716'  = 21
   'V717'  = 05
   'V7181' = 23
   'V7182' = 23
   'V7183' = 23
   'V7189' = 23
   'V719'  = 23
   'V720'  = 23
   'V7211' = 23
   'V7212' = 23
   'V7219' = 23
   'V722'  = 23
   'V7231' = 23
   'V7232' = 23
   'V7240' = 23
   'V7241' = 23
   'V7242' = 23
   'V725'  = 23
   'V7260' = 23
   'V7261' = 23
   'V7262' = 23
   'V7263' = 23
   'V7269' = 23
   'V727'  = 23
   'V7281' = 23
   'V7282' = 23
   'V7283' = 23
   'V7284' = 23
   'V7285' = 23
   'V7286' = 23
   'V729'  = 23
   'V730'  = 23
   'V731'  = 23
   'V732'  = 23
   'V733'  = 23
   'V734'  = 23
   'V735'  = 23
   'V736'  = 23
   'V7381' = 23
   'V7388' = 23
   'V7389' = 23
   'V7398' = 23
   'V7399' = 23
   'V740'  = 23
   'V741'  = 23
   'V742'  = 23
   'V743'  = 23
   'V744'  = 23
   'V745'  = 23
   'V746'  = 23
   'V748'  = 23
   'V749'  = 23
   'V750'  = 23
   'V751'  = 23
   'V752'  = 23
   'V753'  = 23
   'V754'  = 23
   'V755'  = 23
   'V756'  = 23
   'V757'  = 23
   'V758'  = 23
   'V759'  = 23
   'V760'  = 23
   'V7610' = 23
   'V7611' = 23
   'V7612' = 23
   'V7619' = 23
   'V762'  = 23
   'V763'  = 23
   'V7641' = 23
   'V7642' = 23
   'V7643' = 23
   'V7644' = 23
   'V7645' = 23
   'V7646' = 23
   'V7647' = 23
   'V7649' = 23
   'V7650' = 23
   'V7651' = 23
   'V7652' = 23
   'V7681' = 23
   'V7689' = 23
   'V769'  = 23
   'V770'  = 23
   'V771'  = 23
   'V772'  = 23
   'V773'  = 23
   'V774'  = 23
   'V775'  = 23
   'V776'  = 23
   'V777'  = 23
   'V778'  = 23
   'V7791' = 23
   'V7799' = 23
   'V780'  = 23
   'V781'  = 23
   'V782'  = 23
   'V783'  = 23
   'V788'  = 23
   'V789'  = 23
   'V790'  = 23
   'V791'  = 23
   'V792'  = 23
   'V793'  = 23
   'V798'  = 23
   'V799'  = 23
   'V8001' = 23
   'V8009' = 23
   'V801'  = 23
   'V802'  = 23
   'V803'  = 23
   'V810'  = 23
   'V811'  = 23
   'V812'  = 23
   'V813'  = 23
   'V814'  = 23
   'V815'  = 23
   'V816'  = 23
   'V820'  = 23
   'V821'  = 23
   'V822'  = 23
   'V823'  = 23
   'V824'  = 23
   'V825'  = 23
   'V826'  = 23
   'V8271' = 23
   'V8279' = 23
   'V8281' = 23
   'V8289' = 23
   'V829'  = 23
   'V8301' = 23
   'V8302' = 23
   'V8381' = 23
   'V8389' = 23
   'V8401' = 23
   'V8402' = 23
   'V8403' = 23
   'V8404' = 23
   'V8409' = 23
   'V8481' = 23
   'V8489' = 23
   'V850'  = 23
   'V851'  = 23
   'V8521' = 23
   'V8522' = 23
   'V8523' = 23
   'V8524' = 23
   'V8525' = 23
   'V8530' = 23
   'V8531' = 23
   'V8532' = 23
   'V8533' = 23
   'V8534' = 23
   'V8535' = 23
   'V8536' = 23
   'V8537' = 23
   'V8538' = 23
   'V8539' = 23
   'V8541' = 10
   'V8542' = 10
   'V8543' = 10
   'V8544' = 10
   'V8545' = 10
   'V8551' = 23
   'V8552' = 23
   'V8553' = 23
   'V8554' = 23
   'V860'  = 23
   'V861'  = 23
   'V8701' = 23
   'V8702' = 23
   'V8709' = 23
   'V8711' = 23
   'V8712' = 23
   'V8719' = 23
   'V872'  = 23
   'V8731' = 23
   'V8732' = 23
   'V8739' = 23
   'V8741' = 23
   'V8742' = 23
   'V8743' = 23
   'V8744' = 23
   'V8745' = 23
   'V8746' = 23
   'V8749' = 23
   'V8801' = 13
   'V8802' = 13
   'V8803' = 13
   'V8811' = 23
   'V8812' = 23
   'V8821' = 23
   'V8822' = 23
   'V8829' = 23
   'V8901' = 23
   'V8902' = 23
   'V8903' = 23
   'V8904' = 23
   'V8905' = 23
   'V8909' = 23
   'V9001' = 23
   'V9009' = 23
   'V9010' = 23
   'V9011' = 23
   'V9012' = 23
   'V902'  = 23
   'V9031' = 23
   'V9032' = 23
   'V9033' = 23
   'V9039' = 23
   'V9081' = 23
   'V9083' = 23
   'V9089' = 23
   'V909'  = 23
   'V9100' = 23
   'V9101' = 23
   'V9102' = 23
   'V9103' = 23
   'V9109' = 23
   'V9110' = 23
   'V9111' = 23
   'V9112' = 23
   'V9119' = 23
   'V9120' = 23
   'V9121' = 23
   'V9122' = 23
   'V9129' = 23
   'V9190' = 23
   'V9191' = 23
   'V9192' = 23
   'V9199' = 23
   OTHER   = .;

/* ------------------------------------------------------------- */
/* --- FORMATS FOR diagnosis and sites codes for MDC 24          */
/* ------------------------------------------------------------- */

   /*Format for Principal DX*/ 
   VALUE $pr
   '80000' = '1'
   '80001' = '1'
   '80002' = '1'
   '80003' = '1'
   '80004' = '1'
   '80005' = '1'
   '80006' = '1'
   '80009' = '1'
   '80010' = '1'
   '80011' = '1'
   '80012' = '1'
   '80013' = '1'
   '80014' = '1'
   '80015' = '1'
   '80016' = '1'
   '80019' = '1'
   '80020' = '1'
   '80021' = '1'
   '80022' = '1'
   '80023' = '1'
   '80024' = '1'
   '80025' = '1'
   '80026' = '1'
   '80029' = '1'
   '80030' = '1'
   '80031' = '1'
   '80032' = '1'
   '80033' = '1'
   '80034' = '1'
   '80035' = '1'
   '80036' = '1'
   '80039' = '1'
   '80040' = '1'
   '80041' = '1'
   '80042' = '1'
   '80043' = '1'
   '80044' = '1'
   '80045' = '1'
   '80046' = '1'
   '80049' = '1'
   '80050' = '1'
   '80051' = '1'
   '80052' = '1'
   '80053' = '1'
   '80054' = '1'
   '80055' = '1'
   '80056' = '1'
   '80059' = '1'
   '80060' = '1'
   '80061' = '1'
   '80062' = '1'
   '80063' = '1'
   '80064' = '1'
   '80132' = '1'
   '80133' = '1'
   '80134' = '1'
   '80135' = '1'
   '80136' = '1'
   '80139' = '1'
   '80140' = '1'
   '80141' = '1'
   '80142' = '1'
   '80143' = '1'
   '80144' = '1'
   '80145' = '1'
   '80146' = '1'
   '80149' = '1'
   '80150' = '1'
   '80151' = '1'
   '80152' = '1'
   '80153' = '1'
   '80154' = '1'
   '80155' = '1'
   '80156' = '1'
   '80159' = '1'
   '80160' = '1'
   '80161' = '1'
   '80162' = '1'
   '80163' = '1'
   '80164' = '1'
   '80165' = '1'
   '80166' = '1'
   '80169' = '1'
   '80170' = '1'
   '80171' = '1'
   '80172' = '1'
   '80173' = '1'
   '80174' = '1'
   '80175' = '1'
   '80176' = '1'
   '80179' = '1'
   '80180' = '1'
   '80181' = '1'
   '80182' = '1'
   '80183' = '1'
   '80184' = '1'
   '80185' = '1'
   '80186' = '1'
   '80189' = '1'
   '80190' = '1'
   '80191' = '1'
   '80192' = '1'
   '80193' = '1'
   '80194' = '1'
   '80195' = '1'
   '80196' = '1'
   '80199' = '1'
   '8020'  = '1'
   '8021'  = '1'
   '80220' = '1'
   '80221' = '1'
   '80222' = '1'
   '80223' = '1'
   '80224' = '1'
   '80225' = '1'
   '80226' = '1'
   '80227' = '1'
   '80228' = '1'
   '80360' = '1'
   '80361' = '1'
   '80362' = '1'
   '80363' = '1'
   '80364' = '1'
   '80365' = '1'
   '80366' = '1'
   '80369' = '1'
   '80370' = '1'
   '80371' = '1'
   '80372' = '1'
   '80373' = '1'
   '80374' = '1'
   '80375' = '1'
   '80376' = '1'
   '80379' = '1'
   '80380' = '1'
   '80381' = '1'
   '80382' = '1'
   '80383' = '1'
   '80384' = '1'
   '80385' = '1'
   '80386' = '1'
   '80389' = '1'
   '80390' = '1'
   '80391' = '1'
   '80392' = '1'
   '80393' = '1'
   '80394' = '1'
   '80395' = '1'
   '80396' = '1'
   '80399' = '1'
   '80400' = '1'
   '80401' = '1'
   '80402' = '1'
   '80403' = '1'
   '80404' = '1'
   '80405' = '1'
   '80406' = '1'
   '80409' = '1'
   '80410' = '1'
   '80411' = '1'
   '80412' = '1'
   '80413' = '1'
   '80414' = '1'
   '80415' = '1'
   '80416' = '1'
   '80419' = '1'
   '80420' = '1'
   '80421' = '1'
   '80422' = '1'
   '80423' = '1'
   '80424' = '1'
   '80425' = '1'
   '80426' = '1'
   '80429' = '1'
   '80430' = '1'
   '80431' = '1'
   '80432' = '1'
   '80433' = '1'
   '80434' = '1'
   '80435' = '1'
   '80436' = '1'
   '80439' = '1'
   '80440' = '1'
   '8052'  = '1'
   '8053'  = '1'
   '8054'  = '1'
   '8055'  = '1'
   '8056'  = '1'
   '8057'  = '1'
   '8058'  = '1'
   '8059'  = '1'
   '80600' = '1'
   '80601' = '1'
   '80602' = '1'
   '80603' = '1'
   '80604' = '1'
   '80605' = '1'
   '80606' = '1'
   '80607' = '1'
   '80608' = '1'
   '80609' = '1'
   '80610' = '1'
   '80611' = '1'
   '80612' = '1'
   '80613' = '1'
   '80614' = '1'
   '80615' = '1'
   '80616' = '1'
   '80617' = '1'
   '80618' = '1'
   '80619' = '1'
   '80620' = '1'
   '80621' = '1'
   '80622' = '1'
   '80623' = '1'
   '80624' = '1'
   '80625' = '1'
   '80626' = '1'
   '80627' = '1'
   '80628' = '1'
   '80629' = '1'
   '80630' = '1'
   '80631' = '1'
   '80632' = '1'
   '80633' = '1'
   '80634' = '1'
   '80635' = '1'
   '80636' = '1'
   '80637' = '1'
   '80638' = '1'
   '80639' = '1'
   '8064'  = '1'
   '8065'  = '1'
   '80660' = '1'
   '80661' = '1'
   '80662' = '1'
   '80669' = '1'
   '80670' = '1'
   '80671' = '1'
   '80672' = '1'
   '80679' = '1'
   '8068'  = '1'
   '8069'  = '1'
   '80700' = '1'
   '80701' = '1'
   '80702' = '1'
   '80703' = '1'
   '80704' = '1'
   '81221' = '1'
   '81230' = '1'
   '81231' = '1'
   '81240' = '1'
   '81241' = '1'
   '81242' = '1'
   '81243' = '1'
   '81244' = '1'
   '81249' = '1'
   '81250' = '1'
   '81251' = '1'
   '81252' = '1'
   '81253' = '1'
   '81254' = '1'
   '81259' = '1'
   '81300' = '1'
   '81301' = '1'
   '81302' = '1'
   '81303' = '1'
   '81304' = '1'
   '81305' = '1'
   '81306' = '1'
   '81307' = '1'
   '81308' = '1'
   '81310' = '1'
   '81311' = '1'
   '81312' = '1'
   '81313' = '1'
   '81314' = '1'
   '81315' = '1'
   '81316' = '1'
   '81317' = '1'
   '81318' = '1'
   '81320' = '1'
   '81321' = '1'
   '81322' = '1'
   '81323' = '1'
   '81330' = '1'
   '81331' = '1'
   '81332' = '1'
   '81333' = '1'
   '81340' = '1'
   '81341' = '1'
   '81342' = '1'
   '81343' = '1'
   '81344' = '1'
   '81345' = '1'
   '81350' = '1'
   '81351' = '1'
   '81352' = '1'
   '81353' = '1'
   '81354' = '1'
   '81380' = '1'
   '81381' = '1'
   '81382' = '1'
   '81383' = '1'
   '81390' = '1'
   '81391' = '1'
   '81392' = '1'
   '81393' = '1'
   '81400' = '1'
   '81401' = '1'
   '81402' = '1'
   '81403' = '1'
   '81404' = '1'
   '82122' = '1'
   '82123' = '1'
   '82129' = '1'
   '82130' = '1'
   '82131' = '1'
   '82132' = '1'
   '82133' = '1'
   '82139' = '1'
   '8220'  = '1'
   '8221'  = '1'
   '82300' = '1'
   '82301' = '1'
   '82302' = '1'
   '82310' = '1'
   '82311' = '1'
   '82312' = '1'
   '82320' = '1'
   '82321' = '1'
   '82322' = '1'
   '82330' = '1'
   '82331' = '1'
   '82332' = '1'
   '82340' = '1'
   '82341' = '1'
   '82342' = '1'
   '82380' = '1'
   '82381' = '1'
   '82382' = '1'
   '82390' = '1'
   '82391' = '1'
   '82392' = '1'
   '8240'  = '1'
   '8241'  = '1'
   '8242'  = '1'
   '8243'  = '1'
   '8244'  = '1'
   '8245'  = '1'
   '8246'  = '1'
   '8247'  = '1'
   '8248'  = '1'
   '8249'  = '1'
   '8250'  = '1'
   '8251'  = '1'
   '82520' = '1'
   '82521' = '1'
   '82522' = '1'
   '82523' = '1'
   '82524' = '1'
   '82525' = '1'
   '82529' = '1'
   '82530' = '1'
   '82531' = '1'
   '82532' = '1'
   '82533' = '1'
   '82534' = '1'
   '82535' = '1'
   '82539' = '1'
   '8260'  = '1'
   '8261'  = '1'
   '8270'  = '1'
   '8271'  = '1'
   '8280'  = '1'
   '8281'  = '1'
   '8290'  = '1'
   '8291'  = '1'
   '83660' = '1'
   '83661' = '1'
   '83662' = '1'
   '83663' = '1'
   '83664' = '1'
   '83669' = '1'
   '8370'  = '1'
   '8371'  = '1'
   '83800' = '1'
   '83801' = '1'
   '83802' = '1'
   '83803' = '1'
   '83804' = '1'
   '83805' = '1'
   '83806' = '1'
   '83809' = '1'
   '83810' = '1'
   '83811' = '1'
   '83812' = '1'
   '83813' = '1'
   '83814' = '1'
   '83815' = '1'
   '83816' = '1'
   '83819' = '1'
   '83900' = '1'
   '83901' = '1'
   '83902' = '1'
   '83903' = '1'
   '83904' = '1'
   '83905' = '1'
   '83906' = '1'
   '83907' = '1'
   '83908' = '1'
   '83910' = '1'
   '83911' = '1'
   '83912' = '1'
   '83913' = '1'
   '83914' = '1'
   '83915' = '1'
   '83916' = '1'
   '83917' = '1'
   '83918' = '1'
   '83920' = '1'
   '83921' = '1'
   '83930' = '1'
   '83931' = '1'
   '83940' = '1'
   '83941' = '1'
   '83942' = '1'
   '83949' = '1'
   '83950' = '1'
   '83951' = '1'
   '83952' = '1'
   '83959' = '1'
   '83961' = '1'
   '83969' = '1'
   '83971' = '1'
   '83979' = '1'
   '8398'  = '1'
   '8399'  = '1'
   '8400'  = '1'
   '8401'  = '1'
   '8402'  = '1'
   '8403'  = '1'
   '8404'  = '1'
   '85012' = '1'
   '8502'  = '1'
   '8503'  = '1'
   '8504'  = '1'
   '8505'  = '1'
   '8509'  = '1'
   '85100' = '1'
   '85101' = '1'
   '85102' = '1'
   '85103' = '1'
   '85104' = '1'
   '85105' = '1'
   '85106' = '1'
   '85109' = '1'
   '85110' = '1'
   '85111' = '1'
   '85112' = '1'
   '85113' = '1'
   '85114' = '1'
   '85115' = '1'
   '85116' = '1'
   '85119' = '1'
   '85120' = '1'
   '85121' = '1'
   '85122' = '1'
   '85123' = '1'
   '85124' = '1'
   '85125' = '1'
   '85126' = '1'
   '85129' = '1'
   '85130' = '1'
   '85131' = '1'
   '85132' = '1'
   '85133' = '1'
   '85134' = '1'
   '85135' = '1'
   '85136' = '1'
   '85139' = '1'
   '85140' = '1'
   '85141' = '1'
   '85142' = '1'
   '85143' = '1'
   '85144' = '1'
   '85145' = '1'
   '85146' = '1'
   '85149' = '1'
   '85150' = '1'
   '85151' = '1'
   '85152' = '1'
   '85153' = '1'
   '85154' = '1'
   '85155' = '1'
   '85156' = '1'
   '85159' = '1'
   '85160' = '1'
   '85161' = '1'
   '85162' = '1'
   '85163' = '1'
   '85164' = '1'
   '85165' = '1'
   '85166' = '1'
   '85169' = '1'
   '85170' = '1'
   '85171' = '1'
   '85172' = '1'
   '85254' = '1'
   '85255' = '1'
   '85256' = '1'
   '85259' = '1'
   '85300' = '1'
   '85301' = '1'
   '85302' = '1'
   '85303' = '1'
   '85304' = '1'
   '85305' = '1'
   '85306' = '1'
   '85309' = '1'
   '85310' = '1'
   '85311' = '1'
   '85312' = '1'
   '85313' = '1'
   '85314' = '1'
   '85315' = '1'
   '85316' = '1'
   '85319' = '1'
   '85400' = '1'
   '85401' = '1'
   '85402' = '1'
   '85403' = '1'
   '85404' = '1'
   '85405' = '1'
   '85406' = '1'
   '85409' = '1'
   '85410' = '1'
   '85411' = '1'
   '85412' = '1'
   '85413' = '1'
   '85414' = '1'
   '85415' = '1'
   '85416' = '1'
   '85419' = '1'
   '8600'  = '1'
   '8601'  = '1'
   '8602'  = '1'
   '8603'  = '1'
   '8604'  = '1'
   '8605'  = '1'
   '86100' = '1'
   '86101' = '1'
   '86102' = '1'
   '86103' = '1'
   '86110' = '1'
   '86111' = '1'
   '86112' = '1'
   '86113' = '1'
   '86120' = '1'
   '86121' = '1'
   '86122' = '1'
   '86130' = '1'
   '86131' = '1'
   '86132' = '1'
   '8620'  = '1'
   '8621'  = '1'
   '86221' = '1'
   '86222' = '1'
   '86229' = '1'
   '86231' = '1'
   '86232' = '1'
   '86239' = '1'
   '8628'  = '1'
   '86600' = '1'
   '86601' = '1'
   '86602' = '1'
   '86603' = '1'
   '86610' = '1'
   '86611' = '1'
   '86612' = '1'
   '86613' = '1'
   '8670'  = '1'
   '8671'  = '1'
   '8672'  = '1'
   '8673'  = '1'
   '8674'  = '1'
   '8675'  = '1'
   '8676'  = '1'
   '8677'  = '1'
   '8678'  = '1'
   '8679'  = '1'
   '86800' = '1'
   '86801' = '1'
   '86802' = '1'
   '86803' = '1'
   '86804' = '1'
   '86809' = '1'
   '86810' = '1'
   '86811' = '1'
   '86812' = '1'
   '86813' = '1'
   '86814' = '1'
   '86819' = '1'
   '8690'  = '1'
   '8691'  = '1'
   '8700'  = '1'
   '8701'  = '1'
   '8702'  = '1'
   '8703'  = '1'
   '8704'  = '1'
   '8708'  = '1'
   '8709'  = '1'
   '8710'  = '1'
   '8711'  = '1'
   '8712'  = '1'
   '8713'  = '1'
   '8714'  = '1'
   '8715'  = '1'
   '8716'  = '1'
   '8717'  = '1'
   '8719'  = '1'
   '87200' = '1'
   '87201' = '1'
   '87202' = '1'
   '87210' = '1'
   '87211' = '1'
   '87212' = '1'
   '87261' = '1'
   '87262' = '1'
   '87263' = '1'
   '87264' = '1'
   '87269' = '1'
   '87271' = '1'
   '87272' = '1'
   '87273' = '1'
   '87274' = '1'
   '87279' = '1'
   '8728'  = '1'
   '8786'  = '1'
   '8787'  = '1'
   '8788'  = '1'
   '8789'  = '1'
   '8790'  = '1'
   '8791'  = '1'
   '8792'  = '1'
   '8793'  = '1'
   '8794'  = '1'
   '8795'  = '1'
   '8796'  = '1'
   '8797'  = '1'
   '8798'  = '1'
   '8799'  = '1'
   '88000' = '1'
   '88001' = '1'
   '88002' = '1'
   '88003' = '1'
   '88009' = '1'
   '88010' = '1'
   '88011' = '1'
   '88012' = '1'
   '88013' = '1'
   '88019' = '1'
   '88020' = '1'
   '88021' = '1'
   '88022' = '1'
   '88023' = '1'
   '88029' = '1'
   '88100' = '1'
   '88101' = '1'
   '88102' = '1'
   '88110' = '1'
   '88111' = '1'
   '88112' = '1'
   '88120' = '1'
   '88121' = '1'
   '88122' = '1'
   '8820'  = '1'
   '8821'  = '1'
   '8822'  = '1'
   '8830'  = '1'
   '8831'  = '1'
   '8832'  = '1'
   '8840'  = '1'
   '8841'  = '1'
   '8842'  = '1'
   '8850'  = '1'
   '8851'  = '1'
   '8860'  = '1'
   '8861'  = '1'
   '8870'  = '1'
   '8871'  = '1'
   '8872'  = '1'
   '8873'  = '1'
   '8874'  = '1'
   '8875'  = '1'
   '8876'  = '1'
   '8877'  = '1'
   '8900'  = '1'
   '8901'  = '1'
   '8902'  = '1'
   '8910'  = '1'
   '8911'  = '1'
   '8912'  = '1'
   '90249' = '1'
   '90250' = '1'
   '90251' = '1'
   '90252' = '1'
   '90253' = '1'
   '90254' = '1'
   '90255' = '1'
   '90256' = '1'
   '90259' = '1'
   '90281' = '1'
   '90282' = '1'
   '90287' = '1'
   '90289' = '1'
   '9029'  = '1'
   '90300' = '1'
   '90301' = '1'
   '90302' = '1'
   '9031'  = '1'
   '9032'  = '1'
   '9033'  = '1'
   '9034'  = '1'
   '9035'  = '1'
   '9038'  = '1'
   '9039'  = '1'
   '9040'  = '1'
   '9041'  = '1'
   '9042'  = '1'
   '9043'  = '1'
   '90440' = '1'
   '90441' = '1'
   '90442' = '1'
   '90450' = '1'
   '90451' = '1'
   '90452' = '1'
   '90453' = '1'
   '90454' = '1'
   '9046'  = '1'
   '9047'  = '1'
   '9048'  = '1'
   '9049'  = '1'
   '9100'  = '1'
   '9101'  = '1'
   '9102'  = '1'
   '9103'  = '1'
   '9104'  = '1'
   '9105'  = '1'
   '9106'  = '1'
   '9107'  = '1'
   '9108'  = '1'
   '9109'  = '1'
   '9110'  = '1'
   '9111'  = '1'
   '9112'  = '1'
   '9113'  = '1'
   '9114'  = '1'
   '9115'  = '1'
   '9116'  = '1'
   '9117'  = '1'
   '9118'  = '1'
   '9119'  = '1'
   '9120'  = '1'
   '9121'  = '1'
   '9122'  = '1'
   '9123'  = '1'
   '9124'  = '1'
   '9196'  = '1'
   '9197'  = '1'
   '9198'  = '1'
   '9199'  = '1'
   '920'   = '1'
   '9210'  = '1'
   '9211'  = '1'
   '9212'  = '1'
   '9213'  = '1'
   '9219'  = '1'
   '9220'  = '1'
   '9221'  = '1'
   '9222'  = '1'
   '92231' = '1'
   '92232' = '1'
   '92233' = '1'
   '9224'  = '1'
   '9228'  = '1'
   '9229'  = '1'
   '92300' = '1'
   '92301' = '1'
   '92302' = '1'
   '92303' = '1'
   '92309' = '1'
   '92310' = '1'
   '92311' = '1'
   '92320' = '1'
   '92321' = '1'
   '9233'  = '1'
   '9238'  = '1'
   '9239'  = '1'
   '92400' = '1'
   '92401' = '1'
   '92410' = '1'
   '92411' = '1'
   '92420' = '1'
   '92421' = '1'
   '9243'  = '1'
   '9244'  = '1'
   '9245'  = '1'
   '9248'  = '1'
   '9249'  = '1'
   '9251'  = '1'
   '9252'  = '1'
   '9260'  = '1'
   '92611' = '1'
   '92612' = '1'
   '92619' = '1'
   '9268'  = '1'
   '9269'  = '1'
   '92700' = '1'
   '92701' = '1'
   '92702' = '1'
   '92703' = '1'
   '92709' = '1'
   '92710' = '1'
   '92711' = '1'
   '92720' = '1'
   '92721' = '1'
   '9273'  = '1'
   '9278'  = '1'
   '9279'  = '1'
   '92800' = '1'
   '92801' = '1'
   '92810' = '1'
   '9555'  = '1'
   '9556'  = '1'
   '9557'  = '1'
   '9558'  = '1'
   '9559'  = '1'
   '9560'  = '1'
   '9561'  = '1'
   '9562'  = '1'
   '9563'  = '1'
   '9564'  = '1'
   '9565'  = '1'
   '9568'  = '1'
   '9569'  = '1'
   '9570'  = '1'
   '9571'  = '1'
   '9578'  = '1'
   '9579'  = '1'
   '9580'  = '1'
   '9581'  = '1'
   '9582'  = '1'
   '9583'  = '1'
   '80065' = '1'
   '80066' = '1'
   '80069' = '1'
   '80070' = '1'
   '80071' = '1'
   '80072' = '1'
   '80073' = '1'
   '80074' = '1'
   '80075' = '1'
   '80076' = '1'
   '80079' = '1'
   '80080' = '1'
   '80081' = '1'
   '80082' = '1'
   '80083' = '1'
   '80084' = '1'
   '80085' = '1'
   '80086' = '1'
   '80089' = '1'
   '80090' = '1'
   '80091' = '1'
   '80092' = '1'
   '80093' = '1'
   '80094' = '1'
   '80095' = '1'
   '80096' = '1'
   '80099' = '1'
   '80100' = '1'
   '80101' = '1'
   '80102' = '1'
   '80103' = '1'
   '80104' = '1'
   '80105' = '1'
   '80106' = '1'
   '80109' = '1'
   '80110' = '1'
   '80111' = '1'
   '80112' = '1'
   '80113' = '1'
   '80114' = '1'
   '80115' = '1'
   '80116' = '1'
   '80119' = '1'
   '80120' = '1'
   '80121' = '1'
   '80122' = '1'
   '80123' = '1'
   '80124' = '1'
   '80125' = '1'
   '80126' = '1'
   '80129' = '1'
   '80130' = '1'
   '80131' = '1'
   '80229' = '1'
   '80230' = '1'
   '80231' = '1'
   '80232' = '1'
   '80233' = '1'
   '80234' = '1'
   '80235' = '1'
   '80236' = '1'
   '80237' = '1'
   '80238' = '1'
   '80239' = '1'
   '8024'  = '1'
   '8025'  = '1'
   '8026'  = '1'
   '8027'  = '1'
   '8028'  = '1'
   '8029'  = '1'
   '80300' = '1'
   '80301' = '1'
   '80302' = '1'
   '80303' = '1'
   '80304' = '1'
   '80305' = '1'
   '80306' = '1'
   '80309' = '1'
   '80310' = '1'
   '80311' = '1'
   '80312' = '1'
   '80313' = '1'
   '80314' = '1'
   '80315' = '1'
   '80316' = '1'
   '80319' = '1'
   '80320' = '1'
   '80321' = '1'
   '80322' = '1'
   '80323' = '1'
   '80324' = '1'
   '80325' = '1'
   '80326' = '1'
   '80329' = '1'
   '80330' = '1'
   '80331' = '1'
   '80332' = '1'
   '80333' = '1'
   '80334' = '1'
   '80335' = '1'
   '80336' = '1'
   '80339' = '1'
   '80340' = '1'
   '80341' = '1'
   '80342' = '1'
   '80343' = '1'
   '80344' = '1'
   '80345' = '1'
   '80346' = '1'
   '80349' = '1'
   '80350' = '1'
   '80351' = '1'
   '80352' = '1'
   '80353' = '1'
   '80354' = '1'
   '80355' = '1'
   '80356' = '1'
   '80359' = '1'
   '80441' = '1'
   '80442' = '1'
   '80443' = '1'
   '80444' = '1'
   '80445' = '1'
   '80446' = '1'
   '80449' = '1'
   '80450' = '1'
   '80451' = '1'
   '80452' = '1'
   '80453' = '1'
   '80454' = '1'
   '80455' = '1'
   '80456' = '1'
   '80459' = '1'
   '80460' = '1'
   '80461' = '1'
   '80462' = '1'
   '80463' = '1'
   '80464' = '1'
   '80465' = '1'
   '80466' = '1'
   '80469' = '1'
   '80470' = '1'
   '80471' = '1'
   '80472' = '1'
   '80473' = '1'
   '80474' = '1'
   '80475' = '1'
   '80476' = '1'
   '80479' = '1'
   '80480' = '1'
   '80481' = '1'
   '80482' = '1'
   '80483' = '1'
   '80484' = '1'
   '80485' = '1'
   '80486' = '1'
   '80489' = '1'
   '80490' = '1'
   '80491' = '1'
   '80492' = '1'
   '80493' = '1'
   '80494' = '1'
   '80495' = '1'
   '80496' = '1'
   '80499' = '1'
   '80500' = '1'
   '80501' = '1'
   '80502' = '1'
   '80503' = '1'
   '80504' = '1'
   '80505' = '1'
   '80506' = '1'
   '80507' = '1'
   '80508' = '1'
   '80510' = '1'
   '80511' = '1'
   '80512' = '1'
   '80513' = '1'
   '80514' = '1'
   '80515' = '1'
   '80516' = '1'
   '80517' = '1'
   '80518' = '1'
   '80705' = '1'
   '80706' = '1'
   '80707' = '1'
   '80708' = '1'
   '80709' = '1'
   '80710' = '1'
   '80711' = '1'
   '80712' = '1'
   '80713' = '1'
   '80714' = '1'
   '80715' = '1'
   '80716' = '1'
   '80717' = '1'
   '80718' = '1'
   '80719' = '1'
   '8072'  = '1'
   '8073'  = '1'
   '8074'  = '1'
   '8075'  = '1'
   '8076'  = '1'
   '8080'  = '1'
   '8081'  = '1'
   '8082'  = '1'
   '8083'  = '1'
   '80841' = '1'
   '80842' = '1'
   '80843' = '1'
   '80849' = '1'
   '80851' = '1'
   '80852' = '1'
   '80853' = '1'
   '80859' = '1'
   '8088'  = '1'
   '8089'  = '1'
   '8090'  = '1'
   '8091'  = '1'
   '81000' = '1'
   '81001' = '1'
   '81002' = '1'
   '81003' = '1'
   '81010' = '1'
   '81011' = '1'
   '81012' = '1'
   '81013' = '1'
   '81100' = '1'
   '81101' = '1'
   '81102' = '1'
   '81103' = '1'
   '81109' = '1'
   '81110' = '1'
   '81111' = '1'
   '81112' = '1'
   '81113' = '1'
   '81119' = '1'
   '81200' = '1'
   '81201' = '1'
   '81202' = '1'
   '81203' = '1'
   '81209' = '1'
   '81210' = '1'
   '81211' = '1'
   '81212' = '1'
   '81213' = '1'
   '81219' = '1'
   '81220' = '1'
   '81405' = '1'
   '81406' = '1'
   '81407' = '1'
   '81408' = '1'
   '81409' = '1'
   '81410' = '1'
   '81411' = '1'
   '81412' = '1'
   '81413' = '1'
   '81414' = '1'
   '81415' = '1'
   '81416' = '1'
   '81417' = '1'
   '81418' = '1'
   '81419' = '1'
   '81500' = '1'
   '81501' = '1'
   '81502' = '1'
   '81503' = '1'
   '81504' = '1'
   '81509' = '1'
   '81510' = '1'
   '81511' = '1'
   '81512' = '1'
   '81513' = '1'
   '81514' = '1'
   '81519' = '1'
   '81600' = '1'
   '81601' = '1'
   '81602' = '1'
   '81603' = '1'
   '81610' = '1'
   '81611' = '1'
   '81612' = '1'
   '81613' = '1'
   '8170'  = '1'
   '8171'  = '1'
   '8180'  = '1'
   '8181'  = '1'
   '8190'  = '1'
   '8191'  = '1'
   '82000' = '1'
   '82001' = '1'
   '82002' = '1'
   '82003' = '1'
   '82009' = '1'
   '82010' = '1'
   '82011' = '1'
   '82012' = '1'
   '82013' = '1'
   '82019' = '1'
   '82020' = '1'
   '82021' = '1'
   '82022' = '1'
   '82030' = '1'
   '82031' = '1'
   '82032' = '1'
   '8208'  = '1'
   '8209'  = '1'
   '82100' = '1'
   '82101' = '1'
   '82110' = '1'
   '82111' = '1'
   '82120' = '1'
   '82121' = '1'
   '8300'  = '1'
   '8301'  = '1'
   '83100' = '1'
   '83101' = '1'
   '83102' = '1'
   '83103' = '1'
   '83104' = '1'
   '83109' = '1'
   '83110' = '1'
   '83111' = '1'
   '83112' = '1'
   '83113' = '1'
   '83114' = '1'
   '83119' = '1'
   '83200' = '1'
   '83201' = '1'
   '83202' = '1'
   '83203' = '1'
   '83204' = '1'
   '83209' = '1'
   '83210' = '1'
   '83211' = '1'
   '83212' = '1'
   '83213' = '1'
   '83214' = '1'
   '83219' = '1'
   '83300' = '1'
   '83301' = '1'
   '83302' = '1'
   '83303' = '1'
   '83304' = '1'
   '83305' = '1'
   '83309' = '1'
   '83310' = '1'
   '83311' = '1'
   '83312' = '1'
   '83313' = '1'
   '83314' = '1'
   '83315' = '1'
   '83319' = '1'
   '83400' = '1'
   '83401' = '1'
   '83402' = '1'
   '83410' = '1'
   '83411' = '1'
   '83412' = '1'
   '83500' = '1'
   '83501' = '1'
   '83502' = '1'
   '83503' = '1'
   '83510' = '1'
   '83511' = '1'
   '83512' = '1'
   '83513' = '1'
   '8360'  = '1'
   '8361'  = '1'
   '8362'  = '1'
   '8363'  = '1'
   '8364'  = '1'
   '83650' = '1'
   '83651' = '1'
   '83652' = '1'
   '83653' = '1'
   '83654' = '1'
   '83659' = '1'
   '8405'  = '1'
   '8406'  = '1'
   '8407'  = '1'
   '8408'  = '1'
   '8409'  = '1'
   '8410'  = '1'
   '8411'  = '1'
   '8412'  = '1'
   '8413'  = '1'
   '8418'  = '1'
   '8419'  = '1'
   '84200' = '1'
   '84201' = '1'
   '84202' = '1'
   '84209' = '1'
   '84210' = '1'
   '84211' = '1'
   '84212' = '1'
   '84213' = '1'
   '84219' = '1'
   '8430'  = '1'
   '8431'  = '1'
   '8438'  = '1'
   '8439'  = '1'
   '8440'  = '1'
   '8441'  = '1'
   '8442'  = '1'
   '8443'  = '1'
   '8448'  = '1'
   '8449'  = '1'
   '84500' = '1'
   '84501' = '1'
   '84502' = '1'
   '84503' = '1'
   '84509' = '1'
   '84510' = '1'
   '84511' = '1'
   '84512' = '1'
   '84513' = '1'
   '84519' = '1'
   '8460'  = '1'
   '8461'  = '1'
   '8462'  = '1'
   '8463'  = '1'
   '8468'  = '1'
   '8469'  = '1'
   '8470'  = '1'
   '8471'  = '1'
   '8472'  = '1'
   '8473'  = '1'
   '8474'  = '1'
   '8479'  = '1'
   '8480'  = '1'
   '8481'  = '1'
   '8482'  = '1'
   '8483'  = '1'
   '84840' = '1'
   '84841' = '1'
   '84842' = '1'
   '84849' = '1'
   '8485'  = '1'
   '8488'  = '1'
   '8489'  = '1'
   '8500'  = '1'
   '85011' = '1'
   '85173' = '1'
   '85174' = '1'
   '85175' = '1'
   '85176' = '1'
   '85179' = '1'
   '85180' = '1'
   '85181' = '1'
   '85182' = '1'
   '85183' = '1'
   '85184' = '1'
   '85185' = '1'
   '85186' = '1'
   '85189' = '1'
   '85190' = '1'
   '85191' = '1'
   '85192' = '1'
   '85193' = '1'
   '85194' = '1'
   '85195' = '1'
   '85196' = '1'
   '85199' = '1'
   '85200' = '1'
   '85201' = '1'
   '85202' = '1'
   '85203' = '1'
   '85204' = '1'
   '85205' = '1'
   '85206' = '1'
   '85209' = '1'
   '85210' = '1'
   '85211' = '1'
   '85212' = '1'
   '85213' = '1'
   '85214' = '1'
   '85215' = '1'
   '85216' = '1'
   '85219' = '1'
   '85220' = '1'
   '85221' = '1'
   '85222' = '1'
   '85223' = '1'
   '85224' = '1'
   '85225' = '1'
   '85226' = '1'
   '85229' = '1'
   '85230' = '1'
   '85231' = '1'
   '85232' = '1'
   '85233' = '1'
   '85234' = '1'
   '85235' = '1'
   '85236' = '1'
   '85239' = '1'
   '85240' = '1'
   '85241' = '1'
   '85242' = '1'
   '85243' = '1'
   '85244' = '1'
   '85245' = '1'
   '85246' = '1'
   '85249' = '1'
   '85250' = '1'
   '85251' = '1'
   '85252' = '1'
   '85253' = '1'
   '8629'  = '1'
   '8630'  = '1'
   '8631'  = '1'
   '86320' = '1'
   '86321' = '1'
   '86329' = '1'
   '86330' = '1'
   '86331' = '1'
   '86339' = '1'
   '86340' = '1'
   '86341' = '1'
   '86342' = '1'
   '86343' = '1'
   '86344' = '1'
   '86345' = '1'
   '86346' = '1'
   '86349' = '1'
   '86350' = '1'
   '86351' = '1'
   '86352' = '1'
   '86353' = '1'
   '86354' = '1'
   '86355' = '1'
   '86356' = '1'
   '86359' = '1'
   '86380' = '1'
   '86381' = '1'
   '86382' = '1'
   '86383' = '1'
   '86384' = '1'
   '86385' = '1'
   '86389' = '1'
   '86390' = '1'
   '86391' = '1'
   '86392' = '1'
   '86393' = '1'
   '86394' = '1'
   '86395' = '1'
   '86399' = '1'
   '86400' = '1'
   '86401' = '1'
   '86402' = '1'
   '86403' = '1'
   '86404' = '1'
   '86405' = '1'
   '86409' = '1'
   '86410' = '1'
   '86411' = '1'
   '86412' = '1'
   '86413' = '1'
   '86414' = '1'
   '86415' = '1'
   '86419' = '1'
   '86500' = '1'
   '86501' = '1'
   '86502' = '1'
   '86503' = '1'
   '86504' = '1'
   '86509' = '1'
   '86510' = '1'
   '86511' = '1'
   '86512' = '1'
   '86513' = '1'
   '86514' = '1'
   '86519' = '1'
   '8729'  = '1'
   '8730'  = '1'
   '8731'  = '1'
   '87320' = '1'
   '87321' = '1'
   '87322' = '1'
   '87323' = '1'
   '87329' = '1'
   '87330' = '1'
   '87331' = '1'
   '87332' = '1'
   '87333' = '1'
   '87339' = '1'
   '87340' = '1'
   '87341' = '1'
   '87342' = '1'
   '87343' = '1'
   '87344' = '1'
   '87349' = '1'
   '87350' = '1'
   '87351' = '1'
   '87352' = '1'
   '87353' = '1'
   '87354' = '1'
   '87359' = '1'
   '87360' = '1'
   '87361' = '1'
   '87362' = '1'
   '87363' = '1'
   '87364' = '1'
   '87365' = '1'
   '87369' = '1'
   '87370' = '1'
   '87371' = '1'
   '87372' = '1'
   '87373' = '1'
   '87374' = '1'
   '87375' = '1'
   '87379' = '1'
   '8738'  = '1'
   '8739'  = '1'
   '87400' = '1'
   '87401' = '1'
   '87402' = '1'
   '87410' = '1'
   '87411' = '1'
   '87412' = '1'
   '8742'  = '1'
   '8743'  = '1'
   '8744'  = '1'
   '8745'  = '1'
   '8748'  = '1'
   '8749'  = '1'
   '8750'  = '1'
   '8751'  = '1'
   '8760'  = '1'
   '8761'  = '1'
   '8770'  = '1'
   '8771'  = '1'
   '8780'  = '1'
   '8781'  = '1'
   '8782'  = '1'
   '8783'  = '1'
   '8784'  = '1'
   '8785'  = '1'
   '8920'  = '1'
   '8921'  = '1'
   '8922'  = '1'
   '8930'  = '1'
   '8931'  = '1'
   '8932'  = '1'
   '8940'  = '1'
   '8941'  = '1'
   '8942'  = '1'
   '8950'  = '1'
   '8951'  = '1'
   '8960'  = '1'
   '8961'  = '1'
   '8962'  = '1'
   '8963'  = '1'
   '8970'  = '1'
   '8971'  = '1'
   '8972'  = '1'
   '8973'  = '1'
   '8974'  = '1'
   '8975'  = '1'
   '8976'  = '1'
   '8977'  = '1'
   '90000' = '1'
   '90001' = '1'
   '90002' = '1'
   '90003' = '1'
   '9001'  = '1'
   '90081' = '1'
   '90082' = '1'
   '90089' = '1'
   '9009'  = '1'
   '9010'  = '1'
   '9011'  = '1'
   '9012'  = '1'
   '9013'  = '1'
   '90140' = '1'
   '90141' = '1'
   '90142' = '1'
   '90181' = '1'
   '90182' = '1'
   '90183' = '1'
   '90189' = '1'
   '9019'  = '1'
   '9020'  = '1'
   '90210' = '1'
   '90211' = '1'
   '90219' = '1'
   '90220' = '1'
   '90221' = '1'
   '90222' = '1'
   '90223' = '1'
   '90224' = '1'
   '90225' = '1'
   '90226' = '1'
   '90227' = '1'
   '90229' = '1'
   '90231' = '1'
   '90232' = '1'
   '90233' = '1'
   '90234' = '1'
   '90239' = '1'
   '90240' = '1'
   '90241' = '1'
   '90242' = '1'
   '9125'  = '1'
   '9126'  = '1'
   '9127'  = '1'
   '9128'  = '1'
   '9129'  = '1'
   '9130'  = '1'
   '9131'  = '1'
   '9132'  = '1'
   '9133'  = '1'
   '9134'  = '1'
   '9135'  = '1'
   '9136'  = '1'
   '9137'  = '1'
   '9138'  = '1'
   '9139'  = '1'
   '9140'  = '1'
   '9141'  = '1'
   '9142'  = '1'
   '9143'  = '1'
   '9144'  = '1'
   '9145'  = '1'
   '9146'  = '1'
   '9147'  = '1'
   '9148'  = '1'
   '9149'  = '1'
   '9150'  = '1'
   '9151'  = '1'
   '9152'  = '1'
   '9153'  = '1'
   '9154'  = '1'
   '9155'  = '1'
   '9156'  = '1'
   '9157'  = '1'
   '9158'  = '1'
   '9159'  = '1'
   '9160'  = '1'
   '9161'  = '1'
   '9162'  = '1'
   '9163'  = '1'
   '9164'  = '1'
   '9165'  = '1'
   '9166'  = '1'
   '9167'  = '1'
   '9168'  = '1'
   '9169'  = '1'
   '9170'  = '1'
   '9171'  = '1'
   '9172'  = '1'
   '9173'  = '1'
   '9174'  = '1'
   '9175'  = '1'
   '9176'  = '1'
   '9177'  = '1'
   '9178'  = '1'
   '9179'  = '1'
   '9180'  = '1'
   '9181'  = '1'
   '9182'  = '1'
   '9189'  = '1'
   '9190'  = '1'
   '9191'  = '1'
   '9192'  = '1'
   '9193'  = '1'
   '9194'  = '1'
   '9195'  = '1'
   '92811' = '1'
   '92820' = '1'
   '92821' = '1'
   '9283'  = '1'
   '9288'  = '1'
   '9289'  = '1'
   '9290'  = '1'
   '9299'  = '1'
   '9500'  = '1'
   '9501'  = '1'
   '9502'  = '1'
   '9503'  = '1'
   '9509'  = '1'
   '9510'  = '1'
   '9511'  = '1'
   '9512'  = '1'
   '9513'  = '1'
   '9514'  = '1'
   '9515'  = '1'
   '9516'  = '1'
   '9517'  = '1'
   '9518'  = '1'
   '9519'  = '1'
   '95200' = '1'
   '95201' = '1'
   '95202' = '1'
   '95203' = '1'
   '95204' = '1'
   '95205' = '1'
   '95206' = '1'
   '95207' = '1'
   '95208' = '1'
   '95209' = '1'
   '95210' = '1'
   '95211' = '1'
   '95212' = '1'
   '95213' = '1'
   '95214' = '1'
   '95215' = '1'
   '95216' = '1'
   '95217' = '1'
   '95218' = '1'
   '95219' = '1'
   '9522'  = '1'
   '9523'  = '1'
   '9524'  = '1'
   '9528'  = '1'
   '9529'  = '1'
   '9530'  = '1'
   '9531'  = '1'
   '9532'  = '1'
   '9533'  = '1'
   '9534'  = '1'
   '9535'  = '1'
   '9538'  = '1'
   '9539'  = '1'
   '9540'  = '1'
   '9541'  = '1'
   '9548'  = '1'
   '9549'  = '1'
   '9550'  = '1'
   '9551'  = '1'
   '9552'  = '1'
   '9553'  = '1'
   '9554'  = '1'
   '9584'  = '1'
   '9585'  = '1'
   '9586'  = '1'
   '9587'  = '1'
   '9588'  = '1'
   '95901' = '1'
   '95909' = '1'
   '95911' = '1'
   '95912' = '1'
   '95913' = '1'
   '95914' = '1'
   '95919' = '1'
   '9592'  = '1'
   '9593'  = '1'
   '9594'  = '1'
   '9595'  = '1'
   '9596'  = '1'
   '9597'  = '1'
   '9598'  = '1'
   '9599'  = '1'
   OTHER   = '0';


   /*Format for Medical_Head*/ 
   VALUE $s1fmt
   '80002' = '1'
   '80003' = '1'
   '80004' = '1'
   '80005' = '1'
   '80010' = '1'
   '80012' = '1'
   '80013' = '1'
   '80014' = '1'
   '80015' = '1'
   '80016' = '1'
   '80019' = '1'
   '80020' = '1'
   '80022' = '1'
   '80023' = '1'
   '80024' = '1'
   '80025' = '1'
   '80026' = '1'
   '80029' = '1'
   '80030' = '1'
   '80032' = '1'
   '80033' = '1'
   '80034' = '1'
   '80035' = '1'
   '80036' = '1'
   '80039' = '1'
   '80040' = '1'
   '80042' = '1'
   '80043' = '1'
   '80044' = '1'
   '80045' = '1'
   '80046' = '1'
   '80049' = '1'
   '80052' = '1'
   '80053' = '1'
   '80054' = '1'
   '80055' = '1'
   '80060' = '1'
   '80061' = '1'
   '80062' = '1'
   '80116' = '1'
   '80119' = '1'
   '80120' = '1'
   '80121' = '1'
   '80122' = '1'
   '80123' = '1'
   '80124' = '1'
   '80125' = '1'
   '80126' = '1'
   '80129' = '1'
   '80130' = '1'
   '80131' = '1'
   '80132' = '1'
   '80133' = '1'
   '80134' = '1'
   '80135' = '1'
   '80136' = '1'
   '80139' = '1'
   '80140' = '1'
   '80141' = '1'
   '80142' = '1'
   '80143' = '1'
   '80144' = '1'
   '80145' = '1'
   '80146' = '1'
   '80149' = '1'
   '80152' = '1'
   '80153' = '1'
   '80154' = '1'
   '80155' = '1'
   '80160' = '1'
   '80161' = '1'
   '80162' = '1'
   '80163' = '1'
   '80164' = '1'
   '80165' = '1'
   '80166' = '1'
   '80169' = '1'
   '80170' = '1'
   '80171' = '1'
   '80172' = '1'
   '80173' = '1'
   '80174' = '1'
   '80175' = '1'
   '80176' = '1'
   '80179' = '1'
   '80180' = '1'
   '80181' = '1'
   '80182' = '1'
   '80183' = '1'
   '80184' = '1'
   '80185' = '1'
   '80186' = '1'
   '80189' = '1'
   '80190' = '1'
   '80191' = '1'
   '80192' = '1'
   '80193' = '1'
   '80194' = '1'
   '80195' = '1'
   '80196' = '1'
   '80199' = '1'
   '80302' = '1'
   '80303' = '1'
   '80304' = '1'
   '80394' = '1'
   '80395' = '1'
   '80396' = '1'
   '80399' = '1'
   '80402' = '1'
   '80403' = '1'
   '80404' = '1'
   '80405' = '1'
   '80406' = '1'
   '80410' = '1'
   '80411' = '1'
   '80412' = '1'
   '80413' = '1'
   '80414' = '1'
   '80415' = '1'
   '80416' = '1'
   '80419' = '1'
   '80420' = '1'
   '80421' = '1'
   '80422' = '1'
   '80423' = '1'
   '80424' = '1'
   '80425' = '1'
   '80426' = '1'
   '80429' = '1'
   '80430' = '1'
   '80431' = '1'
   '80432' = '1'
   '80433' = '1'
   '80434' = '1'
   '80435' = '1'
   '80436' = '1'
   '80439' = '1'
   '80440' = '1'
   '80441' = '1'
   '80442' = '1'
   '80443' = '1'
   '80444' = '1'
   '80445' = '1'
   '80446' = '1'
   '80452' = '1'
   '80453' = '1'
   '80454' = '1'
   '80455' = '1'
   '80460' = '1'
   '80461' = '1'
   '80462' = '1'
   '80463' = '1'
   '80464' = '1'
   '80465' = '1'
   '80466' = '1'
   '80470' = '1'
   '80471' = '1'
   '80472' = '1'
   '80473' = '1'
   '80474' = '1'
   '80475' = '1'
   '80476' = '1'
   '80479' = '1'
   '80480' = '1'
   '80481' = '1'
   '80482' = '1'
   '80483' = '1'
   '80484' = '1'
   '80485' = '1'
   '85164' = '1'
   '85165' = '1'
   '85166' = '1'
   '85169' = '1'
   '85170' = '1'
   '85171' = '1'
   '85172' = '1'
   '85173' = '1'
   '85174' = '1'
   '85175' = '1'
   '85176' = '1'
   '85179' = '1'
   '85180' = '1'
   '85181' = '1'
   '85182' = '1'
   '85183' = '1'
   '85184' = '1'
   '85185' = '1'
   '85186' = '1'
   '85189' = '1'
   '85190' = '1'
   '85191' = '1'
   '85192' = '1'
   '85193' = '1'
   '85194' = '1'
   '85195' = '1'
   '85196' = '1'
   '85199' = '1'
   '85200' = '1'
   '85201' = '1'
   '85202' = '1'
   '85203' = '1'
   '85204' = '1'
   '85205' = '1'
   '85206' = '1'
   '85209' = '1'
   '85210' = '1'
   '85211' = '1'
   '85212' = '1'
   '85213' = '1'
   '85214' = '1'
   '85215' = '1'
   '85216' = '1'
   '85219' = '1'
   '85220' = '1'
   '85221' = '1'
   '85222' = '1'
   '85223' = '1'
   '85224' = '1'
   '85225' = '1'
   '85226' = '1'
   '85229' = '1'
   '85230' = '1'
   '85231' = '1'
   '85232' = '1'
   '85233' = '1'
   '85234' = '1'
   '85235' = '1'
   '80063' = '1'
   '80064' = '1'
   '80065' = '1'
   '80066' = '1'
   '80069' = '1'
   '80070' = '1'
   '80071' = '1'
   '80072' = '1'
   '80073' = '1'
   '80074' = '1'
   '80075' = '1'
   '80076' = '1'
   '80079' = '1'
   '80080' = '1'
   '80081' = '1'
   '80082' = '1'
   '80083' = '1'
   '80084' = '1'
   '80085' = '1'
   '80086' = '1'
   '80089' = '1'
   '80090' = '1'
   '80091' = '1'
   '80092' = '1'
   '80093' = '1'
   '80094' = '1'
   '80095' = '1'
   '80096' = '1'
   '80099' = '1'
   '80102' = '1'
   '80103' = '1'
   '80104' = '1'
   '80105' = '1'
   '80110' = '1'
   '80111' = '1'
   '80112' = '1'
   '80113' = '1'
   '80114' = '1'
   '80115' = '1'
   '80305' = '1'
   '80310' = '1'
   '80311' = '1'
   '80312' = '1'
   '80313' = '1'
   '80314' = '1'
   '80315' = '1'
   '80316' = '1'
   '80319' = '1'
   '80320' = '1'
   '80321' = '1'
   '80322' = '1'
   '80323' = '1'
   '80324' = '1'
   '80325' = '1'
   '80326' = '1'
   '80329' = '1'
   '80330' = '1'
   '80331' = '1'
   '80332' = '1'
   '80333' = '1'
   '80334' = '1'
   '80335' = '1'
   '80336' = '1'
   '80339' = '1'
   '80340' = '1'
   '80341' = '1'
   '80342' = '1'
   '80343' = '1'
   '80344' = '1'
   '80345' = '1'
   '80346' = '1'
   '80349' = '1'
   '80352' = '1'
   '80353' = '1'
   '80354' = '1'
   '80355' = '1'
   '80360' = '1'
   '80361' = '1'
   '80362' = '1'
   '80363' = '1'
   '80364' = '1'
   '80365' = '1'
   '80366' = '1'
   '80369' = '1'
   '80370' = '1'
   '80371' = '1'
   '80372' = '1'
   '80373' = '1'
   '80374' = '1'
   '80375' = '1'
   '80376' = '1'
   '80379' = '1'
   '80380' = '1'
   '80381' = '1'
   '80382' = '1'
   '80383' = '1'
   '80384' = '1'
   '80385' = '1'
   '80386' = '1'
   '80389' = '1'
   '80390' = '1'
   '80391' = '1'
   '80392' = '1'
   '80393' = '1'
   '80486' = '1'
   '80489' = '1'
   '80490' = '1'
   '80491' = '1'
   '80492' = '1'
   '80493' = '1'
   '80494' = '1'
   '80495' = '1'
   '80496' = '1'
   '80499' = '1'
   '8502'  = '1'
   '8503'  = '1'
   '8504'  = '1'
   '85100' = '1'
   '85101' = '1'
   '85102' = '1'
   '85103' = '1'
   '85104' = '1'
   '85105' = '1'
   '85106' = '1'
   '85109' = '1'
   '85110' = '1'
   '85111' = '1'
   '85112' = '1'
   '85113' = '1'
   '85114' = '1'
   '85115' = '1'
   '85116' = '1'
   '85119' = '1'
   '85120' = '1'
   '85121' = '1'
   '85122' = '1'
   '85123' = '1'
   '85124' = '1'
   '85125' = '1'
   '85126' = '1'
   '85129' = '1'
   '85130' = '1'
   '85131' = '1'
   '85132' = '1'
   '85133' = '1'
   '85134' = '1'
   '85135' = '1'
   '85136' = '1'
   '85139' = '1'
   '85140' = '1'
   '85141' = '1'
   '85142' = '1'
   '85143' = '1'
   '85144' = '1'
   '85145' = '1'
   '85146' = '1'
   '85149' = '1'
   '85150' = '1'
   '85151' = '1'
   '85152' = '1'
   '85153' = '1'
   '85154' = '1'
   '85155' = '1'
   '85156' = '1'
   '85159' = '1'
   '85160' = '1'
   '85161' = '1'
   '85162' = '1'
   '85163' = '1'
   '85236' = '1'
   '85239' = '1'
   '85240' = '1'
   '85241' = '1'
   '85242' = '1'
   '85243' = '1'
   '85244' = '1'
   '85245' = '1'
   '85246' = '1'
   '85249' = '1'
   '85250' = '1'
   '85251' = '1'
   '85252' = '1'
   '85253' = '1'
   '85254' = '1'
   '85255' = '1'
   '85256' = '1'
   '85259' = '1'
   '85300' = '1'
   '85301' = '1'
   '85302' = '1'
   '85303' = '1'
   '85304' = '1'
   '85305' = '1'
   '85306' = '1'
   '85309' = '1'
   '85310' = '1'
   '85311' = '1'
   '85312' = '1'
   '85313' = '1'
   '85314' = '1'
   '85315' = '1'
   '85316' = '1'
   '85319' = '1'
   '85400' = '1'
   '85401' = '1'
   '85402' = '1'
   '85403' = '1'
   '85404' = '1'
   '85405' = '1'
   '85406' = '1'
   '85409' = '1'
   '85410' = '1'
   '85411' = '1'
   '85412' = '1'
   '85413' = '1'
   '85414' = '1'
   '85415' = '1'
   '85416' = '1'
   '85419' = '1'
   '90001' = '1'
   '90002' = '1'
   '90003' = '1'
   '9001'  = '1'
   '90081' = '1'
   '90082' = '1'
   '9251'  = '1'
   '9252'  = '1'
   OTHER   = '0';
   /*Format for Medical_Chest*/ 
   VALUE $s2fmt
   '80707' = '1'
   '80708' = '1'
   '80716' = '1'
   '80717' = '1'
   '80718' = '1'
   '80719' = '1'
   '8073'  = '1'
   '8074'  = '1'
   '8075'  = '1'
   '8076'  = '1'
   '8191'  = '1'
   '83971' = '1'
   '8600'  = '1'
   '8601'  = '1'
   '8602'  = '1'
   '8603'  = '1'
   '8604'  = '1'
   '8605'  = '1'
   '86100' = '1'
   '86101' = '1'
   '86102' = '1'
   '86103' = '1'
   '86110' = '1'
   '86111' = '1'
   '86112' = '1'
   '86113' = '1'
   '86120' = '1'
   '86121' = '1'
   '86122' = '1'
   '86130' = '1'
   '80714' = '1'
   '80715' = '1'
   '86131' = '1'
   '86132' = '1'
   '8620'  = '1'
   '8621'  = '1'
   '86221' = '1'
   '86222' = '1'
   '86229' = '1'
   '86231' = '1'
   '86232' = '1'
   '86239' = '1'
   '8628'  = '1'
   '8629'  = '1'
   '87410' = '1'
   '87411' = '1'
   '87412' = '1'
   '9010'  = '1'
   '9011'  = '1'
   '9012'  = '1'
   '9013'  = '1'
   '90140' = '1'
   '90141' = '1'
   '90142' = '1'
   '90183' = '1'
   '90189' = '1'
   '9019'  = '1'
   '92701' = '1'
   '9580'  = '1'
   '9581'  = '1'
   OTHER   = '0';
   /*Format for Medical_Abdominal*/ 
   VALUE $s3fmt
   '8630'  = '1'
   '8631'  = '1'
   '86320' = '1'
   '86321' = '1'
   '86329' = '1'
   '86330' = '1'
   '86331' = '1'
   '86339' = '1'
   '86340' = '1'
   '86341' = '1'
   '86342' = '1'
   '86343' = '1'
   '86344' = '1'
   '86345' = '1'
   '86346' = '1'
   '86349' = '1'
   '86350' = '1'
   '86351' = '1'
   '86352' = '1'
   '86353' = '1'
   '86354' = '1'
   '86355' = '1'
   '86356' = '1'
   '86359' = '1'
   '86381' = '1'
   '86382' = '1'
   '86383' = '1'
   '86384' = '1'
   '86385' = '1'
   '86389' = '1'
   '86390' = '1'
   '86391' = '1'
   '86809' = '1'
   '86812' = '1'
   '86813' = '1'
   '86814' = '1'
   '86819' = '1'
   '9020'  = '1'
   '90210' = '1'
   '90211' = '1'
   '90219' = '1'
   '90220' = '1'
   '90221' = '1'
   '90222' = '1'
   '90223' = '1'
   '90224' = '1'
   '90225' = '1'
   '90226' = '1'
   '90227' = '1'
   '90229' = '1'
   '90231' = '1'
   '90232' = '1'
   '86392' = '1'
   '86393' = '1'
   '86394' = '1'
   '86395' = '1'
   '86399' = '1'
   '86400' = '1'
   '86401' = '1'
   '86402' = '1'
   '86403' = '1'
   '86404' = '1'
   '86405' = '1'
   '86409' = '1'
   '86410' = '1'
   '86411' = '1'
   '86412' = '1'
   '86413' = '1'
   '86414' = '1'
   '86415' = '1'
   '86419' = '1'
   '86500' = '1'
   '86501' = '1'
   '86502' = '1'
   '86503' = '1'
   '86504' = '1'
   '86509' = '1'
   '86510' = '1'
   '86511' = '1'
   '86512' = '1'
   '86513' = '1'
   '86514' = '1'
   '86519' = '1'
   '86802' = '1'
   '90233' = '1'
   '90234' = '1'
   '90239' = '1'
   '90240' = '1'
   '90241' = '1'
   '90242' = '1'
   '90249' = '1'
   '90250' = '1'
   '90251' = '1'
   '90252' = '1'
   '90253' = '1'
   '90254' = '1'
   '90255' = '1'
   '90256' = '1'
   '90259' = '1'
   '90281' = '1'
   '90282' = '1'
   '90287' = '1'
   '90289' = '1'
   '9029'  = '1'
   OTHER   = '0';
   /*Format for Medical_Kidney*/ 
   VALUE $s4fmt
   '86600' = '1'
   '86601' = '1'
   '86602' = '1'
   '86603' = '1'
   '86610' = '1'
   '86611' = '1'
   '86612' = '1'
   '86613' = '1'
   '86801' = '1'
   '86811' = '1'
   OTHER   = '0';
   /*Format for Medical_Urinary*/ 
   VALUE $s5fmt
   '8670'  = '1'
   '8671'  = '1'
   '8672'  = '1'
   '8673'  = '1'
   '8674'  = '1'
   '8675'  = '1'
   '8676'  = '1'
   '8677'  = '1'
   '8678'  = '1'
   '8679'  = '1'
   OTHER   = '0';
   /*Format for Medical_Pelvis_Spine*/ 
   VALUE $s6fmt
   '8056'  = '1'
   '8057'  = '1'
   '80600' = '1'
   '80601' = '1'
   '80602' = '1'
   '80603' = '1'
   '80604' = '1'
   '80605' = '1'
   '80606' = '1'
   '80607' = '1'
   '80608' = '1'
   '80609' = '1'
   '80610' = '1'
   '80611' = '1'
   '80612' = '1'
   '80613' = '1'
   '80614' = '1'
   '80615' = '1'
   '80616' = '1'
   '80617' = '1'
   '80618' = '1'
   '80619' = '1'
   '80660' = '1'
   '80670' = '1'
   '80671' = '1'
   '80672' = '1'
   '80679' = '1'
   '8068'  = '1'
   '8069'  = '1'
   '8080'  = '1'
   '8081'  = '1'
   '8082'  = '1'
   '8083'  = '1'
   '80841' = '1'
   '80842' = '1'
   '80843' = '1'
   '80849' = '1'
   '80851' = '1'
   '80852' = '1'
   '80853' = '1'
   '80859' = '1'
   '8088'  = '1'
   '8089'  = '1'
   '8091'  = '1'
   '83900' = '1'
   '83901' = '1'
   '83902' = '1'
   '83903' = '1'
   '83904' = '1'
   '83905' = '1'
   '83906' = '1'
   '83907' = '1'
   '83908' = '1'
   '83910' = '1'
   '83911' = '1'
   '83912' = '1'
   '83913' = '1'
   '83914' = '1'
   '83915' = '1'
   '83916' = '1'
   '83917' = '1'
   '80620' = '1'
   '80621' = '1'
   '80622' = '1'
   '80623' = '1'
   '80624' = '1'
   '80625' = '1'
   '80626' = '1'
   '80627' = '1'
   '80628' = '1'
   '80629' = '1'
   '80630' = '1'
   '80631' = '1'
   '80632' = '1'
   '80633' = '1'
   '80634' = '1'
   '80635' = '1'
   '80636' = '1'
   '80637' = '1'
   '80638' = '1'
   '80639' = '1'
   '8064'  = '1'
   '8065'  = '1'
   '83918' = '1'
   '83952' = '1'
   '83959' = '1'
   '86803' = '1'
   '86804' = '1'
   '92611' = '1'
   '92619' = '1'
   '9268'  = '1'
   '9269'  = '1'
   '95200' = '1'
   '95201' = '1'
   '95202' = '1'
   '95203' = '1'
   '95204' = '1'
   '95205' = '1'
   '95206' = '1'
   '95207' = '1'
   '95208' = '1'
   '95209' = '1'
   '95210' = '1'
   '95211' = '1'
   '95212' = '1'
   '95213' = '1'
   '95214' = '1'
   '95215' = '1'
   '95216' = '1'
   '95217' = '1'
   '95218' = '1'
   '95219' = '1'
   '9522'  = '1'
   '9523'  = '1'
   '9524'  = '1'
   '9528'  = '1'
   '9529'  = '1'
   '9535'  = '1'
   '9538'  = '1'
   '9548'  = '1'
   '9549'  = '1'
   OTHER   = '0';
   /*Format for Medical_UpperLimb*/ 
   VALUE $s7fmt
   '81210' = '1'
   '81211' = '1'
   '81212' = '1'
   '81213' = '1'
   '81219' = '1'
   '81230' = '1'
   '81231' = '1'
   '81250' = '1'
   '81251' = '1'
   '81252' = '1'
   '81253' = '1'
   '81254' = '1'
   '81259' = '1'
   '81310' = '1'
   '81311' = '1'
   '81312' = '1'
   '81313' = '1'
   '81314' = '1'
   '81315' = '1'
   '81316' = '1'
   '81317' = '1'
   '83210' = '1'
   '83211' = '1'
   '83212' = '1'
   '83213' = '1'
   '83214' = '1'
   '83219' = '1'
   '8870'  = '1'
   '8871'  = '1'
   '8872'  = '1'
   '8873'  = '1'
   '8874'  = '1'
   '8875'  = '1'
   '8876'  = '1'
   '8877'  = '1'
   '90300' = '1'
   '90301' = '1'
   '90302' = '1'
   '9031'  = '1'
   '9032'  = '1'
   '81318' = '1'
   '81330' = '1'
   '81331' = '1'
   '81332' = '1'
   '81333' = '1'
   '81350' = '1'
   '81351' = '1'
   '81352' = '1'
   '81353' = '1'
   '81354' = '1'
   '81390' = '1'
   '81391' = '1'
   '81392' = '1'
   '81393' = '1'
   '8181'  = '1'
   '83110' = '1'
   '83111' = '1'
   '83112' = '1'
   '83113' = '1'
   '83114' = '1'
   '83119' = '1'
   '9033'  = '1'
   '9038'  = '1'
   '9039'  = '1'
   '92700' = '1'
   '92702' = '1'
   '92703' = '1'
   '92709' = '1'
   '92710' = '1'
   '92711' = '1'
   '9278'  = '1'
   '9279'  = '1'
   '9534'  = '1'
   '9550'  = '1'
   '9551'  = '1'
   '9552'  = '1'
   '9553'  = '1'
   '9558'  = '1'
   '9586'  = '1'
   OTHER   = '0';
   /*Format for Medical_LowerLimb*/ 
   VALUE $s8fmt
   '82000' = '1'
   '82001' = '1'
   '82002' = '1'
   '82003' = '1'
   '82009' = '1'
   '82010' = '1'
   '82011' = '1'
   '82012' = '1'
   '82013' = '1'
   '82019' = '1'
   '82020' = '1'
   '82021' = '1'
   '82022' = '1'
   '82030' = '1'
   '82031' = '1'
   '82032' = '1'
   '8208'  = '1'
   '8209'  = '1'
   '82100' = '1'
   '82101' = '1'
   '82110' = '1'
   '82111' = '1'
   '82120' = '1'
   '82121' = '1'
   '82122' = '1'
   '82123' = '1'
   '82129' = '1'
   '82130' = '1'
   '82131' = '1'
   '82132' = '1'
   '82133' = '1'
   '82139' = '1'
   '82310' = '1'
   '82311' = '1'
   '82312' = '1'
   '82330' = '1'
   '82331' = '1'
   '82332' = '1'
   '82340' = '1'
   '82341' = '1'
   '82342' = '1'
   '92800' = '1'
   '92801' = '1'
   '92810' = '1'
   '92811' = '1'
   '9288'  = '1'
   '9289'  = '1'
   '82390' = '1'
   '82391' = '1'
   '82392' = '1'
   '8280'  = '1'
   '8281'  = '1'
   '83510' = '1'
   '83511' = '1'
   '83512' = '1'
   '83513' = '1'
   '83660' = '1'
   '83661' = '1'
   '83662' = '1'
   '83663' = '1'
   '83664' = '1'
   '83669' = '1'
   '8371'  = '1'
   '8960'  = '1'
   '8961'  = '1'
   '8962'  = '1'
   '8963'  = '1'
   '8970'  = '1'
   '8971'  = '1'
   '8972'  = '1'
   '8973'  = '1'
   '8974'  = '1'
   '8975'  = '1'
   '8976'  = '1'
   '8977'  = '1'
   '9040'  = '1'
   '9041'  = '1'
   '9042'  = '1'
   '90440' = '1'
   '90441' = '1'
   '90442' = '1'
   '90450' = '1'
   '90451' = '1'
   '90452' = '1'
   '90453' = '1'
   '90454' = '1'
   '9047'  = '1'
   '92612' = '1'
   '9560'  = '1'
   '9561'  = '1'
   '9562'  = '1'
   '9563'  = '1'
   '9568'  = '1'
   '9569'  = '1'
   OTHER   = '0';

* -------------------------------------------------------------- * ;
* --- PDI DEFINING FORMATS ------------------------------------- * ;
* -------------------------------------------------------------- * ;

/* ------------------------------ */
/* NEONATE AND NEWBORN            */
/* ------------------------------ */
/* Liveborn (Populaton at Risk)           */
/* ICD-9-CM Diagnosis Codes:              */

value $LIVEBND
'V3000' = 1  /* SINGLE LB IN-HOSP W/O CS */
'V3001' = 1  /* SINGLE LB IN-HOSP W CS */
'V3100' = 1  /* TWIN-MATE LB-HOSP W/O CS */
'V3101' = 1  /* TWIN-MATE LB-IN HOS W CS */
'V3200' = 1  /* TWIN-MATE SB-HOSP W/O CS */
'V3201' = 1  /* TWIN-MATE SB-HOSP W CS */
'V3300' = 1  /* TWIN-NOS-IN HOSP W/O CS */
'V3301' = 1  /* TWIN-NOS-IN HOSP W CS */
'V3400' = 1  /* OTH MULT LB-HOSP W/O CS */
'V3401' = 1  /* OTH MULT LB-IN HOSP W CS */
'V3500' = 1  /* OTH MULT SB-HOSP W/O CS */
'V3501' = 1  /* OTH MULT SB-IN HOSP W CS */
'V3600' = 1  /* MULT LB/SB-IN HOS W/O CS */
'V3601' = 1  /* MULT LB/SB-IN HOSP W CS */
'V3700' = 1  /* MULT BRTH NOS-HOS W/O CS */
'V3701' = 1  /* MULT BIRTH NOS-HOSP W CS */
'V3900' = 1  /* LIVEBORN NOS-HOSP W/O CS */
'V3901' = 1  /* LIVEBORN NOS-HOSP W CS */
other   = 0;

value $V29D
"V290"  = "1" /* OBSERVATIONS FOR SUSPECTED INFECTIOUS CONDITION */
"V291"  = "1" /* OBSERVATIONS FOR SUSPECTED NEUROLOGICAL CONDITION */
"V292"  = "1" /* OBSERVATIONS FOR SUSPECTED RESPIRATORY CONDITION */
"V293"  = "1" /* OBSERVATIONS FOR SUSPECTED GENETIC OR METABOLIC CONDITION */
"V298"  = "1" /* OBSERVATIONS FOR OTHER SPECIFIED SUSPECTED CONDITION */
"V299"  = "1" /* OBSERVATIONS FOR UNSPECIFIED SUSPECTED CONDITION */
other   = "0";

value $LIVEB2D
'V301 ' = 1  /* SINGL LIVEBRN-BEFORE ADM */
'V302 ' = 1  /* SINGLE LIVEBORN-NONHOSP */
'V311 ' = 1  /* TWIN, MATE LB-BEFORE ADM */
'V312 ' = 1  /* TWIN, MATE LB-NONHOSP */
'V321 ' = 1  /* TWIN, MATE SB-BEFORE ADM */
'V322 ' = 1  /* TWIN, MATE SB-NONHOSP */
'V331 ' = 1  /* TWIN NOS-BEFORE ADMISSN */
'V332 ' = 1  /* TWIN NOS-NONHOSP */
'V341 ' = 1  /* OTH MULT NB-BEFORE ADM */
'V342 ' = 1  /* OTH MULTIPLE NB-NONHOSP */
'V351 ' = 1  /* OTH MULT SB-BEFORE ADM */
'V352 ' = 1  /* OTH MULTIPLE SB-NONHOSP */
'V361 ' = 1  /* MULT NB/SB-BEFORE ADM */
'V362 ' = 1  /* MULTIPLE NB/SB-NONHOSP */
'V371 ' = 1  /* MULT BRTH NOS-BEFORE ADM */
'V372 ' = 1  /* MULT BIRTH NOS-NONHOSP */
'V391 ' = 1  /* LIVEBORN NOS-BEFORE ADM */
'V392 ' = 1  /* LIVEBORN NOS-NONHOSP */
other   = 0;

/* ---------------------------------------------------------------- */
/* LOW BIRTH WEIGHT                                                 */
/* ---------------------------------------------------------------- */
/* ICD-9-CM DIAGNOSIS CODES: */
value $LW500G
"76401" = "1"
"76411" = "1"
"76421" = "1"
"76491" = "1"
"76501" = "1"
"76511" = "1"
"V2131" = "1"
other = "0";
value $LW750G
"76402" = "1"
"76412" = "1"
"76422" = "1"
"76492" = "1"
"76502" = "1"
"76512" = "1"
"V2132" = "1"
other   = "0";
value $LW1000G
"76403" = "1"
"76413" = "1"
"76423" = "1"
"76493" = "1"
"76503" = "1"
"76513" = "1"
"V2132" = "1"
other   = "0";
value $LW1250G
"76404" = "1"
"76414" = "1"
"76424" = "1"
"76494" = "1"
"76504" = "1"
"76514" = "1"
"V2133" = "1"
other   = "0";
value $LW1500G
"76405" = "1"
"76415" = "1"
"76425" = "1"
"76495" = "1"
"76505" = "1"
"76515" = "1"
"V2133" = "1"
other   = "0";
value $LW1750G
"76406" = "1"
"76416" = "1"
"76426" = "1"
"76496" = "1"
"76506" = "1"
"76516" = "1"
"V2134" = "1"
other   = "0";
value $LW2000G
"76407" = "1"
"76417" = "1"
"76427" = "1"
"76497" = "1"
"76507" = "1"
"76517" = "1"
"V2134" = "1"
other   = "0";
value $LW2500G
"76408" = "1" /* LT-FOR-DATES 2000-2499G */
"76418" = "1" /* LT-DATE W/MAL 2000-2499G */
"76428" = "1" /* FETAL MALNUTR 2000-2499G */
"76498" = "1" /* FET GRWTH RET 2000-2499G */
"76508" = "1" /* EXTREME IMMAT 2000-2499G */
"76518" = "1" /* OTHER PRETERM INFANTS 2000-2499G */
"V2135" = "1"
other   = "0";
value $LW2500P
"76409" = "1" /* LT-FOR-DATES 2000-2499G */
"76419" = "1" /* LT-DATE W/MAL 2000-2499G */
"76429" = "1" /* FETAL MALNUTR 2000-2499G */
"76499" = "1" /* FET GRWTH RET 2000-2499G */
"76509" = "1" /* EXTREME IMMAT 2000-2499G */
"76519" = "1" /* OTHER PRETERM INFANTS 2000-2499G */
other   = "0";

/* ------------------------------------- */
/* Birth Trauma Rate  Injury to Neonate */
/*   PROVIDER INDICATOR / PSI 17         */
/* ------------------------------------- */
/* BIRTH TRAUMA */
/* ICD-9-CM DIAGNOSIS CODES: */
value $BIRTHID
"7670 " = "1" /* SUBDURAL AND CEREBRAL HEMORRHAGE (DUE TO TRAUMA OR TO INTRAPARTUM ANOXIA OR HYPOXIA) */
"76711" = "1" /* EPICRANIAL SUBAPO HEMORR */
"7673 " = "1" /* INJURIES TO SKELETON (EXCLUDES CLAVICLE) */
"7674 " = "1" /* INJURY TO SPINE AND SPINAL CORD */
"7675 " = "1" /* FACIAL NERVE INJ-BIRTH */
"7677 " = "1" /* OTHER CRANIAL AND PERIPHERAL NERVE INJURIES */
"7678 " = "1" /* OTHER SPECIFIED BIRTH TRAUMA */
other   = "0"
;
/* EXCLUDE: PRETERM INFANT */
/* ICD-9-CM DIAGNOSIS CODES: */
value $PRETEID
"76500" = "1" /* EXTREME IMMATUR WTNOS */
"76501" = "1" /* EXTREME IMMATURITY, LESS THAN 500 GRAMS  */
"76502" = "1" /* EXTREME IMMATURITY, 500 - 749 GRAMS */
"76503" = "1" /* EXTREME IMMATURITY, 750 - 999 GRAMS  */
"76504" = "1" /* EXTREME IMMATURITY, 1000 - 1249 GRAMS  */
"76505" = "1" /* EXTREME IMMATURITY, 1250 - 1499 GRAMS */
"76506" = "1" /* EXTREME IMMATURITY, 1500 - 1749 GRAMS  */
"76507" = "1" /* EXTREME IMMATURITY, 1750 - 1999 GRAMS  */
"76511" = "1" /* OTHER PRETERM INFANTS, LESS THAN 500 GRAMS  */
"76512" = "1" /* OTHER PRETERM INFANTS, 500 - 749 GRAMS  */
"76513" = "1" /* OTHER PRETERM INFANTS, 750 - 999 GRAMS  */
"76514" = "1" /* OTHER PRETERM INFANTS, 1000 - 1249 GRAMS  */
"76515" = "1" /* OTHER PRETERM INFANTS, 1250 - 1499 GRAMS  */
"76516" = "1" /* OTHER PRETERM INFANTS, 1500 - 1749 GRAMS */
"76517" = "1" /* OTHER PRETERM INFANTS, 1750 - 1999 GRAMS  */
other   = "0";

/* EXCLUDE: OSTEOGENESIS IMPERFECTA */
/* ICD-9-CM DIAGNOSIS CODES: */
value $OSTEOID
"75651" = "1" /* OSTEOGENESIS IMPERFECTA */
other   = "0";

/* --------------------------------------- */
/* ---   FORMATS FOR DRG STRATIFIERS   --- */
/* --------------------------------------- */

/* MS-DRG TO MDC (MDCF2T) for DRGs V25 or later*/
value MDCF2T
001 = 77
002 = 77
003 = 77
004 = 77
005 = 77
006 = 77
007 = 77
008 = 77
009 = 77
010 = 77
011 = 77
012 = 77
013 = 77
014 = 77
015 = 77
016 = 77
017 = 77
020 = 01
021 = 01
022 = 01
023 = 01
024 = 01
025 = 01
026 = 01
027 = 01
028 = 01
029 = 01
030 = 01
031 = 01
032 = 01
033 = 01
034 = 01
035 = 01
036 = 01
037 = 01
038 = 01
039 = 01
040 = 01
041 = 01
042 = 01
052 = 01
053 = 01
054 = 01
055 = 01
056 = 01
057 = 01
058 = 01
059 = 01
060 = 01
061 = 01
062 = 01
063 = 01
064 = 01
065 = 01
066 = 01
067 = 01
068 = 01
069 = 01
070 = 01
071 = 01
072 = 01
073 = 01
074 = 01
075 = 01
076 = 01
077 = 01
078 = 01
079 = 01
080 = 01
081 = 01
082 = 01
083 = 01
084 = 01
085 = 01
086 = 01
087 = 01
088 = 01
089 = 01
090 = 01
091 = 01
092 = 01
093 = 01
094 = 01
095 = 01
096 = 01
097 = 01
098 = 01
099 = 01
100 = 01
101 = 01
102 = 01
103 = 01
113 = 02
114 = 02
115 = 02
116 = 02
117 = 02
121 = 02
122 = 02
123 = 02
124 = 02
125 = 02
129 = 03
130 = 03
131 = 03
132 = 03
133 = 03
134 = 03
135 = 03
136 = 03
137 = 03
138 = 03
139 = 03
146 = 03
147 = 03
148 = 03
149 = 03
150 = 03
151 = 03
152 = 03
153 = 03
154 = 03
155 = 03
156 = 03
157 = 03
158 = 03
159 = 03
163 = 04
164 = 04
165 = 04
166 = 04
167 = 04
168 = 04
175 = 04
176 = 04
177 = 04
178 = 04
179 = 04
180 = 04
181 = 04
182 = 04
183 = 04
184 = 04
185 = 04
186 = 04
187 = 04
188 = 04
189 = 04
190 = 04
191 = 04
192 = 04
193 = 04
194 = 04
195 = 04
196 = 04
197 = 04
198 = 04
199 = 04
200 = 04
201 = 04
202 = 04
203 = 04
204 = 04
205 = 04
206 = 04
207 = 04
208 = 04
215 = 05
216 = 05
217 = 05
218 = 05
219 = 05
220 = 05
221 = 05
222 = 05
223 = 05
224 = 05
225 = 05
226 = 05
227 = 05
228 = 05
229 = 05
230 = 05
231 = 05
232 = 05
233 = 05
234 = 05
235 = 05
236 = 05
237 = 05
238 = 05
239 = 05
240 = 05
241 = 05
242 = 05
243 = 05
244 = 05
245 = 05
246 = 05
247 = 05
248 = 05
249 = 05
250 = 05
251 = 05
252 = 05
253 = 05
254 = 05
255 = 05
256 = 05
257 = 05
258 = 05
259 = 05
260 = 05
261 = 05
262 = 05
263 = 05
264 = 05
265 = 05
266 = 05
267 = 05
280 = 05
281 = 05
282 = 05
283 = 05
284 = 05
285 = 05
286 = 05
287 = 05
288 = 05
289 = 05
290 = 05
291 = 05
292 = 05
293 = 05
294 = 05
295 = 05
296 = 05
297 = 05
298 = 05
299 = 05
300 = 05
301 = 05
302 = 05
303 = 05
304 = 05
305 = 05
306 = 05
307 = 05
308 = 05
309 = 05
310 = 05
311 = 05
312 = 05
313 = 05
314 = 05
315 = 05
316 = 05
326 = 06
327 = 06
328 = 06
329 = 06
330 = 06
331 = 06
332 = 06
333 = 06
334 = 06
335 = 06
336 = 06
337 = 06
338 = 06
339 = 06
340 = 06
341 = 06
342 = 06
343 = 06
344 = 06
345 = 06
346 = 06
347 = 06
348 = 06
349 = 06
350 = 06
351 = 06
352 = 06
353 = 06
354 = 06
355 = 06
356 = 06
357 = 06
358 = 06
368 = 06
369 = 06
370 = 06
371 = 06
372 = 06
373 = 06
374 = 06
375 = 06
376 = 06
377 = 06
378 = 06
379 = 06
380 = 06
381 = 06
382 = 06
383 = 06
384 = 06
385 = 06
386 = 06
387 = 06
388 = 06
389 = 06
390 = 06
391 = 06
392 = 06
393 = 06
394 = 06
395 = 06
405 = 07
406 = 07
407 = 07
408 = 07
409 = 07
410 = 07
411 = 07
412 = 07
413 = 07
414 = 07
415 = 07
416 = 07
417 = 07
418 = 07
419 = 07
420 = 07
421 = 07
422 = 07
423 = 07
424 = 07
425 = 07
432 = 07
433 = 07
434 = 07
435 = 07
436 = 07
437 = 07
438 = 07
439 = 07
440 = 07
441 = 07
442 = 07
443 = 07
444 = 07
445 = 07
446 = 07
453 = 08
454 = 08
455 = 08
456 = 08
457 = 08
458 = 08
459 = 08
460 = 08
461 = 08
462 = 08
463 = 08
464 = 08
465 = 08
466 = 08
467 = 08
468 = 08
469 = 08
470 = 08
471 = 08
472 = 08
473 = 08
474 = 08
475 = 08
476 = 08
477 = 08
478 = 08
479 = 08
480 = 08
481 = 08
482 = 08
483 = 08
484 = 08
485 = 08
486 = 08
487 = 08
488 = 08
489 = 08
490 = 08
491 = 08
492 = 08
493 = 08
494 = 08
495 = 08
496 = 08
497 = 08
498 = 08
499 = 08
500 = 08
501 = 08
502 = 08
503 = 08
504 = 08
505 = 08
506 = 08
507 = 08
508 = 08
509 = 08
510 = 08
511 = 08
512 = 08
513 = 08
514 = 08
515 = 08
516 = 08
517 = 08
518 = 08
519 = 08
520 = 08
533 = 08
534 = 08
535 = 08
536 = 08
537 = 08
538 = 08
539 = 08
540 = 08
541 = 08
542 = 08
543 = 08
544 = 08
545 = 08
546 = 08
547 = 08
548 = 08
549 = 08
550 = 08
551 = 08
552 = 08
553 = 08
554 = 08
555 = 08
556 = 08
557 = 08
558 = 08
559 = 08
560 = 08
561 = 08
562 = 08
563 = 08
564 = 08
565 = 08
566 = 08
570 = 09
571 = 09
572 = 09
573 = 09
574 = 09
575 = 09
576 = 09
577 = 09
578 = 09
579 = 09
580 = 09
581 = 09
582 = 09
583 = 09
584 = 09
585 = 09
592 = 09
593 = 09
594 = 09
595 = 09
596 = 09
597 = 09
598 = 09
599 = 09
600 = 09
601 = 09
602 = 09
603 = 09
604 = 09
605 = 09
606 = 09
607 = 09
614 = 10
615 = 10
616 = 10
617 = 10
618 = 10
619 = 10
620 = 10
621 = 10
622 = 10
623 = 10
624 = 10
625 = 10
626 = 10
627 = 10
628 = 10
629 = 10
630 = 10
637 = 10
638 = 10
639 = 10
640 = 10
641 = 10
642 = 10
643 = 10
644 = 10
645 = 10
652 = 11
653 = 11
654 = 11
655 = 11
656 = 11
657 = 11
658 = 11
659 = 11
660 = 11
661 = 11
662 = 11
663 = 11
664 = 11
665 = 11
666 = 11
667 = 11
668 = 11
669 = 11
670 = 11
671 = 11
672 = 11
673 = 11
674 = 11
675 = 11
682 = 11
683 = 11
684 = 11
685 = 11
686 = 11
687 = 11
688 = 11
689 = 11
690 = 11
691 = 11
692 = 11
693 = 11
694 = 11
695 = 11
696 = 11
697 = 11
698 = 11
699 = 11
700 = 11
707 = 12
708 = 12
709 = 12
710 = 12
711 = 12
712 = 12
713 = 12
714 = 12
715 = 12
716 = 12
717 = 12
718 = 12
722 = 12
723 = 12
724 = 12
725 = 12
726 = 12
727 = 12
728 = 12
729 = 12
730 = 12
734 = 13
735 = 13
736 = 13
737 = 13
738 = 13
739 = 13
740 = 13
741 = 13
742 = 13
743 = 13
744 = 13
745 = 13
746 = 13
747 = 13
748 = 13
749 = 13
750 = 13
754 = 13
755 = 13
756 = 13
757 = 13
758 = 13
759 = 13
760 = 13
761 = 13
765 = 14
766 = 14
767 = 14
768 = 14
769 = 14
770 = 14
774 = 14
775 = 14
776 = 14
777 = 14
778 = 14
779 = 14
780 = 14
781 = 14
782 = 14
789 = 15
790 = 15
791 = 15
792 = 15
793 = 15
794 = 15
795 = 15
799 = 16
800 = 16
801 = 16
802 = 16
803 = 16
804 = 16
808 = 16
809 = 16
810 = 16
811 = 16
812 = 16
813 = 16
814 = 16
815 = 16
816 = 16
820 = 17
821 = 17
822 = 17
823 = 17
824 = 17
825 = 17
826 = 17
827 = 17
828 = 17
829 = 17
830 = 17
834 = 17
835 = 17
836 = 17
837 = 17
838 = 17
839 = 17
840 = 17
841 = 17
842 = 17
843 = 17
844 = 17
845 = 17
846 = 17
847 = 17
848 = 17
849 = 17
853 = 18
854 = 18
855 = 18
856 = 18
857 = 18
858 = 18
862 = 18
863 = 18
864 = 18
865 = 18
866 = 18
867 = 18
868 = 18
869 = 18
870 = 18
871 = 18
872 = 18
876 = 19
880 = 19
881 = 19
882 = 19
883 = 19
884 = 19
885 = 19
886 = 19
887 = 19
894 = 20
895 = 20
896 = 20
897 = 20
901 = 21
902 = 21
903 = 21
904 = 21
905 = 21
906 = 21
907 = 21
908 = 21
909 = 21
913 = 21
914 = 21
915 = 21
916 = 21
917 = 21
918 = 21
919 = 21
920 = 21
921 = 21
922 = 21
923 = 21
927 = 22
928 = 22
929 = 22
933 = 22
934 = 22
935 = 22
939 = 23
940 = 23
941 = 23
945 = 23
946 = 23
947 = 23
948 = 23
949 = 23
950 = 23
951 = 23
955 = 24
956 = 24
957 = 24
958 = 24
959 = 24
963 = 24
964 = 24
965 = 24
969 = 25
970 = 25
974 = 25
975 = 25
976 = 25
977 = 25
981 = 88
982 = 88
983 = 88
984 = 88
985 = 88
986 = 88
987 = 88
988 = 88
989 = 88
998 = 88
999 = 88
other  = 99
;
run;
